Class: Google::Apis::FirestoreV1::ExplainStats

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/firestore_v1/classes.rb,
lib/google/apis/firestore_v1/representations.rb,
lib/google/apis/firestore_v1/representations.rb

Overview

Pipeline explain stats. Depending on the explain options in the original request, this can contain the optimized plan and / or execution stats.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ExplainStats

Returns a new instance of ExplainStats.



1081
1082
1083
# File 'lib/google/apis/firestore_v1/classes.rb', line 1081

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#dataHash<String,Object>

The format depends on the output_format options in the request. Currently there are two supported options: TEXT and JSON. Both supply a google. protobuf.StringValue. Corresponds to the JSON property data

Returns:

  • (Hash<String,Object>)


1079
1080
1081
# File 'lib/google/apis/firestore_v1/classes.rb', line 1079

def data
  @data
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1086
1087
1088
# File 'lib/google/apis/firestore_v1/classes.rb', line 1086

def update!(**args)
  @data = args[:data] if args.key?(:data)
end