Class: Google::Apis::FirestoreV1::GoogleFirestoreAdminV1Backup
- Inherits:
-
Object
- Object
- Google::Apis::FirestoreV1::GoogleFirestoreAdminV1Backup
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/firestore_v1/classes.rb,
lib/google/apis/firestore_v1/representations.rb,
lib/google/apis/firestore_v1/representations.rb
Overview
A Backup of a Cloud Firestore Database. The backup contains all documents and index configurations for the given database at a specific point in time.
Instance Attribute Summary collapse
-
#database ⇒ String
Output only.
-
#database_uid ⇒ String
Output only.
-
#expire_time ⇒ String
Output only.
-
#name ⇒ String
Output only.
-
#snapshot_time ⇒ String
Output only.
-
#state ⇒ String
Output only.
-
#stats ⇒ Google::Apis::FirestoreV1::GoogleFirestoreAdminV1Stats
Backup specific statistics.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleFirestoreAdminV1Backup
constructor
A new instance of GoogleFirestoreAdminV1Backup.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleFirestoreAdminV1Backup
Returns a new instance of GoogleFirestoreAdminV1Backup.
1399 1400 1401 |
# File 'lib/google/apis/firestore_v1/classes.rb', line 1399 def initialize(**args) update!(**args) end |
Instance Attribute Details
#database ⇒ String
Output only. Name of the Firestore database that the backup is from. Format is
projects/project/databases/database`.
Corresponds to the JSON propertydatabase`
1361 1362 1363 |
# File 'lib/google/apis/firestore_v1/classes.rb', line 1361 def database @database end |
#database_uid ⇒ String
Output only. The system-generated UUID4 for the Firestore database that the
backup is from.
Corresponds to the JSON property databaseUid
1367 1368 1369 |
# File 'lib/google/apis/firestore_v1/classes.rb', line 1367 def database_uid @database_uid end |
#expire_time ⇒ String
Output only. The timestamp at which this backup expires.
Corresponds to the JSON property expireTime
1372 1373 1374 |
# File 'lib/google/apis/firestore_v1/classes.rb', line 1372 def expire_time @expire_time end |
#name ⇒ String
Output only. The unique resource name of the Backup. Format is projects/
project/locations/location/backups/backup`. The location in the name will
be the Standard Managed Multi-Region (SMMR) location (e.g.us) if the backup
was created with an SMMR location, or the Google Managed Multi-Region (GMMR)
location (e.g.nam5) if the backup was created with a GMMR location.
Corresponds to the JSON propertyname`
1381 1382 1383 |
# File 'lib/google/apis/firestore_v1/classes.rb', line 1381 def name @name end |
#snapshot_time ⇒ String
Output only. The backup contains an externally consistent copy of the database
at this time.
Corresponds to the JSON property snapshotTime
1387 1388 1389 |
# File 'lib/google/apis/firestore_v1/classes.rb', line 1387 def snapshot_time @snapshot_time end |
#state ⇒ String
Output only. The current state of the backup.
Corresponds to the JSON property state
1392 1393 1394 |
# File 'lib/google/apis/firestore_v1/classes.rb', line 1392 def state @state end |
#stats ⇒ Google::Apis::FirestoreV1::GoogleFirestoreAdminV1Stats
Backup specific statistics.
Corresponds to the JSON property stats
1397 1398 1399 |
# File 'lib/google/apis/firestore_v1/classes.rb', line 1397 def stats @stats end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1404 1405 1406 1407 1408 1409 1410 1411 1412 |
# File 'lib/google/apis/firestore_v1/classes.rb', line 1404 def update!(**args) @database = args[:database] if args.key?(:database) @database_uid = args[:database_uid] if args.key?(:database_uid) @expire_time = args[:expire_time] if args.key?(:expire_time) @name = args[:name] if args.key?(:name) @snapshot_time = args[:snapshot_time] if args.key?(:snapshot_time) @state = args[:state] if args.key?(:state) @stats = args[:stats] if args.key?(:stats) end |