Class: Google::Apis::FirestoreV1::GoogleFirestoreAdminV1BackupSource

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/firestore_v1/classes.rb,
lib/google/apis/firestore_v1/representations.rb,
lib/google/apis/firestore_v1/representations.rb

Overview

Information about a backup that was used to restore a database.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleFirestoreAdminV1BackupSource

Returns a new instance of GoogleFirestoreAdminV1BackupSource.



1484
1485
1486
# File 'lib/google/apis/firestore_v1/classes.rb', line 1484

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#backupString

The resource name of the backup that was used to restore this database. Format: projects/project/locations/location/backups/backup`. Corresponds to the JSON propertybackup`

Returns:

  • (String)


1482
1483
1484
# File 'lib/google/apis/firestore_v1/classes.rb', line 1482

def backup
  @backup
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1489
1490
1491
# File 'lib/google/apis/firestore_v1/classes.rb', line 1489

def update!(**args)
  @backup = args[:backup] if args.key?(:backup)
end