Class: Google::Apis::FirestoreV1::GoogleFirestoreAdminV1BulkDeleteDocumentsRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/firestore_v1/classes.rb,
lib/google/apis/firestore_v1/representations.rb,
lib/google/apis/firestore_v1/representations.rb

Overview

The request for FirestoreAdmin.BulkDeleteDocuments. When both collection_ids and namespace_ids are set, only documents satisfying both conditions will be deleted. Requests with namespace_ids and collection_ids both empty will be rejected. Please use FirestoreAdmin.DeleteDatabase instead.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleFirestoreAdminV1BulkDeleteDocumentsRequest

Returns a new instance of GoogleFirestoreAdminV1BulkDeleteDocumentsRequest.



1553
1554
1555
# File 'lib/google/apis/firestore_v1/classes.rb', line 1553

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#collection_idsArray<String>

Optional. IDs of the collection groups to delete. Unspecified means all collection groups. Each collection group in this list must be unique. Corresponds to the JSON property collectionIds

Returns:

  • (Array<String>)


1542
1543
1544
# File 'lib/google/apis/firestore_v1/classes.rb', line 1542

def collection_ids
  @collection_ids
end

#namespace_idsArray<String>

Optional. Namespaces to delete. An empty list means all namespaces. This is the recommended usage for databases that don't use namespaces. An empty string element represents the default namespace. This should be used if the database has data in non-default namespaces, but doesn't want to delete from them. Each namespace in this list must be unique. Corresponds to the JSON property namespaceIds

Returns:

  • (Array<String>)


1551
1552
1553
# File 'lib/google/apis/firestore_v1/classes.rb', line 1551

def namespace_ids
  @namespace_ids
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1558
1559
1560
1561
# File 'lib/google/apis/firestore_v1/classes.rb', line 1558

def update!(**args)
  @collection_ids = args[:collection_ids] if args.key?(:collection_ids)
  @namespace_ids = args[:namespace_ids] if args.key?(:namespace_ids)
end