Class: Google::Apis::FirestoreV1::GoogleFirestoreAdminV1DatabaseScope

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/firestore_v1/classes.rb,
lib/google/apis/firestore_v1/representations.rb,
lib/google/apis/firestore_v1/representations.rb

Overview

The change stream is scoped to the entire database. All events in the database are visible to the Change Stream. One Database scope Change Stream is allowed per database.

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleFirestoreAdminV1DatabaseScope

Returns a new instance of GoogleFirestoreAdminV1DatabaseScope.



2087
2088
2089
# File 'lib/google/apis/firestore_v1/classes.rb', line 2087

def initialize(**args)
   update!(**args)
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2092
2093
# File 'lib/google/apis/firestore_v1/classes.rb', line 2092

def update!(**args)
end