Class: Google::Apis::FirestoreV1::GoogleFirestoreAdminV1ExportDocumentsRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/firestore_v1/classes.rb,
lib/google/apis/firestore_v1/representations.rb,
lib/google/apis/firestore_v1/representations.rb

Overview

The request for FirestoreAdmin.ExportDocuments.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleFirestoreAdminV1ExportDocumentsRequest

Returns a new instance of GoogleFirestoreAdminV1ExportDocumentsRequest.



2280
2281
2282
# File 'lib/google/apis/firestore_v1/classes.rb', line 2280

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#collection_idsArray<String>

IDs of the collection groups to export. Unspecified means all collection groups. Each collection group in this list must be unique. Corresponds to the JSON property collectionIds

Returns:

  • (Array<String>)


2249
2250
2251
# File 'lib/google/apis/firestore_v1/classes.rb', line 2249

def collection_ids
  @collection_ids
end

#namespace_idsArray<String>

An empty list represents all namespaces. This is the preferred usage for databases that don't use namespaces. An empty string element represents the default namespace. This should be used if the database has data in non-default namespaces, but doesn't want to include them. Each namespace in this list must be unique. Corresponds to the JSON property namespaceIds

Returns:

  • (Array<String>)


2258
2259
2260
# File 'lib/google/apis/firestore_v1/classes.rb', line 2258

def namespace_ids
  @namespace_ids
end

#output_uri_prefixString

The output URI. Currently only supports Google Cloud Storage URIs of the form: gs://BUCKET_NAME[/NAMESPACE_PATH], where BUCKET_NAME is the name of the Google Cloud Storage bucket and NAMESPACE_PATH is an optional Google Cloud Storage namespace path. When choosing a name, be sure to consider Google Cloud Storage naming guidelines: https://cloud.google.com/storage/docs/naming. If the URI is a bucket (without a namespace path), a prefix will be generated based on the start time. Corresponds to the JSON property outputUriPrefix

Returns:

  • (String)


2269
2270
2271
# File 'lib/google/apis/firestore_v1/classes.rb', line 2269

def output_uri_prefix
  @output_uri_prefix
end

#snapshot_timeString

The timestamp that corresponds to the version of the database to be exported. The timestamp must be in the past, rounded to the minute and not older than earliestVersionTime. If specified, then the exported documents will represent a consistent view of the database at the provided time. Otherwise, there are no guarantees about the consistency of the exported documents. Corresponds to the JSON property snapshotTime

Returns:

  • (String)


2278
2279
2280
# File 'lib/google/apis/firestore_v1/classes.rb', line 2278

def snapshot_time
  @snapshot_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2285
2286
2287
2288
2289
2290
# File 'lib/google/apis/firestore_v1/classes.rb', line 2285

def update!(**args)
  @collection_ids = args[:collection_ids] if args.key?(:collection_ids)
  @namespace_ids = args[:namespace_ids] if args.key?(:namespace_ids)
  @output_uri_prefix = args[:output_uri_prefix] if args.key?(:output_uri_prefix)
  @snapshot_time = args[:snapshot_time] if args.key?(:snapshot_time)
end