Class: Google::Apis::FirestoreV1::GoogleFirestoreAdminV1FieldOperationMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/firestore_v1/classes.rb,
lib/google/apis/firestore_v1/representations.rb,
lib/google/apis/firestore_v1/representations.rb

Overview

Metadata for google.longrunning.Operation results from FirestoreAdmin. UpdateField.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleFirestoreAdminV1FieldOperationMetadata

Returns a new instance of GoogleFirestoreAdminV1FieldOperationMetadata.



2418
2419
2420
# File 'lib/google/apis/firestore_v1/classes.rb', line 2418

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#end_timeString

The time this operation completed. Will be unset if operation still in progress. Corresponds to the JSON property endTime

Returns:

  • (String)


2377
2378
2379
# File 'lib/google/apis/firestore_v1/classes.rb', line 2377

def end_time
  @end_time
end

#fieldString

The field resource that this operation is acting on. For example: projects/ project_id/databases/database_id/collectionGroups/collection_id/fields/ field_path` Corresponds to the JSON propertyfield`

Returns:

  • (String)


2384
2385
2386
# File 'lib/google/apis/firestore_v1/classes.rb', line 2384

def field
  @field
end

#index_config_deltasArray<Google::Apis::FirestoreV1::GoogleFirestoreAdminV1IndexConfigDelta>

A list of IndexConfigDelta, which describe the intent of this operation. Corresponds to the JSON property indexConfigDeltas



2389
2390
2391
# File 'lib/google/apis/firestore_v1/classes.rb', line 2389

def index_config_deltas
  @index_config_deltas
end

#progress_bytesGoogle::Apis::FirestoreV1::GoogleFirestoreAdminV1Progress

Describes the progress of the operation. Unit of work is generic and must be interpreted based on where Progress is used. Corresponds to the JSON property progressBytes



2395
2396
2397
# File 'lib/google/apis/firestore_v1/classes.rb', line 2395

def progress_bytes
  @progress_bytes
end

#progress_documentsGoogle::Apis::FirestoreV1::GoogleFirestoreAdminV1Progress

Describes the progress of the operation. Unit of work is generic and must be interpreted based on where Progress is used. Corresponds to the JSON property progressDocuments



2401
2402
2403
# File 'lib/google/apis/firestore_v1/classes.rb', line 2401

def progress_documents
  @progress_documents
end

#start_timeString

The time this operation started. Corresponds to the JSON property startTime

Returns:

  • (String)


2406
2407
2408
# File 'lib/google/apis/firestore_v1/classes.rb', line 2406

def start_time
  @start_time
end

#stateString

The state of the operation. Corresponds to the JSON property state

Returns:

  • (String)


2411
2412
2413
# File 'lib/google/apis/firestore_v1/classes.rb', line 2411

def state
  @state
end

#ttl_config_deltaGoogle::Apis::FirestoreV1::GoogleFirestoreAdminV1TtlConfigDelta

Information about a TTL configuration change. Corresponds to the JSON property ttlConfigDelta



2416
2417
2418
# File 'lib/google/apis/firestore_v1/classes.rb', line 2416

def ttl_config_delta
  @ttl_config_delta
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2423
2424
2425
2426
2427
2428
2429
2430
2431
2432
# File 'lib/google/apis/firestore_v1/classes.rb', line 2423

def update!(**args)
  @end_time = args[:end_time] if args.key?(:end_time)
  @field = args[:field] if args.key?(:field)
  @index_config_deltas = args[:index_config_deltas] if args.key?(:index_config_deltas)
  @progress_bytes = args[:progress_bytes] if args.key?(:progress_bytes)
  @progress_documents = args[:progress_documents] if args.key?(:progress_documents)
  @start_time = args[:start_time] if args.key?(:start_time)
  @state = args[:state] if args.key?(:state)
  @ttl_config_delta = args[:ttl_config_delta] if args.key?(:ttl_config_delta)
end