Class: Google::Apis::FirestoreV1::GoogleFirestoreAdminV1IndexConfigDelta

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/firestore_v1/classes.rb,
lib/google/apis/firestore_v1/representations.rb,
lib/google/apis/firestore_v1/representations.rb

Overview

Information about an index configuration change.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleFirestoreAdminV1IndexConfigDelta

Returns a new instance of GoogleFirestoreAdminV1IndexConfigDelta.



2733
2734
2735
# File 'lib/google/apis/firestore_v1/classes.rb', line 2733

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#change_typeString

Specifies how the index is changing. Corresponds to the JSON property changeType

Returns:

  • (String)


2721
2722
2723
# File 'lib/google/apis/firestore_v1/classes.rb', line 2721

def change_type
  @change_type
end

#indexGoogle::Apis::FirestoreV1::GoogleFirestoreAdminV1Index

Cloud Firestore indexes enable simple and complex queries against documents in a database. In Standard edition databases, single-field indexes are managed using the google.firestore.admin.v1.Field resource, and composite indexes are managed using the google.firestore.admin.v1.Index resource. In Enterprise edition databases, both single-field and composite indexes are managed using the google.firestore.admin.v1.Index resource. Corresponds to the JSON property index



2731
2732
2733
# File 'lib/google/apis/firestore_v1/classes.rb', line 2731

def index
  @index
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2738
2739
2740
2741
# File 'lib/google/apis/firestore_v1/classes.rb', line 2738

def update!(**args)
  @change_type = args[:change_type] if args.key?(:change_type)
  @index = args[:index] if args.key?(:index)
end