Class: Google::Apis::FirestoreV1::GoogleFirestoreAdminV1IndexField

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/firestore_v1/classes.rb,
lib/google/apis/firestore_v1/representations.rb,
lib/google/apis/firestore_v1/representations.rb

Overview

A field in an index. The field_path describes which field is indexed, the value_mode describes how the field value is indexed.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleFirestoreAdminV1IndexField

Returns a new instance of GoogleFirestoreAdminV1IndexField.



2776
2777
2778
# File 'lib/google/apis/firestore_v1/classes.rb', line 2776

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#array_configString

Indicates that this field supports operations on array_values. Corresponds to the JSON property arrayConfig

Returns:

  • (String)


2752
2753
2754
# File 'lib/google/apis/firestore_v1/classes.rb', line 2752

def array_config
  @array_config
end

#field_pathString

Can be name. For single field indexes, this must match the name of the field or may be omitted. Corresponds to the JSON property fieldPath

Returns:

  • (String)


2758
2759
2760
# File 'lib/google/apis/firestore_v1/classes.rb', line 2758

def field_path
  @field_path
end

#orderString

Indicates that this field supports ordering by the specified order or comparing using =, !=, <, <=, >, >=. Corresponds to the JSON property order

Returns:

  • (String)


2764
2765
2766
# File 'lib/google/apis/firestore_v1/classes.rb', line 2764

def order
  @order
end

#search_configGoogle::Apis::FirestoreV1::GoogleFirestoreAdminV1SearchConfig

The configuration for how to index a field for search. Corresponds to the JSON property searchConfig



2769
2770
2771
# File 'lib/google/apis/firestore_v1/classes.rb', line 2769

def search_config
  @search_config
end

#vector_configGoogle::Apis::FirestoreV1::GoogleFirestoreAdminV1VectorConfig

The index configuration to support vector search operations Corresponds to the JSON property vectorConfig



2774
2775
2776
# File 'lib/google/apis/firestore_v1/classes.rb', line 2774

def vector_config
  @vector_config
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2781
2782
2783
2784
2785
2786
2787
# File 'lib/google/apis/firestore_v1/classes.rb', line 2781

def update!(**args)
  @array_config = args[:array_config] if args.key?(:array_config)
  @field_path = args[:field_path] if args.key?(:field_path)
  @order = args[:order] if args.key?(:order)
  @search_config = args[:search_config] if args.key?(:search_config)
  @vector_config = args[:vector_config] if args.key?(:vector_config)
end