Class: Google::Apis::FirestoreV1::GoogleFirestoreAdminV1ListDatabasesResponse
- Inherits:
-
Object
- Object
- Google::Apis::FirestoreV1::GoogleFirestoreAdminV1ListDatabasesResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/firestore_v1/classes.rb,
lib/google/apis/firestore_v1/representations.rb,
lib/google/apis/firestore_v1/representations.rb
Overview
The list of databases for a project.
Instance Attribute Summary collapse
-
#databases ⇒ Array<Google::Apis::FirestoreV1::GoogleFirestoreAdminV1Database>
The databases in the project.
-
#unreachable ⇒ Array<String>
In the event that data about individual databases cannot be listed they will be recorded here.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleFirestoreAdminV1ListDatabasesResponse
constructor
A new instance of GoogleFirestoreAdminV1ListDatabasesResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleFirestoreAdminV1ListDatabasesResponse
Returns a new instance of GoogleFirestoreAdminV1ListDatabasesResponse.
2932 2933 2934 |
# File 'lib/google/apis/firestore_v1/classes.rb', line 2932 def initialize(**args) update!(**args) end |
Instance Attribute Details
#databases ⇒ Array<Google::Apis::FirestoreV1::GoogleFirestoreAdminV1Database>
The databases in the project.
Corresponds to the JSON property databases
2919 2920 2921 |
# File 'lib/google/apis/firestore_v1/classes.rb', line 2919 def databases @databases end |
#unreachable ⇒ Array<String>
In the event that data about individual databases cannot be listed they will
be recorded here. An example entry might be: projects/some_project/locations/
some_location This can happen if the Cloud Region that the Database resides in
is currently unavailable. In this case we can't fetch all the details about
the database. You may be able to get a more detailed error message (or
possibly fetch the resource) by sending a 'Get' request for the resource or a '
List' request for the specific location.
Corresponds to the JSON property unreachable
2930 2931 2932 |
# File 'lib/google/apis/firestore_v1/classes.rb', line 2930 def unreachable @unreachable end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2937 2938 2939 2940 |
# File 'lib/google/apis/firestore_v1/classes.rb', line 2937 def update!(**args) @databases = args[:databases] if args.key?(:databases) @unreachable = args[:unreachable] if args.key?(:unreachable) end |