Class: Google::Apis::FirestoreV1::GoogleFirestoreAdminV1RestoreDatabaseMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/firestore_v1/classes.rb,
lib/google/apis/firestore_v1/representations.rb,
lib/google/apis/firestore_v1/representations.rb

Overview

Metadata for the long-running operation from the RestoreDatabase request.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleFirestoreAdminV1RestoreDatabaseMetadata

Returns a new instance of GoogleFirestoreAdminV1RestoreDatabaseMetadata.



3158
3159
3160
# File 'lib/google/apis/firestore_v1/classes.rb', line 3158

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#backupString

The name of the backup restoring from. Corresponds to the JSON property backup

Returns:

  • (String)


3130
3131
3132
# File 'lib/google/apis/firestore_v1/classes.rb', line 3130

def backup
  @backup
end

#databaseString

The name of the database being restored to. Corresponds to the JSON property database

Returns:

  • (String)


3135
3136
3137
# File 'lib/google/apis/firestore_v1/classes.rb', line 3135

def database
  @database
end

#end_timeString

The time the restore finished, unset for ongoing restores. Corresponds to the JSON property endTime

Returns:

  • (String)


3140
3141
3142
# File 'lib/google/apis/firestore_v1/classes.rb', line 3140

def end_time
  @end_time
end

#operation_stateString

The operation state of the restore. Corresponds to the JSON property operationState

Returns:

  • (String)


3145
3146
3147
# File 'lib/google/apis/firestore_v1/classes.rb', line 3145

def operation_state
  @operation_state
end

#progress_percentageGoogle::Apis::FirestoreV1::GoogleFirestoreAdminV1Progress

Describes the progress of the operation. Unit of work is generic and must be interpreted based on where Progress is used. Corresponds to the JSON property progressPercentage



3151
3152
3153
# File 'lib/google/apis/firestore_v1/classes.rb', line 3151

def progress_percentage
  @progress_percentage
end

#start_timeString

The time the restore was started. Corresponds to the JSON property startTime

Returns:

  • (String)


3156
3157
3158
# File 'lib/google/apis/firestore_v1/classes.rb', line 3156

def start_time
  @start_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3163
3164
3165
3166
3167
3168
3169
3170
# File 'lib/google/apis/firestore_v1/classes.rb', line 3163

def update!(**args)
  @backup = args[:backup] if args.key?(:backup)
  @database = args[:database] if args.key?(:database)
  @end_time = args[:end_time] if args.key?(:end_time)
  @operation_state = args[:operation_state] if args.key?(:operation_state)
  @progress_percentage = args[:progress_percentage] if args.key?(:progress_percentage)
  @start_time = args[:start_time] if args.key?(:start_time)
end