Class: Google::Apis::FirestoreV1::GoogleFirestoreAdminV1SearchConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/firestore_v1/classes.rb,
lib/google/apis/firestore_v1/representations.rb,
lib/google/apis/firestore_v1/representations.rb

Overview

The configuration for how to index a field for search.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleFirestoreAdminV1SearchConfig

Returns a new instance of GoogleFirestoreAdminV1SearchConfig.



3058
3059
3060
# File 'lib/google/apis/firestore_v1/classes.rb', line 3058

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#geo_specGoogle::Apis::FirestoreV1::GoogleFirestoreAdminV1SearchGeoSpec

The specification for how to build a geo search index for a field. Corresponds to the JSON property geoSpec



3051
3052
3053
# File 'lib/google/apis/firestore_v1/classes.rb', line 3051

def geo_spec
  @geo_spec
end

#text_specGoogle::Apis::FirestoreV1::GoogleFirestoreAdminV1SearchTextSpec

The specification for how to build a text search index for a field. Corresponds to the JSON property textSpec



3056
3057
3058
# File 'lib/google/apis/firestore_v1/classes.rb', line 3056

def text_spec
  @text_spec
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3063
3064
3065
3066
# File 'lib/google/apis/firestore_v1/classes.rb', line 3063

def update!(**args)
  @geo_spec = args[:geo_spec] if args.key?(:geo_spec)
  @text_spec = args[:text_spec] if args.key?(:text_spec)
end