Class: Google::Apis::FirestoreV1::GoogleFirestoreAdminV1SearchIndexOptions

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/firestore_v1/classes.rb,
lib/google/apis/firestore_v1/representations.rb,
lib/google/apis/firestore_v1/representations.rb

Overview

Options for search indexes at the definition level.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleFirestoreAdminV1SearchIndexOptions

Returns a new instance of GoogleFirestoreAdminV1SearchIndexOptions.



3112
3113
3114
# File 'lib/google/apis/firestore_v1/classes.rb', line 3112

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#text_languageString

Optional. The language to use for text search indexes. Used as the default language if not overridden at the document level by specifying the text_language_override_field. The language is specified as a BCP 47 language code. For indexes with MONGODB_COMPATIBLE_API ApiScope: If unspecified, the default language is English. For indexes with ANY_API ApiScope: If unspecified, the default behavior is autodetect. Corresponds to the JSON property textLanguage

Returns:

  • (String)


3102
3103
3104
# File 'lib/google/apis/firestore_v1/classes.rb', line 3102

def text_language
  @text_language
end

#text_language_override_field_pathString

Optional. The field in the document that specifies which language to use for that specific document. For indexes with MONGODB_COMPATIBLE_API ApiScope: if unspecified, the language is taken from the "language" field if it exists or from text_language if it does not. Corresponds to the JSON property textLanguageOverrideFieldPath

Returns:

  • (String)


3110
3111
3112
# File 'lib/google/apis/firestore_v1/classes.rb', line 3110

def text_language_override_field_path
  @text_language_override_field_path
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3117
3118
3119
3120
# File 'lib/google/apis/firestore_v1/classes.rb', line 3117

def update!(**args)
  @text_language = args[:text_language] if args.key?(:text_language)
  @text_language_override_field_path = args[:text_language_override_field_path] if args.key?(:text_language_override_field_path)
end