Class: Google::Apis::FirestoreV1::GoogleFirestoreAdminV1SearchTextSpec

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/firestore_v1/classes.rb,
lib/google/apis/firestore_v1/representations.rb,
lib/google/apis/firestore_v1/representations.rb

Overview

The specification for how to build a text search index for a field.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleFirestoreAdminV1SearchTextSpec

Returns a new instance of GoogleFirestoreAdminV1SearchTextSpec.



3172
3173
3174
# File 'lib/google/apis/firestore_v1/classes.rb', line 3172

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#index_specsArray<Google::Apis::FirestoreV1::GoogleFirestoreAdminV1SearchTextIndexSpec>

Required. Specifications for how the field should be indexed. Repeated so that the field can be indexed in multiple ways. Corresponds to the JSON property indexSpecs



3170
3171
3172
# File 'lib/google/apis/firestore_v1/classes.rb', line 3170

def index_specs
  @index_specs
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3177
3178
3179
# File 'lib/google/apis/firestore_v1/classes.rb', line 3177

def update!(**args)
  @index_specs = args[:index_specs] if args.key?(:index_specs)
end