Class: Google::Apis::FirestoreV1::GoogleFirestoreAdminV1SourceInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/firestore_v1/classes.rb,
lib/google/apis/firestore_v1/representations.rb,
lib/google/apis/firestore_v1/representations.rb

Overview

Information about the provenance of this database.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleFirestoreAdminV1SourceInfo

Returns a new instance of GoogleFirestoreAdminV1SourceInfo.



3197
3198
3199
# File 'lib/google/apis/firestore_v1/classes.rb', line 3197

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#backupGoogle::Apis::FirestoreV1::GoogleFirestoreAdminV1BackupSource

Information about a backup that was used to restore a database. Corresponds to the JSON property backup



3188
3189
3190
# File 'lib/google/apis/firestore_v1/classes.rb', line 3188

def backup
  @backup
end

#operationString

The associated long-running operation. This field may not be set after the operation has completed. Format: projects/project/databases/database/ operations/operation`. Corresponds to the JSON propertyoperation`

Returns:

  • (String)


3195
3196
3197
# File 'lib/google/apis/firestore_v1/classes.rb', line 3195

def operation
  @operation
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3202
3203
3204
3205
# File 'lib/google/apis/firestore_v1/classes.rb', line 3202

def update!(**args)
  @backup = args[:backup] if args.key?(:backup)
  @operation = args[:operation] if args.key?(:operation)
end