Class: Google::Apis::FirestoreV1::GoogleFirestoreAdminV1TtlConfigDelta
- Inherits:
-
Object
- Object
- Google::Apis::FirestoreV1::GoogleFirestoreAdminV1TtlConfigDelta
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/firestore_v1/classes.rb,
lib/google/apis/firestore_v1/representations.rb,
lib/google/apis/firestore_v1/representations.rb
Overview
Information about a TTL configuration change.
Instance Attribute Summary collapse
-
#change_type ⇒ String
Specifies how the TTL configuration is changing.
-
#expiration_offset ⇒ String
The offset, relative to the timestamp value in the TTL-enabled field, used determine the document's expiration time.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleFirestoreAdminV1TtlConfigDelta
constructor
A new instance of GoogleFirestoreAdminV1TtlConfigDelta.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleFirestoreAdminV1TtlConfigDelta
Returns a new instance of GoogleFirestoreAdminV1TtlConfigDelta.
3296 3297 3298 |
# File 'lib/google/apis/firestore_v1/classes.rb', line 3296 def initialize(**args) update!(**args) end |
Instance Attribute Details
#change_type ⇒ String
Specifies how the TTL configuration is changing.
Corresponds to the JSON property changeType
3288 3289 3290 |
# File 'lib/google/apis/firestore_v1/classes.rb', line 3288 def change_type @change_type end |
#expiration_offset ⇒ String
The offset, relative to the timestamp value in the TTL-enabled field, used
determine the document's expiration time.
Corresponds to the JSON property expirationOffset
3294 3295 3296 |
# File 'lib/google/apis/firestore_v1/classes.rb', line 3294 def expiration_offset @expiration_offset end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3301 3302 3303 3304 |
# File 'lib/google/apis/firestore_v1/classes.rb', line 3301 def update!(**args) @change_type = args[:change_type] if args.key?(:change_type) @expiration_offset = args[:expiration_offset] if args.key?(:expiration_offset) end |