Class: Google::Apis::FirestoreV1::GoogleLongrunningListOperationsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/firestore_v1/classes.rb,
lib/google/apis/firestore_v1/representations.rb,
lib/google/apis/firestore_v1/representations.rb

Overview

The response message for Operations.ListOperations.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleLongrunningListOperationsResponse

Returns a new instance of GoogleLongrunningListOperationsResponse.



3295
3296
3297
# File 'lib/google/apis/firestore_v1/classes.rb', line 3295

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#next_page_tokenString

The standard List next-page token. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


3280
3281
3282
# File 'lib/google/apis/firestore_v1/classes.rb', line 3280

def next_page_token
  @next_page_token
end

#operationsArray<Google::Apis::FirestoreV1::GoogleLongrunningOperation>

A list of operations that matches the specified filter in the request. Corresponds to the JSON property operations



3285
3286
3287
# File 'lib/google/apis/firestore_v1/classes.rb', line 3285

def operations
  @operations
end

#unreachableArray<String>

Unordered list. Unreachable resources. Populated when the request sets ListOperationsRequest.return_partial_success and reads across collections. For example, when attempting to list all resources across all supported locations. Corresponds to the JSON property unreachable

Returns:

  • (Array<String>)


3293
3294
3295
# File 'lib/google/apis/firestore_v1/classes.rb', line 3293

def unreachable
  @unreachable
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3300
3301
3302
3303
3304
# File 'lib/google/apis/firestore_v1/classes.rb', line 3300

def update!(**args)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @operations = args[:operations] if args.key?(:operations)
  @unreachable = args[:unreachable] if args.key?(:unreachable)
end