Class: Google::Apis::FirestoreV1::LatLng

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/firestore_v1/classes.rb,
lib/google/apis/firestore_v1/representations.rb,
lib/google/apis/firestore_v1/representations.rb

Overview

An object that represents a latitude/longitude pair. This is expressed as a pair of doubles to represent degrees latitude and degrees longitude. Unless specified otherwise, this object must conform to the WGS84 standard. Values must be within normalized ranges.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ LatLng

Returns a new instance of LatLng.



3738
3739
3740
# File 'lib/google/apis/firestore_v1/classes.rb', line 3738

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#latitudeFloat

The latitude in degrees. It must be in the range [-90.0, +90.0]. Corresponds to the JSON property latitude

Returns:

  • (Float)


3731
3732
3733
# File 'lib/google/apis/firestore_v1/classes.rb', line 3731

def latitude
  @latitude
end

#longitudeFloat

The longitude in degrees. It must be in the range [-180.0, +180.0]. Corresponds to the JSON property longitude

Returns:

  • (Float)


3736
3737
3738
# File 'lib/google/apis/firestore_v1/classes.rb', line 3736

def longitude
  @longitude
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3743
3744
3745
3746
# File 'lib/google/apis/firestore_v1/classes.rb', line 3743

def update!(**args)
  @latitude = args[:latitude] if args.key?(:latitude)
  @longitude = args[:longitude] if args.key?(:longitude)
end