Class: Google::Apis::FirestoreV1::Precondition
- Inherits:
-
Object
- Object
- Google::Apis::FirestoreV1::Precondition
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/firestore_v1/classes.rb,
lib/google/apis/firestore_v1/representations.rb,
lib/google/apis/firestore_v1/representations.rb
Overview
A precondition on a document, used for conditional operations.
Instance Attribute Summary collapse
-
#exists ⇒ Boolean
(also: #exists?)
When set to
true, the target document must exist. -
#update_time ⇒ String
When set, the target document must exist and have been last updated at that time.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Precondition
constructor
A new instance of Precondition.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Precondition
Returns a new instance of Precondition.
4010 4011 4012 |
# File 'lib/google/apis/firestore_v1/classes.rb', line 4010 def initialize(**args) update!(**args) end |
Instance Attribute Details
#exists ⇒ Boolean Also known as: exists?
When set to true, the target document must exist. When set to false, the
target document must not exist.
Corresponds to the JSON property exists
4001 4002 4003 |
# File 'lib/google/apis/firestore_v1/classes.rb', line 4001 def exists @exists end |
#update_time ⇒ String
When set, the target document must exist and have been last updated at that
time. Timestamp must be microsecond aligned.
Corresponds to the JSON property updateTime
4008 4009 4010 |
# File 'lib/google/apis/firestore_v1/classes.rb', line 4008 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4015 4016 4017 4018 |
# File 'lib/google/apis/firestore_v1/classes.rb', line 4015 def update!(**args) @exists = args[:exists] if args.key?(:exists) @update_time = args[:update_time] if args.key?(:update_time) end |