Class: Google::Apis::FirestoreV1::RunQueryResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/firestore_v1/classes.rb,
lib/google/apis/firestore_v1/representations.rb,
lib/google/apis/firestore_v1/representations.rb

Overview

The response for Firestore.RunQuery.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RunQueryResponse

Returns a new instance of RunQueryResponse.



4151
4152
4153
# File 'lib/google/apis/firestore_v1/classes.rb', line 4151

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#documentGoogle::Apis::FirestoreV1::Document

A Firestore document. Must not exceed 1 MiB - 4 bytes. Corresponds to the JSON property document



4114
4115
4116
# File 'lib/google/apis/firestore_v1/classes.rb', line 4114

def document
  @document
end

#doneBoolean Also known as: done?

If present, Firestore has completely finished the request and no more documents will be returned. Corresponds to the JSON property done

Returns:

  • (Boolean)


4120
4121
4122
# File 'lib/google/apis/firestore_v1/classes.rb', line 4120

def done
  @done
end

#explain_metricsGoogle::Apis::FirestoreV1::ExplainMetrics

Explain metrics for the query. Corresponds to the JSON property explainMetrics



4126
4127
4128
# File 'lib/google/apis/firestore_v1/classes.rb', line 4126

def explain_metrics
  @explain_metrics
end

#read_timeString

The time at which the document was read. This may be monotonically increasing; in this case, the previous documents in the result stream are guaranteed not to have changed between their read_time and this one. If the query returns no results, a response with read_time and no document will be sent, and this represents the time at which the query was run. Corresponds to the JSON property readTime

Returns:

  • (String)


4135
4136
4137
# File 'lib/google/apis/firestore_v1/classes.rb', line 4135

def read_time
  @read_time
end

#skipped_resultsFixnum

The number of results that have been skipped due to an offset between the last response and the current response. Corresponds to the JSON property skippedResults

Returns:

  • (Fixnum)


4141
4142
4143
# File 'lib/google/apis/firestore_v1/classes.rb', line 4141

def skipped_results
  @skipped_results
end

#transactionString

The transaction that was started as part of this request. Can only be set in the first response, and only if RunQueryRequest.new_transaction was set in the request. If set, no other fields will be set in this response. Corresponds to the JSON property transaction NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


4149
4150
4151
# File 'lib/google/apis/firestore_v1/classes.rb', line 4149

def transaction
  @transaction
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4156
4157
4158
4159
4160
4161
4162
4163
# File 'lib/google/apis/firestore_v1/classes.rb', line 4156

def update!(**args)
  @document = args[:document] if args.key?(:document)
  @done = args[:done] if args.key?(:done)
  @explain_metrics = args[:explain_metrics] if args.key?(:explain_metrics)
  @read_time = args[:read_time] if args.key?(:read_time)
  @skipped_results = args[:skipped_results] if args.key?(:skipped_results)
  @transaction = args[:transaction] if args.key?(:transaction)
end