Class: Google::Apis::FirestoreV1::StructuredPipeline

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/firestore_v1/classes.rb,
lib/google/apis/firestore_v1/representations.rb,
lib/google/apis/firestore_v1/representations.rb

Overview

A Firestore query represented as an ordered list of operations / stages. This is considered the top-level function which plans and executes a query. It is logically equivalent to query(stages, options), but prevents the client from having to build a function wrapper.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ StructuredPipeline

Returns a new instance of StructuredPipeline.



4703
4704
4705
# File 'lib/google/apis/firestore_v1/classes.rb', line 4703

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#optionsHash<String,Google::Apis::FirestoreV1::Value>

Optional. Optional query-level arguments. Corresponds to the JSON property options

Returns:



4696
4697
4698
# File 'lib/google/apis/firestore_v1/classes.rb', line 4696

def options
  @options
end

#pipelineGoogle::Apis::FirestoreV1::Pipeline

A Firestore query represented as an ordered list of operations / stages. Corresponds to the JSON property pipeline



4701
4702
4703
# File 'lib/google/apis/firestore_v1/classes.rb', line 4701

def pipeline
  @pipeline
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4708
4709
4710
4711
# File 'lib/google/apis/firestore_v1/classes.rb', line 4708

def update!(**args)
  @options = args[:options] if args.key?(:options)
  @pipeline = args[:pipeline] if args.key?(:pipeline)
end