Class: Google::Apis::FirestoreV1::Sum
- Inherits:
-
Object
- Object
- Google::Apis::FirestoreV1::Sum
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/firestore_v1/classes.rb,
lib/google/apis/firestore_v1/representations.rb,
lib/google/apis/firestore_v1/representations.rb
Overview
Sum of the values of the requested field. * Only numeric values will be
aggregated. All non-numeric values including NULL are skipped. * If the
aggregated values contain NaN, returns NaN. Infinity math follows IEEE-754
standards. * If the aggregated value set is empty, returns 0. * Returns a 64-
bit integer if all aggregated numbers are integers and the sum result does not
overflow. Otherwise, the result is returned as a double. Note that even if all
the aggregated values are integers, the result is returned as a double if it
cannot fit within a 64-bit signed integer. When this occurs, the returned
value will lose precision. * When underflow occurs, floating-point aggregation
is non-deterministic. This means that running the same query repeatedly
without any changes to the underlying values could produce slightly different
results each time. In those cases, values should be stored as integers over
floating-point numbers.
Instance Attribute Summary collapse
-
#field ⇒ Google::Apis::FirestoreV1::FieldReference
A reference to a field in a document, ex:
stats.operations.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Sum
constructor
A new instance of Sum.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Sum
Returns a new instance of Sum.
4582 4583 4584 |
# File 'lib/google/apis/firestore_v1/classes.rb', line 4582 def initialize(**args) update!(**args) end |
Instance Attribute Details
#field ⇒ Google::Apis::FirestoreV1::FieldReference
A reference to a field in a document, ex: stats.operations.
Corresponds to the JSON property field
4580 4581 4582 |
# File 'lib/google/apis/firestore_v1/classes.rb', line 4580 def field @field end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4587 4588 4589 |
# File 'lib/google/apis/firestore_v1/classes.rb', line 4587 def update!(**args) @field = args[:field] if args.key?(:field) end |