Class: Google::Apis::FirestoreV1::Target

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/firestore_v1/classes.rb,
lib/google/apis/firestore_v1/representations.rb,
lib/google/apis/firestore_v1/representations.rb

Overview

A specification of a set of documents to listen to.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Target

Returns a new instance of Target.



4658
4659
4660
# File 'lib/google/apis/firestore_v1/classes.rb', line 4658

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#documentsGoogle::Apis::FirestoreV1::DocumentsTarget

A target specified by a set of documents names. Corresponds to the JSON property documents



4608
4609
4610
# File 'lib/google/apis/firestore_v1/classes.rb', line 4608

def documents
  @documents
end

#expected_countFixnum

The number of documents that last matched the query at the resume token or read time. This value is only relevant when a resume_type is provided. This value being present and greater than zero signals that the client wants ExistenceFilter.unchanged_names to be included in the response. Corresponds to the JSON property expectedCount

Returns:

  • (Fixnum)


4616
4617
4618
# File 'lib/google/apis/firestore_v1/classes.rb', line 4616

def expected_count
  @expected_count
end

#onceBoolean Also known as: once?

If the target should be removed once it is current and consistent. Corresponds to the JSON property once

Returns:

  • (Boolean)


4621
4622
4623
# File 'lib/google/apis/firestore_v1/classes.rb', line 4621

def once
  @once
end

#queryGoogle::Apis::FirestoreV1::QueryTarget

A target specified by a query. Corresponds to the JSON property query



4627
4628
4629
# File 'lib/google/apis/firestore_v1/classes.rb', line 4627

def query
  @query
end

#read_timeString

Start listening after a specific read_time. The client must know the state of matching documents at this time. Corresponds to the JSON property readTime

Returns:

  • (String)


4633
4634
4635
# File 'lib/google/apis/firestore_v1/classes.rb', line 4633

def read_time
  @read_time
end

#resume_tokenString

A resume token from a prior TargetChange for an identical target. Using a resume token with a different target is unsupported and may fail. Corresponds to the JSON property resumeToken NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


4640
4641
4642
# File 'lib/google/apis/firestore_v1/classes.rb', line 4640

def resume_token
  @resume_token
end

#target_idFixnum

The target ID that identifies the target on the stream. Must be a positive number and non-zero. If target_id is 0 (or unspecified), the server will assign an ID for this target and return that in a TargetChange::ADD event. Once a target with target_id=0 is added, all subsequent targets must also have target_id=0. If an AddTarget request with target_id != 0 is sent to the server after a target with target_id=0 is added, the server will immediately send a response with a TargetChange::Remove event. Note that if the client sends multiple AddTarget requests without an ID, the order of IDs returned in TargetChange.target_ids are undefined. Therefore, clients should provide a target ID instead of relying on the server to assign one. If target_id is non-zero, there must not be an existing active target on this stream with the same ID. Corresponds to the JSON property targetId

Returns:

  • (Fixnum)


4656
4657
4658
# File 'lib/google/apis/firestore_v1/classes.rb', line 4656

def target_id
  @target_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4663
4664
4665
4666
4667
4668
4669
4670
4671
# File 'lib/google/apis/firestore_v1/classes.rb', line 4663

def update!(**args)
  @documents = args[:documents] if args.key?(:documents)
  @expected_count = args[:expected_count] if args.key?(:expected_count)
  @once = args[:once] if args.key?(:once)
  @query = args[:query] if args.key?(:query)
  @read_time = args[:read_time] if args.key?(:read_time)
  @resume_token = args[:resume_token] if args.key?(:resume_token)
  @target_id = args[:target_id] if args.key?(:target_id)
end