Class: Google::Apis::FirestoreV1::WriteResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/firestore_v1/classes.rb,
lib/google/apis/firestore_v1/representations.rb,
lib/google/apis/firestore_v1/representations.rb

Overview

The response for Firestore.Write.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ WriteResponse

Returns a new instance of WriteResponse.



5029
5030
5031
# File 'lib/google/apis/firestore_v1/classes.rb', line 5029

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#commit_timeString

The time at which the commit occurred. Any read with an equal or greater read_time is guaranteed to see the effects of the write. Corresponds to the JSON property commitTime

Returns:

  • (String)


5007
5008
5009
# File 'lib/google/apis/firestore_v1/classes.rb', line 5007

def commit_time
  @commit_time
end

#stream_idString

The ID of the stream. Only set on the first message, when a new stream was created. Corresponds to the JSON property streamId

Returns:

  • (String)


5013
5014
5015
# File 'lib/google/apis/firestore_v1/classes.rb', line 5013

def stream_id
  @stream_id
end

#stream_tokenString

A token that represents the position of this response in the stream. This can be used by a client to resume the stream at this point. This field is always set. Corresponds to the JSON property streamToken NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


5021
5022
5023
# File 'lib/google/apis/firestore_v1/classes.rb', line 5021

def stream_token
  @stream_token
end

#write_resultsArray<Google::Apis::FirestoreV1::WriteResult>

The result of applying the writes. This i-th write result corresponds to the i- th write in the request. Corresponds to the JSON property writeResults



5027
5028
5029
# File 'lib/google/apis/firestore_v1/classes.rb', line 5027

def write_results
  @write_results
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5034
5035
5036
5037
5038
5039
# File 'lib/google/apis/firestore_v1/classes.rb', line 5034

def update!(**args)
  @commit_time = args[:commit_time] if args.key?(:commit_time)
  @stream_id = args[:stream_id] if args.key?(:stream_id)
  @stream_token = args[:stream_token] if args.key?(:stream_token)
  @write_results = args[:write_results] if args.key?(:write_results)
end