Class: Google::Apis::FirestoreV1::ExecutePipelineRequest
- Inherits:
-
Object
- Object
- Google::Apis::FirestoreV1::ExecutePipelineRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/firestore_v1/classes.rb,
lib/google/apis/firestore_v1/representations.rb,
lib/google/apis/firestore_v1/representations.rb
Overview
The request for Firestore.ExecutePipeline.
Instance Attribute Summary collapse
-
#auto_commit_transaction ⇒ Boolean
(also: #auto_commit_transaction?)
Optional.
-
#new_transaction ⇒ Google::Apis::FirestoreV1::TransactionOptions
Options for creating a new transaction.
-
#read_time ⇒ String
Execute the pipeline in a snapshot transaction at the given time.
-
#structured_pipeline ⇒ Google::Apis::FirestoreV1::StructuredPipeline
A Firestore query represented as an ordered list of operations / stages.
-
#transaction ⇒ String
Run the query within an already active transaction.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ExecutePipelineRequest
constructor
A new instance of ExecutePipelineRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ExecutePipelineRequest
Returns a new instance of ExecutePipelineRequest.
869 870 871 |
# File 'lib/google/apis/firestore_v1/classes.rb', line 869 def initialize(**args) update!(**args) end |
Instance Attribute Details
#auto_commit_transaction ⇒ Boolean Also known as: auto_commit_transaction?
Optional. Automatically commits the transaction after the pipeline has been
executed. Only permitted in combination with transaction or new_transaction
.
Corresponds to the JSON property autoCommitTransaction
838 839 840 |
# File 'lib/google/apis/firestore_v1/classes.rb', line 838 def auto_commit_transaction @auto_commit_transaction end |
#new_transaction ⇒ Google::Apis::FirestoreV1::TransactionOptions
Options for creating a new transaction.
Corresponds to the JSON property newTransaction
844 845 846 |
# File 'lib/google/apis/firestore_v1/classes.rb', line 844 def new_transaction @new_transaction end |
#read_time ⇒ String
Execute the pipeline in a snapshot transaction at the given time. This must be
a microsecond precision timestamp within the past one hour, or if Point-in-
Time Recovery is enabled, can additionally be a whole minute timestamp within
the past 7 days.
Corresponds to the JSON property readTime
852 853 854 |
# File 'lib/google/apis/firestore_v1/classes.rb', line 852 def read_time @read_time end |
#structured_pipeline ⇒ Google::Apis::FirestoreV1::StructuredPipeline
A Firestore query represented as an ordered list of operations / stages. This
is considered the top-level function which plans and executes a query. It is
logically equivalent to query(stages, options), but prevents the client from
having to build a function wrapper.
Corresponds to the JSON property structuredPipeline
860 861 862 |
# File 'lib/google/apis/firestore_v1/classes.rb', line 860 def structured_pipeline @structured_pipeline end |
#transaction ⇒ String
Run the query within an already active transaction. The value here is the
opaque transaction ID to execute the query in.
Corresponds to the JSON property transaction
NOTE: Values are automatically base64 encoded/decoded in the client library.
867 868 869 |
# File 'lib/google/apis/firestore_v1/classes.rb', line 867 def transaction @transaction end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
874 875 876 877 878 879 880 |
# File 'lib/google/apis/firestore_v1/classes.rb', line 874 def update!(**args) @auto_commit_transaction = args[:auto_commit_transaction] if args.key?(:auto_commit_transaction) @new_transaction = args[:new_transaction] if args.key?(:new_transaction) @read_time = args[:read_time] if args.key?(:read_time) @structured_pipeline = args[:structured_pipeline] if args.key?(:structured_pipeline) @transaction = args[:transaction] if args.key?(:transaction) end |