Class: Google::Apis::FirestoreV1::GoogleFirestoreAdminV1BackupSchedule
- Inherits:
-
Object
- Object
- Google::Apis::FirestoreV1::GoogleFirestoreAdminV1BackupSchedule
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/firestore_v1/classes.rb,
lib/google/apis/firestore_v1/representations.rb,
lib/google/apis/firestore_v1/representations.rb
Overview
A backup schedule for a Cloud Firestore Database. This resource is owned by the database it is backing up, and is deleted along with the database. The actual backups are not though.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#daily_recurrence ⇒ Google::Apis::FirestoreV1::GoogleFirestoreAdminV1DailyRecurrence
Represents a recurring schedule that runs every day.
-
#name ⇒ String
Output only.
-
#retention ⇒ String
At what relative time in the future, compared to its creation time, the backup should be deleted, e.g.
-
#update_time ⇒ String
Output only.
-
#weekly_recurrence ⇒ Google::Apis::FirestoreV1::GoogleFirestoreAdminV1WeeklyRecurrence
Represents a recurring schedule that runs on a specified day of the week.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleFirestoreAdminV1BackupSchedule
constructor
A new instance of GoogleFirestoreAdminV1BackupSchedule.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleFirestoreAdminV1BackupSchedule
Returns a new instance of GoogleFirestoreAdminV1BackupSchedule.
1429 1430 1431 |
# File 'lib/google/apis/firestore_v1/classes.rb', line 1429 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. The timestamp at which this backup schedule was created and
effective since. No backups will be created for this schedule before this time.
Corresponds to the JSON property createTime
1395 1396 1397 |
# File 'lib/google/apis/firestore_v1/classes.rb', line 1395 def create_time @create_time end |
#daily_recurrence ⇒ Google::Apis::FirestoreV1::GoogleFirestoreAdminV1DailyRecurrence
Represents a recurring schedule that runs every day. The time zone is UTC.
Corresponds to the JSON property dailyRecurrence
1400 1401 1402 |
# File 'lib/google/apis/firestore_v1/classes.rb', line 1400 def daily_recurrence @daily_recurrence end |
#name ⇒ String
Output only. The unique backup schedule identifier across all locations and
databases for the given project. This will be auto-assigned. Format is
projects/project/databases/database/backupSchedules/backup_schedule`
Corresponds to the JSON propertyname`
1407 1408 1409 |
# File 'lib/google/apis/firestore_v1/classes.rb', line 1407 def name @name end |
#retention ⇒ String
At what relative time in the future, compared to its creation time, the backup
should be deleted, e.g. keep backups for 7 days. The maximum supported
retention period is 14 weeks.
Corresponds to the JSON property retention
1414 1415 1416 |
# File 'lib/google/apis/firestore_v1/classes.rb', line 1414 def retention @retention end |
#update_time ⇒ String
Output only. The timestamp at which this backup schedule was most recently
updated. When a backup schedule is first created, this is the same as
create_time.
Corresponds to the JSON property updateTime
1421 1422 1423 |
# File 'lib/google/apis/firestore_v1/classes.rb', line 1421 def update_time @update_time end |
#weekly_recurrence ⇒ Google::Apis::FirestoreV1::GoogleFirestoreAdminV1WeeklyRecurrence
Represents a recurring schedule that runs on a specified day of the week. The
time zone is UTC.
Corresponds to the JSON property weeklyRecurrence
1427 1428 1429 |
# File 'lib/google/apis/firestore_v1/classes.rb', line 1427 def weekly_recurrence @weekly_recurrence end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1434 1435 1436 1437 1438 1439 1440 1441 |
# File 'lib/google/apis/firestore_v1/classes.rb', line 1434 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @daily_recurrence = args[:daily_recurrence] if args.key?(:daily_recurrence) @name = args[:name] if args.key?(:name) @retention = args[:retention] if args.key?(:retention) @update_time = args[:update_time] if args.key?(:update_time) @weekly_recurrence = args[:weekly_recurrence] if args.key?(:weekly_recurrence) end |