Class: Google::Apis::FirestoreV1::GoogleFirestoreAdminV1BackupSchedule
- Inherits:
-
Object
- Object
- Google::Apis::FirestoreV1::GoogleFirestoreAdminV1BackupSchedule
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/firestore_v1/classes.rb,
lib/google/apis/firestore_v1/representations.rb,
lib/google/apis/firestore_v1/representations.rb
Overview
A backup schedule for a Cloud Firestore Database. This resource is owned by the database it is backing up, and is deleted along with the database. The actual backups are not though.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#daily_recurrence ⇒ Google::Apis::FirestoreV1::GoogleFirestoreAdminV1DailyRecurrence
Represents a recurring schedule that runs every day.
-
#name ⇒ String
Output only.
-
#retention ⇒ String
At what relative time in the future, compared to its creation time, the backup should be deleted, e.g.
-
#update_time ⇒ String
Output only.
-
#weekly_recurrence ⇒ Google::Apis::FirestoreV1::GoogleFirestoreAdminV1WeeklyRecurrence
Represents a recurring schedule that runs on a specified day of the week.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleFirestoreAdminV1BackupSchedule
constructor
A new instance of GoogleFirestoreAdminV1BackupSchedule.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleFirestoreAdminV1BackupSchedule
Returns a new instance of GoogleFirestoreAdminV1BackupSchedule.
1420 1421 1422 |
# File 'lib/google/apis/firestore_v1/classes.rb', line 1420 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. The timestamp at which this backup schedule was created and
effective since. No backups will be created for this schedule before this time.
Corresponds to the JSON property createTime
1386 1387 1388 |
# File 'lib/google/apis/firestore_v1/classes.rb', line 1386 def create_time @create_time end |
#daily_recurrence ⇒ Google::Apis::FirestoreV1::GoogleFirestoreAdminV1DailyRecurrence
Represents a recurring schedule that runs every day. The time zone is UTC.
Corresponds to the JSON property dailyRecurrence
1391 1392 1393 |
# File 'lib/google/apis/firestore_v1/classes.rb', line 1391 def daily_recurrence @daily_recurrence end |
#name ⇒ String
Output only. The unique backup schedule identifier across all locations and
databases for the given project. This will be auto-assigned. Format is
projects/project/databases/database/backupSchedules/backup_schedule`
Corresponds to the JSON propertyname`
1398 1399 1400 |
# File 'lib/google/apis/firestore_v1/classes.rb', line 1398 def name @name end |
#retention ⇒ String
At what relative time in the future, compared to its creation time, the backup
should be deleted, e.g. keep backups for 7 days. The maximum supported
retention period is 14 weeks.
Corresponds to the JSON property retention
1405 1406 1407 |
# File 'lib/google/apis/firestore_v1/classes.rb', line 1405 def retention @retention end |
#update_time ⇒ String
Output only. The timestamp at which this backup schedule was most recently
updated. When a backup schedule is first created, this is the same as
create_time.
Corresponds to the JSON property updateTime
1412 1413 1414 |
# File 'lib/google/apis/firestore_v1/classes.rb', line 1412 def update_time @update_time end |
#weekly_recurrence ⇒ Google::Apis::FirestoreV1::GoogleFirestoreAdminV1WeeklyRecurrence
Represents a recurring schedule that runs on a specified day of the week. The
time zone is UTC.
Corresponds to the JSON property weeklyRecurrence
1418 1419 1420 |
# File 'lib/google/apis/firestore_v1/classes.rb', line 1418 def weekly_recurrence @weekly_recurrence end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1425 1426 1427 1428 1429 1430 1431 1432 |
# File 'lib/google/apis/firestore_v1/classes.rb', line 1425 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @daily_recurrence = args[:daily_recurrence] if args.key?(:daily_recurrence) @name = args[:name] if args.key?(:name) @retention = args[:retention] if args.key?(:retention) @update_time = args[:update_time] if args.key?(:update_time) @weekly_recurrence = args[:weekly_recurrence] if args.key?(:weekly_recurrence) end |