Class: Google::Apis::FirestoreV1::GoogleFirestoreAdminV1BulkDeleteDocumentsMetadata
- Inherits:
-
Object
- Object
- Google::Apis::FirestoreV1::GoogleFirestoreAdminV1BulkDeleteDocumentsMetadata
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/firestore_v1/classes.rb,
lib/google/apis/firestore_v1/representations.rb,
lib/google/apis/firestore_v1/representations.rb
Overview
Metadata for google.longrunning.Operation results from FirestoreAdmin. BulkDeleteDocuments.
Instance Attribute Summary collapse
-
#collection_ids ⇒ Array<String>
The IDs of the collection groups that are being deleted.
-
#end_time ⇒ String
The time this operation completed.
-
#namespace_ids ⇒ Array<String>
Which namespace IDs are being deleted.
-
#operation_state ⇒ String
The state of the operation.
-
#progress_bytes ⇒ Google::Apis::FirestoreV1::GoogleFirestoreAdminV1Progress
Describes the progress of the operation.
-
#progress_documents ⇒ Google::Apis::FirestoreV1::GoogleFirestoreAdminV1Progress
Describes the progress of the operation.
-
#snapshot_time ⇒ String
The timestamp that corresponds to the version of the database that is being read to get the list of documents to delete.
-
#start_time ⇒ String
The time this operation started.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleFirestoreAdminV1BulkDeleteDocumentsMetadata
constructor
A new instance of GoogleFirestoreAdminV1BulkDeleteDocumentsMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleFirestoreAdminV1BulkDeleteDocumentsMetadata
Returns a new instance of GoogleFirestoreAdminV1BulkDeleteDocumentsMetadata.
1514 1515 1516 |
# File 'lib/google/apis/firestore_v1/classes.rb', line 1514 def initialize(**args) update!(**args) end |
Instance Attribute Details
#collection_ids ⇒ Array<String>
The IDs of the collection groups that are being deleted.
Corresponds to the JSON property collectionIds
1472 1473 1474 |
# File 'lib/google/apis/firestore_v1/classes.rb', line 1472 def collection_ids @collection_ids end |
#end_time ⇒ String
The time this operation completed. Will be unset if operation still in
progress.
Corresponds to the JSON property endTime
1478 1479 1480 |
# File 'lib/google/apis/firestore_v1/classes.rb', line 1478 def end_time @end_time end |
#namespace_ids ⇒ Array<String>
Which namespace IDs are being deleted.
Corresponds to the JSON property namespaceIds
1483 1484 1485 |
# File 'lib/google/apis/firestore_v1/classes.rb', line 1483 def namespace_ids @namespace_ids end |
#operation_state ⇒ String
The state of the operation.
Corresponds to the JSON property operationState
1488 1489 1490 |
# File 'lib/google/apis/firestore_v1/classes.rb', line 1488 def operation_state @operation_state end |
#progress_bytes ⇒ Google::Apis::FirestoreV1::GoogleFirestoreAdminV1Progress
Describes the progress of the operation. Unit of work is generic and must be
interpreted based on where Progress is used.
Corresponds to the JSON property progressBytes
1494 1495 1496 |
# File 'lib/google/apis/firestore_v1/classes.rb', line 1494 def progress_bytes @progress_bytes end |
#progress_documents ⇒ Google::Apis::FirestoreV1::GoogleFirestoreAdminV1Progress
Describes the progress of the operation. Unit of work is generic and must be
interpreted based on where Progress is used.
Corresponds to the JSON property progressDocuments
1500 1501 1502 |
# File 'lib/google/apis/firestore_v1/classes.rb', line 1500 def progress_documents @progress_documents end |
#snapshot_time ⇒ String
The timestamp that corresponds to the version of the database that is being
read to get the list of documents to delete. This time can also be used as the
timestamp of PITR in case of disaster recovery (subject to PITR window limit).
Corresponds to the JSON property snapshotTime
1507 1508 1509 |
# File 'lib/google/apis/firestore_v1/classes.rb', line 1507 def snapshot_time @snapshot_time end |
#start_time ⇒ String
The time this operation started.
Corresponds to the JSON property startTime
1512 1513 1514 |
# File 'lib/google/apis/firestore_v1/classes.rb', line 1512 def start_time @start_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1519 1520 1521 1522 1523 1524 1525 1526 1527 1528 |
# File 'lib/google/apis/firestore_v1/classes.rb', line 1519 def update!(**args) @collection_ids = args[:collection_ids] if args.key?(:collection_ids) @end_time = args[:end_time] if args.key?(:end_time) @namespace_ids = args[:namespace_ids] if args.key?(:namespace_ids) @operation_state = args[:operation_state] if args.key?(:operation_state) @progress_bytes = args[:progress_bytes] if args.key?(:progress_bytes) @progress_documents = args[:progress_documents] if args.key?(:progress_documents) @snapshot_time = args[:snapshot_time] if args.key?(:snapshot_time) @start_time = args[:start_time] if args.key?(:start_time) end |