Class: Google::Apis::FirestoreV1::GoogleFirestoreAdminV1BulkDeleteDocumentsMetadata
- Inherits:
-
Object
- Object
- Google::Apis::FirestoreV1::GoogleFirestoreAdminV1BulkDeleteDocumentsMetadata
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/firestore_v1/classes.rb,
lib/google/apis/firestore_v1/representations.rb,
lib/google/apis/firestore_v1/representations.rb
Overview
Metadata for google.longrunning.Operation results from FirestoreAdmin. BulkDeleteDocuments.
Instance Attribute Summary collapse
-
#collection_ids ⇒ Array<String>
The IDs of the collection groups that are being deleted.
-
#end_time ⇒ String
The time this operation completed.
-
#namespace_ids ⇒ Array<String>
Which namespace IDs are being deleted.
-
#operation_state ⇒ String
The state of the operation.
-
#progress_bytes ⇒ Google::Apis::FirestoreV1::GoogleFirestoreAdminV1Progress
Describes the progress of the operation.
-
#progress_documents ⇒ Google::Apis::FirestoreV1::GoogleFirestoreAdminV1Progress
Describes the progress of the operation.
-
#snapshot_time ⇒ String
The timestamp that corresponds to the version of the database that is being read to get the list of documents to delete.
-
#start_time ⇒ String
The time this operation started.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleFirestoreAdminV1BulkDeleteDocumentsMetadata
constructor
A new instance of GoogleFirestoreAdminV1BulkDeleteDocumentsMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleFirestoreAdminV1BulkDeleteDocumentsMetadata
Returns a new instance of GoogleFirestoreAdminV1BulkDeleteDocumentsMetadata.
1505 1506 1507 |
# File 'lib/google/apis/firestore_v1/classes.rb', line 1505 def initialize(**args) update!(**args) end |
Instance Attribute Details
#collection_ids ⇒ Array<String>
The IDs of the collection groups that are being deleted.
Corresponds to the JSON property collectionIds
1463 1464 1465 |
# File 'lib/google/apis/firestore_v1/classes.rb', line 1463 def collection_ids @collection_ids end |
#end_time ⇒ String
The time this operation completed. Will be unset if operation still in
progress.
Corresponds to the JSON property endTime
1469 1470 1471 |
# File 'lib/google/apis/firestore_v1/classes.rb', line 1469 def end_time @end_time end |
#namespace_ids ⇒ Array<String>
Which namespace IDs are being deleted.
Corresponds to the JSON property namespaceIds
1474 1475 1476 |
# File 'lib/google/apis/firestore_v1/classes.rb', line 1474 def namespace_ids @namespace_ids end |
#operation_state ⇒ String
The state of the operation.
Corresponds to the JSON property operationState
1479 1480 1481 |
# File 'lib/google/apis/firestore_v1/classes.rb', line 1479 def operation_state @operation_state end |
#progress_bytes ⇒ Google::Apis::FirestoreV1::GoogleFirestoreAdminV1Progress
Describes the progress of the operation. Unit of work is generic and must be
interpreted based on where Progress is used.
Corresponds to the JSON property progressBytes
1485 1486 1487 |
# File 'lib/google/apis/firestore_v1/classes.rb', line 1485 def progress_bytes @progress_bytes end |
#progress_documents ⇒ Google::Apis::FirestoreV1::GoogleFirestoreAdminV1Progress
Describes the progress of the operation. Unit of work is generic and must be
interpreted based on where Progress is used.
Corresponds to the JSON property progressDocuments
1491 1492 1493 |
# File 'lib/google/apis/firestore_v1/classes.rb', line 1491 def progress_documents @progress_documents end |
#snapshot_time ⇒ String
The timestamp that corresponds to the version of the database that is being
read to get the list of documents to delete. This time can also be used as the
timestamp of PITR in case of disaster recovery (subject to PITR window limit).
Corresponds to the JSON property snapshotTime
1498 1499 1500 |
# File 'lib/google/apis/firestore_v1/classes.rb', line 1498 def snapshot_time @snapshot_time end |
#start_time ⇒ String
The time this operation started.
Corresponds to the JSON property startTime
1503 1504 1505 |
# File 'lib/google/apis/firestore_v1/classes.rb', line 1503 def start_time @start_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1510 1511 1512 1513 1514 1515 1516 1517 1518 1519 |
# File 'lib/google/apis/firestore_v1/classes.rb', line 1510 def update!(**args) @collection_ids = args[:collection_ids] if args.key?(:collection_ids) @end_time = args[:end_time] if args.key?(:end_time) @namespace_ids = args[:namespace_ids] if args.key?(:namespace_ids) @operation_state = args[:operation_state] if args.key?(:operation_state) @progress_bytes = args[:progress_bytes] if args.key?(:progress_bytes) @progress_documents = args[:progress_documents] if args.key?(:progress_documents) @snapshot_time = args[:snapshot_time] if args.key?(:snapshot_time) @start_time = args[:start_time] if args.key?(:start_time) end |