Class: Google::Apis::FirestoreV1::GoogleFirestoreAdminV1CloneDatabaseMetadata
- Inherits:
-
Object
- Object
- Google::Apis::FirestoreV1::GoogleFirestoreAdminV1CloneDatabaseMetadata
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/firestore_v1/classes.rb,
lib/google/apis/firestore_v1/representations.rb,
lib/google/apis/firestore_v1/representations.rb
Overview
Metadata for the long-running operation from the CloneDatabase request.
Instance Attribute Summary collapse
-
#database ⇒ String
The name of the database being cloned to.
-
#end_time ⇒ String
The time the clone finished, unset for ongoing clones.
-
#operation_state ⇒ String
The operation state of the clone.
-
#pitr_snapshot ⇒ Google::Apis::FirestoreV1::GoogleFirestoreAdminV1PitrSnapshot
A consistent snapshot of a database at a specific point in time.
-
#progress_percentage ⇒ Google::Apis::FirestoreV1::GoogleFirestoreAdminV1Progress
Describes the progress of the operation.
-
#start_time ⇒ String
The time the clone was started.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleFirestoreAdminV1CloneDatabaseMetadata
constructor
A new instance of GoogleFirestoreAdminV1CloneDatabaseMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleFirestoreAdminV1CloneDatabaseMetadata
Returns a new instance of GoogleFirestoreAdminV1CloneDatabaseMetadata.
1633 1634 1635 |
# File 'lib/google/apis/firestore_v1/classes.rb', line 1633 def initialize(**args) update!(**args) end |
Instance Attribute Details
#database ⇒ String
The name of the database being cloned to.
Corresponds to the JSON property database
1601 1602 1603 |
# File 'lib/google/apis/firestore_v1/classes.rb', line 1601 def database @database end |
#end_time ⇒ String
The time the clone finished, unset for ongoing clones.
Corresponds to the JSON property endTime
1606 1607 1608 |
# File 'lib/google/apis/firestore_v1/classes.rb', line 1606 def end_time @end_time end |
#operation_state ⇒ String
The operation state of the clone.
Corresponds to the JSON property operationState
1611 1612 1613 |
# File 'lib/google/apis/firestore_v1/classes.rb', line 1611 def operation_state @operation_state end |
#pitr_snapshot ⇒ Google::Apis::FirestoreV1::GoogleFirestoreAdminV1PitrSnapshot
A consistent snapshot of a database at a specific point in time. A PITR (Point-
in-time recovery) snapshot with previous versions of a database's data is
available for every minute up to the associated database's data retention
period. If the PITR feature is enabled, the retention period is 7 days;
otherwise, it is one hour.
Corresponds to the JSON property pitrSnapshot
1620 1621 1622 |
# File 'lib/google/apis/firestore_v1/classes.rb', line 1620 def pitr_snapshot @pitr_snapshot end |
#progress_percentage ⇒ Google::Apis::FirestoreV1::GoogleFirestoreAdminV1Progress
Describes the progress of the operation. Unit of work is generic and must be
interpreted based on where Progress is used.
Corresponds to the JSON property progressPercentage
1626 1627 1628 |
# File 'lib/google/apis/firestore_v1/classes.rb', line 1626 def progress_percentage @progress_percentage end |
#start_time ⇒ String
The time the clone was started.
Corresponds to the JSON property startTime
1631 1632 1633 |
# File 'lib/google/apis/firestore_v1/classes.rb', line 1631 def start_time @start_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1638 1639 1640 1641 1642 1643 1644 1645 |
# File 'lib/google/apis/firestore_v1/classes.rb', line 1638 def update!(**args) @database = args[:database] if args.key?(:database) @end_time = args[:end_time] if args.key?(:end_time) @operation_state = args[:operation_state] if args.key?(:operation_state) @pitr_snapshot = args[:pitr_snapshot] if args.key?(:pitr_snapshot) @progress_percentage = args[:progress_percentage] if args.key?(:progress_percentage) @start_time = args[:start_time] if args.key?(:start_time) end |