Class: Google::Apis::FirestoreV1::GoogleFirestoreAdminV1CloneDatabaseMetadata
- Inherits:
-
Object
- Object
- Google::Apis::FirestoreV1::GoogleFirestoreAdminV1CloneDatabaseMetadata
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/firestore_v1/classes.rb,
lib/google/apis/firestore_v1/representations.rb,
lib/google/apis/firestore_v1/representations.rb
Overview
Metadata for the long-running operation from the CloneDatabase request.
Instance Attribute Summary collapse
-
#database ⇒ String
The name of the database being cloned to.
-
#end_time ⇒ String
The time the clone finished, unset for ongoing clones.
-
#operation_state ⇒ String
The operation state of the clone.
-
#pitr_snapshot ⇒ Google::Apis::FirestoreV1::GoogleFirestoreAdminV1PitrSnapshot
A consistent snapshot of a database at a specific point in time.
-
#progress_percentage ⇒ Google::Apis::FirestoreV1::GoogleFirestoreAdminV1Progress
Describes the progress of the operation.
-
#start_time ⇒ String
The time the clone was started.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleFirestoreAdminV1CloneDatabaseMetadata
constructor
A new instance of GoogleFirestoreAdminV1CloneDatabaseMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleFirestoreAdminV1CloneDatabaseMetadata
Returns a new instance of GoogleFirestoreAdminV1CloneDatabaseMetadata.
1594 1595 1596 |
# File 'lib/google/apis/firestore_v1/classes.rb', line 1594 def initialize(**args) update!(**args) end |
Instance Attribute Details
#database ⇒ String
The name of the database being cloned to.
Corresponds to the JSON property database
1562 1563 1564 |
# File 'lib/google/apis/firestore_v1/classes.rb', line 1562 def database @database end |
#end_time ⇒ String
The time the clone finished, unset for ongoing clones.
Corresponds to the JSON property endTime
1567 1568 1569 |
# File 'lib/google/apis/firestore_v1/classes.rb', line 1567 def end_time @end_time end |
#operation_state ⇒ String
The operation state of the clone.
Corresponds to the JSON property operationState
1572 1573 1574 |
# File 'lib/google/apis/firestore_v1/classes.rb', line 1572 def operation_state @operation_state end |
#pitr_snapshot ⇒ Google::Apis::FirestoreV1::GoogleFirestoreAdminV1PitrSnapshot
A consistent snapshot of a database at a specific point in time. A PITR (Point-
in-time recovery) snapshot with previous versions of a database's data is
available for every minute up to the associated database's data retention
period. If the PITR feature is enabled, the retention period is 7 days;
otherwise, it is one hour.
Corresponds to the JSON property pitrSnapshot
1581 1582 1583 |
# File 'lib/google/apis/firestore_v1/classes.rb', line 1581 def pitr_snapshot @pitr_snapshot end |
#progress_percentage ⇒ Google::Apis::FirestoreV1::GoogleFirestoreAdminV1Progress
Describes the progress of the operation. Unit of work is generic and must be
interpreted based on where Progress is used.
Corresponds to the JSON property progressPercentage
1587 1588 1589 |
# File 'lib/google/apis/firestore_v1/classes.rb', line 1587 def progress_percentage @progress_percentage end |
#start_time ⇒ String
The time the clone was started.
Corresponds to the JSON property startTime
1592 1593 1594 |
# File 'lib/google/apis/firestore_v1/classes.rb', line 1592 def start_time @start_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1599 1600 1601 1602 1603 1604 1605 1606 |
# File 'lib/google/apis/firestore_v1/classes.rb', line 1599 def update!(**args) @database = args[:database] if args.key?(:database) @end_time = args[:end_time] if args.key?(:end_time) @operation_state = args[:operation_state] if args.key?(:operation_state) @pitr_snapshot = args[:pitr_snapshot] if args.key?(:pitr_snapshot) @progress_percentage = args[:progress_percentage] if args.key?(:progress_percentage) @start_time = args[:start_time] if args.key?(:start_time) end |