Class: Google::Apis::FirestoreV1::GoogleFirestoreAdminV1CloneDatabaseRequest
- Inherits:
-
Object
- Object
- Google::Apis::FirestoreV1::GoogleFirestoreAdminV1CloneDatabaseRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/firestore_v1/classes.rb,
lib/google/apis/firestore_v1/representations.rb,
lib/google/apis/firestore_v1/representations.rb
Overview
The request message for FirestoreAdmin.CloneDatabase.
Instance Attribute Summary collapse
-
#database_id ⇒ String
Required.
-
#encryption_config ⇒ Google::Apis::FirestoreV1::GoogleFirestoreAdminV1EncryptionConfig
Encryption configuration for a new database being created from another source.
-
#pitr_snapshot ⇒ Google::Apis::FirestoreV1::GoogleFirestoreAdminV1PitrSnapshot
A consistent snapshot of a database at a specific point in time.
-
#tags ⇒ Hash<String,String>
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleFirestoreAdminV1CloneDatabaseRequest
constructor
A new instance of GoogleFirestoreAdminV1CloneDatabaseRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleFirestoreAdminV1CloneDatabaseRequest
Returns a new instance of GoogleFirestoreAdminV1CloneDatabaseRequest.
1646 1647 1648 |
# File 'lib/google/apis/firestore_v1/classes.rb', line 1646 def initialize(**args) update!(**args) end |
Instance Attribute Details
#database_id ⇒ String
Required. The ID to use for the database, which will become the final
component of the database's resource name. This database ID must not be
associated with an existing database. This value should be 4-63 characters.
Valid characters are /a-z-/ with first character a letter and the last a
letter or a number. Must not be UUID-like /[0-9a-f]8(-[0-9a-f]4)3-[0-9a-
f]12/. "(default)" database ID is also valid if the database is Standard
edition.
Corresponds to the JSON property databaseId
1622 1623 1624 |
# File 'lib/google/apis/firestore_v1/classes.rb', line 1622 def database_id @database_id end |
#encryption_config ⇒ Google::Apis::FirestoreV1::GoogleFirestoreAdminV1EncryptionConfig
Encryption configuration for a new database being created from another source.
The source could be a Backup or a PitrSnapshot.
Corresponds to the JSON property encryptionConfig
1628 1629 1630 |
# File 'lib/google/apis/firestore_v1/classes.rb', line 1628 def encryption_config @encryption_config end |
#pitr_snapshot ⇒ Google::Apis::FirestoreV1::GoogleFirestoreAdminV1PitrSnapshot
A consistent snapshot of a database at a specific point in time. A PITR (Point-
in-time recovery) snapshot with previous versions of a database's data is
available for every minute up to the associated database's data retention
period. If the PITR feature is enabled, the retention period is 7 days;
otherwise, it is one hour.
Corresponds to the JSON property pitrSnapshot
1637 1638 1639 |
# File 'lib/google/apis/firestore_v1/classes.rb', line 1637 def pitr_snapshot @pitr_snapshot end |
#tags ⇒ Hash<String,String>
Optional. Immutable. Tags to be bound to the cloned database. The tags should
be provided in the format of tagKeys/tag_key_id-> tagValues/tag_value_id`
.
Corresponds to the JSON propertytags`
1644 1645 1646 |
# File 'lib/google/apis/firestore_v1/classes.rb', line 1644 def @tags end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1651 1652 1653 1654 1655 1656 |
# File 'lib/google/apis/firestore_v1/classes.rb', line 1651 def update!(**args) @database_id = args[:database_id] if args.key?(:database_id) @encryption_config = args[:encryption_config] if args.key?(:encryption_config) @pitr_snapshot = args[:pitr_snapshot] if args.key?(:pitr_snapshot) @tags = args[:tags] if args.key?(:tags) end |