Class: Google::Apis::FirestoreV1::GoogleFirestoreAdminV1CollectionGroupScope
- Inherits:
-
Object
- Object
- Google::Apis::FirestoreV1::GoogleFirestoreAdminV1CollectionGroupScope
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/firestore_v1/classes.rb,
lib/google/apis/firestore_v1/representations.rb,
lib/google/apis/firestore_v1/representations.rb
Overview
The change stream is scoped to a collection group. Only events associated with the given collection group are visible to the Change Stream. Only a single change stream can be enabled per collection group.
Instance Attribute Summary collapse
-
#collection_group_id ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleFirestoreAdminV1CollectionGroupScope
constructor
A new instance of GoogleFirestoreAdminV1CollectionGroupScope.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleFirestoreAdminV1CollectionGroupScope
Returns a new instance of GoogleFirestoreAdminV1CollectionGroupScope.
1816 1817 1818 |
# File 'lib/google/apis/firestore_v1/classes.rb', line 1816 def initialize(**args) update!(**args) end |
Instance Attribute Details
#collection_group_id ⇒ String
Required. The collection group name.
Corresponds to the JSON property collectionGroupId
1814 1815 1816 |
# File 'lib/google/apis/firestore_v1/classes.rb', line 1814 def collection_group_id @collection_group_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1821 1822 1823 |
# File 'lib/google/apis/firestore_v1/classes.rb', line 1821 def update!(**args) @collection_group_id = args[:collection_group_id] if args.key?(:collection_group_id) end |