Class: Google::Apis::FirestoreV1::GoogleFirestoreAdminV1EncryptionConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/firestore_v1/classes.rb,
lib/google/apis/firestore_v1/representations.rb,
lib/google/apis/firestore_v1/representations.rb

Overview

Encryption configuration for a new database being created from another source. The source could be a Backup or a PitrSnapshot.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleFirestoreAdminV1EncryptionConfig

Returns a new instance of GoogleFirestoreAdminV1EncryptionConfig.



2019
2020
2021
# File 'lib/google/apis/firestore_v1/classes.rb', line 2019

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#customer_managed_encryptionGoogle::Apis::FirestoreV1::GoogleFirestoreAdminV1CustomerManagedEncryptionOptions

The configuration options for using CMEK (Customer Managed Encryption Key) encryption. Corresponds to the JSON property customerManagedEncryption



2007
2008
2009
# File 'lib/google/apis/firestore_v1/classes.rb', line 2007

def customer_managed_encryption
  @customer_managed_encryption
end

#google_default_encryptionGoogle::Apis::FirestoreV1::GoogleFirestoreAdminV1GoogleDefaultEncryptionOptions

The configuration options for using Google default encryption. Corresponds to the JSON property googleDefaultEncryption



2012
2013
2014
# File 'lib/google/apis/firestore_v1/classes.rb', line 2012

def google_default_encryption
  @google_default_encryption
end

#use_source_encryptionGoogle::Apis::FirestoreV1::GoogleFirestoreAdminV1SourceEncryptionOptions

The configuration options for using the same encryption method as the source. Corresponds to the JSON property useSourceEncryption



2017
2018
2019
# File 'lib/google/apis/firestore_v1/classes.rb', line 2017

def use_source_encryption
  @use_source_encryption
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2024
2025
2026
2027
2028
# File 'lib/google/apis/firestore_v1/classes.rb', line 2024

def update!(**args)
  @customer_managed_encryption = args[:customer_managed_encryption] if args.key?(:customer_managed_encryption)
  @google_default_encryption = args[:google_default_encryption] if args.key?(:google_default_encryption)
  @use_source_encryption = args[:use_source_encryption] if args.key?(:use_source_encryption)
end