Class: Google::Apis::FirestoreV1::GoogleFirestoreAdminV1ExportDocumentsMetadata
- Inherits:
-
Object
- Object
- Google::Apis::FirestoreV1::GoogleFirestoreAdminV1ExportDocumentsMetadata
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/firestore_v1/classes.rb,
lib/google/apis/firestore_v1/representations.rb,
lib/google/apis/firestore_v1/representations.rb
Overview
Metadata for google.longrunning.Operation results from FirestoreAdmin. ExportDocuments.
Instance Attribute Summary collapse
-
#collection_ids ⇒ Array<String>
Which collection IDs are being exported.
-
#end_time ⇒ String
The time this operation completed.
-
#namespace_ids ⇒ Array<String>
Which namespace IDs are being exported.
-
#operation_state ⇒ String
The state of the export operation.
-
#output_uri_prefix ⇒ String
Where the documents are being exported to.
-
#progress_bytes ⇒ Google::Apis::FirestoreV1::GoogleFirestoreAdminV1Progress
Describes the progress of the operation.
-
#progress_documents ⇒ Google::Apis::FirestoreV1::GoogleFirestoreAdminV1Progress
Describes the progress of the operation.
-
#snapshot_time ⇒ String
The timestamp that corresponds to the version of the database that is being exported.
-
#start_time ⇒ String
The time this operation started.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleFirestoreAdminV1ExportDocumentsMetadata
constructor
A new instance of GoogleFirestoreAdminV1ExportDocumentsMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleFirestoreAdminV1ExportDocumentsMetadata
Returns a new instance of GoogleFirestoreAdminV1ExportDocumentsMetadata.
2116 2117 2118 |
# File 'lib/google/apis/firestore_v1/classes.rb', line 2116 def initialize(**args) update!(**args) end |
Instance Attribute Details
#collection_ids ⇒ Array<String>
Which collection IDs are being exported.
Corresponds to the JSON property collectionIds
2069 2070 2071 |
# File 'lib/google/apis/firestore_v1/classes.rb', line 2069 def collection_ids @collection_ids end |
#end_time ⇒ String
The time this operation completed. Will be unset if operation still in
progress.
Corresponds to the JSON property endTime
2075 2076 2077 |
# File 'lib/google/apis/firestore_v1/classes.rb', line 2075 def end_time @end_time end |
#namespace_ids ⇒ Array<String>
Which namespace IDs are being exported.
Corresponds to the JSON property namespaceIds
2080 2081 2082 |
# File 'lib/google/apis/firestore_v1/classes.rb', line 2080 def namespace_ids @namespace_ids end |
#operation_state ⇒ String
The state of the export operation.
Corresponds to the JSON property operationState
2085 2086 2087 |
# File 'lib/google/apis/firestore_v1/classes.rb', line 2085 def operation_state @operation_state end |
#output_uri_prefix ⇒ String
Where the documents are being exported to.
Corresponds to the JSON property outputUriPrefix
2090 2091 2092 |
# File 'lib/google/apis/firestore_v1/classes.rb', line 2090 def output_uri_prefix @output_uri_prefix end |
#progress_bytes ⇒ Google::Apis::FirestoreV1::GoogleFirestoreAdminV1Progress
Describes the progress of the operation. Unit of work is generic and must be
interpreted based on where Progress is used.
Corresponds to the JSON property progressBytes
2096 2097 2098 |
# File 'lib/google/apis/firestore_v1/classes.rb', line 2096 def progress_bytes @progress_bytes end |
#progress_documents ⇒ Google::Apis::FirestoreV1::GoogleFirestoreAdminV1Progress
Describes the progress of the operation. Unit of work is generic and must be
interpreted based on where Progress is used.
Corresponds to the JSON property progressDocuments
2102 2103 2104 |
# File 'lib/google/apis/firestore_v1/classes.rb', line 2102 def progress_documents @progress_documents end |
#snapshot_time ⇒ String
The timestamp that corresponds to the version of the database that is being
exported. If unspecified, there are no guarantees about the consistency of the
documents being exported.
Corresponds to the JSON property snapshotTime
2109 2110 2111 |
# File 'lib/google/apis/firestore_v1/classes.rb', line 2109 def snapshot_time @snapshot_time end |
#start_time ⇒ String
The time this operation started.
Corresponds to the JSON property startTime
2114 2115 2116 |
# File 'lib/google/apis/firestore_v1/classes.rb', line 2114 def start_time @start_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2121 2122 2123 2124 2125 2126 2127 2128 2129 2130 2131 |
# File 'lib/google/apis/firestore_v1/classes.rb', line 2121 def update!(**args) @collection_ids = args[:collection_ids] if args.key?(:collection_ids) @end_time = args[:end_time] if args.key?(:end_time) @namespace_ids = args[:namespace_ids] if args.key?(:namespace_ids) @operation_state = args[:operation_state] if args.key?(:operation_state) @output_uri_prefix = args[:output_uri_prefix] if args.key?(:output_uri_prefix) @progress_bytes = args[:progress_bytes] if args.key?(:progress_bytes) @progress_documents = args[:progress_documents] if args.key?(:progress_documents) @snapshot_time = args[:snapshot_time] if args.key?(:snapshot_time) @start_time = args[:start_time] if args.key?(:start_time) end |