Class: Google::Apis::FirestoreV1::GoogleFirestoreAdminV1ExportDocumentsMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/firestore_v1/classes.rb,
lib/google/apis/firestore_v1/representations.rb,
lib/google/apis/firestore_v1/representations.rb

Overview

Metadata for google.longrunning.Operation results from FirestoreAdmin. ExportDocuments.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleFirestoreAdminV1ExportDocumentsMetadata

Returns a new instance of GoogleFirestoreAdminV1ExportDocumentsMetadata.



2086
2087
2088
# File 'lib/google/apis/firestore_v1/classes.rb', line 2086

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#collection_idsArray<String>

Which collection IDs are being exported. Corresponds to the JSON property collectionIds

Returns:

  • (Array<String>)


2039
2040
2041
# File 'lib/google/apis/firestore_v1/classes.rb', line 2039

def collection_ids
  @collection_ids
end

#end_timeString

The time this operation completed. Will be unset if operation still in progress. Corresponds to the JSON property endTime

Returns:

  • (String)


2045
2046
2047
# File 'lib/google/apis/firestore_v1/classes.rb', line 2045

def end_time
  @end_time
end

#namespace_idsArray<String>

Which namespace IDs are being exported. Corresponds to the JSON property namespaceIds

Returns:

  • (Array<String>)


2050
2051
2052
# File 'lib/google/apis/firestore_v1/classes.rb', line 2050

def namespace_ids
  @namespace_ids
end

#operation_stateString

The state of the export operation. Corresponds to the JSON property operationState

Returns:

  • (String)


2055
2056
2057
# File 'lib/google/apis/firestore_v1/classes.rb', line 2055

def operation_state
  @operation_state
end

#output_uri_prefixString

Where the documents are being exported to. Corresponds to the JSON property outputUriPrefix

Returns:

  • (String)


2060
2061
2062
# File 'lib/google/apis/firestore_v1/classes.rb', line 2060

def output_uri_prefix
  @output_uri_prefix
end

#progress_bytesGoogle::Apis::FirestoreV1::GoogleFirestoreAdminV1Progress

Describes the progress of the operation. Unit of work is generic and must be interpreted based on where Progress is used. Corresponds to the JSON property progressBytes



2066
2067
2068
# File 'lib/google/apis/firestore_v1/classes.rb', line 2066

def progress_bytes
  @progress_bytes
end

#progress_documentsGoogle::Apis::FirestoreV1::GoogleFirestoreAdminV1Progress

Describes the progress of the operation. Unit of work is generic and must be interpreted based on where Progress is used. Corresponds to the JSON property progressDocuments



2072
2073
2074
# File 'lib/google/apis/firestore_v1/classes.rb', line 2072

def progress_documents
  @progress_documents
end

#snapshot_timeString

The timestamp that corresponds to the version of the database that is being exported. If unspecified, there are no guarantees about the consistency of the documents being exported. Corresponds to the JSON property snapshotTime

Returns:

  • (String)


2079
2080
2081
# File 'lib/google/apis/firestore_v1/classes.rb', line 2079

def snapshot_time
  @snapshot_time
end

#start_timeString

The time this operation started. Corresponds to the JSON property startTime

Returns:

  • (String)


2084
2085
2086
# File 'lib/google/apis/firestore_v1/classes.rb', line 2084

def start_time
  @start_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2091
2092
2093
2094
2095
2096
2097
2098
2099
2100
2101
# File 'lib/google/apis/firestore_v1/classes.rb', line 2091

def update!(**args)
  @collection_ids = args[:collection_ids] if args.key?(:collection_ids)
  @end_time = args[:end_time] if args.key?(:end_time)
  @namespace_ids = args[:namespace_ids] if args.key?(:namespace_ids)
  @operation_state = args[:operation_state] if args.key?(:operation_state)
  @output_uri_prefix = args[:output_uri_prefix] if args.key?(:output_uri_prefix)
  @progress_bytes = args[:progress_bytes] if args.key?(:progress_bytes)
  @progress_documents = args[:progress_documents] if args.key?(:progress_documents)
  @snapshot_time = args[:snapshot_time] if args.key?(:snapshot_time)
  @start_time = args[:start_time] if args.key?(:start_time)
end