Class: Google::Apis::FirestoreV1::GoogleFirestoreAdminV1ExportDocumentsRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/firestore_v1/classes.rb,
lib/google/apis/firestore_v1/representations.rb,
lib/google/apis/firestore_v1/representations.rb

Overview

The request for FirestoreAdmin.ExportDocuments.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleFirestoreAdminV1ExportDocumentsRequest

Returns a new instance of GoogleFirestoreAdminV1ExportDocumentsRequest.



2129
2130
2131
# File 'lib/google/apis/firestore_v1/classes.rb', line 2129

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#collection_idsArray<String>

IDs of the collection groups to export. Unspecified means all collection groups. Each collection group in this list must be unique. Corresponds to the JSON property collectionIds

Returns:

  • (Array<String>)


2098
2099
2100
# File 'lib/google/apis/firestore_v1/classes.rb', line 2098

def collection_ids
  @collection_ids
end

#namespace_idsArray<String>

An empty list represents all namespaces. This is the preferred usage for databases that don't use namespaces. An empty string element represents the default namespace. This should be used if the database has data in non-default namespaces, but doesn't want to include them. Each namespace in this list must be unique. Corresponds to the JSON property namespaceIds

Returns:

  • (Array<String>)


2107
2108
2109
# File 'lib/google/apis/firestore_v1/classes.rb', line 2107

def namespace_ids
  @namespace_ids
end

#output_uri_prefixString

The output URI. Currently only supports Google Cloud Storage URIs of the form: gs://BUCKET_NAME[/NAMESPACE_PATH], where BUCKET_NAME is the name of the Google Cloud Storage bucket and NAMESPACE_PATH is an optional Google Cloud Storage namespace path. When choosing a name, be sure to consider Google Cloud Storage naming guidelines: https://cloud.google.com/storage/docs/naming. If the URI is a bucket (without a namespace path), a prefix will be generated based on the start time. Corresponds to the JSON property outputUriPrefix

Returns:

  • (String)


2118
2119
2120
# File 'lib/google/apis/firestore_v1/classes.rb', line 2118

def output_uri_prefix
  @output_uri_prefix
end

#snapshot_timeString

The timestamp that corresponds to the version of the database to be exported. The timestamp must be in the past, rounded to the minute and not older than earliestVersionTime. If specified, then the exported documents will represent a consistent view of the database at the provided time. Otherwise, there are no guarantees about the consistency of the exported documents. Corresponds to the JSON property snapshotTime

Returns:

  • (String)


2127
2128
2129
# File 'lib/google/apis/firestore_v1/classes.rb', line 2127

def snapshot_time
  @snapshot_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2134
2135
2136
2137
2138
2139
# File 'lib/google/apis/firestore_v1/classes.rb', line 2134

def update!(**args)
  @collection_ids = args[:collection_ids] if args.key?(:collection_ids)
  @namespace_ids = args[:namespace_ids] if args.key?(:namespace_ids)
  @output_uri_prefix = args[:output_uri_prefix] if args.key?(:output_uri_prefix)
  @snapshot_time = args[:snapshot_time] if args.key?(:snapshot_time)
end