Class: Google::Apis::FirestoreV1::GoogleFirestoreAdminV1FieldOperationMetadata
- Inherits:
-
Object
- Object
- Google::Apis::FirestoreV1::GoogleFirestoreAdminV1FieldOperationMetadata
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/firestore_v1/classes.rb,
lib/google/apis/firestore_v1/representations.rb,
lib/google/apis/firestore_v1/representations.rb
Overview
Metadata for google.longrunning.Operation results from FirestoreAdmin. UpdateField.
Instance Attribute Summary collapse
-
#end_time ⇒ String
The time this operation completed.
-
#field ⇒ String
The field resource that this operation is acting on.
-
#index_config_deltas ⇒ Array<Google::Apis::FirestoreV1::GoogleFirestoreAdminV1IndexConfigDelta>
A list of IndexConfigDelta, which describe the intent of this operation.
-
#progress_bytes ⇒ Google::Apis::FirestoreV1::GoogleFirestoreAdminV1Progress
Describes the progress of the operation.
-
#progress_documents ⇒ Google::Apis::FirestoreV1::GoogleFirestoreAdminV1Progress
Describes the progress of the operation.
-
#start_time ⇒ String
The time this operation started.
-
#state ⇒ String
The state of the operation.
-
#ttl_config_delta ⇒ Google::Apis::FirestoreV1::GoogleFirestoreAdminV1TtlConfigDelta
Information about a TTL configuration change.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleFirestoreAdminV1FieldOperationMetadata
constructor
A new instance of GoogleFirestoreAdminV1FieldOperationMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleFirestoreAdminV1FieldOperationMetadata
Returns a new instance of GoogleFirestoreAdminV1FieldOperationMetadata.
2281 2282 2283 |
# File 'lib/google/apis/firestore_v1/classes.rb', line 2281 def initialize(**args) update!(**args) end |
Instance Attribute Details
#end_time ⇒ String
The time this operation completed. Will be unset if operation still in
progress.
Corresponds to the JSON property endTime
2240 2241 2242 |
# File 'lib/google/apis/firestore_v1/classes.rb', line 2240 def end_time @end_time end |
#field ⇒ String
The field resource that this operation is acting on. For example: projects/
project_id/databases/database_id/collectionGroups/collection_id/fields/
field_path`
Corresponds to the JSON propertyfield`
2247 2248 2249 |
# File 'lib/google/apis/firestore_v1/classes.rb', line 2247 def field @field end |
#index_config_deltas ⇒ Array<Google::Apis::FirestoreV1::GoogleFirestoreAdminV1IndexConfigDelta>
A list of IndexConfigDelta, which describe the intent of this operation.
Corresponds to the JSON property indexConfigDeltas
2252 2253 2254 |
# File 'lib/google/apis/firestore_v1/classes.rb', line 2252 def index_config_deltas @index_config_deltas end |
#progress_bytes ⇒ Google::Apis::FirestoreV1::GoogleFirestoreAdminV1Progress
Describes the progress of the operation. Unit of work is generic and must be
interpreted based on where Progress is used.
Corresponds to the JSON property progressBytes
2258 2259 2260 |
# File 'lib/google/apis/firestore_v1/classes.rb', line 2258 def progress_bytes @progress_bytes end |
#progress_documents ⇒ Google::Apis::FirestoreV1::GoogleFirestoreAdminV1Progress
Describes the progress of the operation. Unit of work is generic and must be
interpreted based on where Progress is used.
Corresponds to the JSON property progressDocuments
2264 2265 2266 |
# File 'lib/google/apis/firestore_v1/classes.rb', line 2264 def progress_documents @progress_documents end |
#start_time ⇒ String
The time this operation started.
Corresponds to the JSON property startTime
2269 2270 2271 |
# File 'lib/google/apis/firestore_v1/classes.rb', line 2269 def start_time @start_time end |
#state ⇒ String
The state of the operation.
Corresponds to the JSON property state
2274 2275 2276 |
# File 'lib/google/apis/firestore_v1/classes.rb', line 2274 def state @state end |
#ttl_config_delta ⇒ Google::Apis::FirestoreV1::GoogleFirestoreAdminV1TtlConfigDelta
Information about a TTL configuration change.
Corresponds to the JSON property ttlConfigDelta
2279 2280 2281 |
# File 'lib/google/apis/firestore_v1/classes.rb', line 2279 def ttl_config_delta @ttl_config_delta end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2286 2287 2288 2289 2290 2291 2292 2293 2294 2295 |
# File 'lib/google/apis/firestore_v1/classes.rb', line 2286 def update!(**args) @end_time = args[:end_time] if args.key?(:end_time) @field = args[:field] if args.key?(:field) @index_config_deltas = args[:index_config_deltas] if args.key?(:index_config_deltas) @progress_bytes = args[:progress_bytes] if args.key?(:progress_bytes) @progress_documents = args[:progress_documents] if args.key?(:progress_documents) @start_time = args[:start_time] if args.key?(:start_time) @state = args[:state] if args.key?(:state) @ttl_config_delta = args[:ttl_config_delta] if args.key?(:ttl_config_delta) end |