Class: Google::Apis::FirestoreV1::GoogleFirestoreAdminV1ImportDocumentsMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/firestore_v1/classes.rb,
lib/google/apis/firestore_v1/representations.rb,
lib/google/apis/firestore_v1/representations.rb

Overview

Metadata for google.longrunning.Operation results from FirestoreAdmin. ImportDocuments.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleFirestoreAdminV1ImportDocumentsMetadata

Returns a new instance of GoogleFirestoreAdminV1ImportDocumentsMetadata.



2358
2359
2360
# File 'lib/google/apis/firestore_v1/classes.rb', line 2358

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#collection_idsArray<String>

Which collection IDs are being imported. Corresponds to the JSON property collectionIds

Returns:

  • (Array<String>)


2318
2319
2320
# File 'lib/google/apis/firestore_v1/classes.rb', line 2318

def collection_ids
  @collection_ids
end

#end_timeString

The time this operation completed. Will be unset if operation still in progress. Corresponds to the JSON property endTime

Returns:

  • (String)


2324
2325
2326
# File 'lib/google/apis/firestore_v1/classes.rb', line 2324

def end_time
  @end_time
end

#input_uri_prefixString

The location of the documents being imported. Corresponds to the JSON property inputUriPrefix

Returns:

  • (String)


2329
2330
2331
# File 'lib/google/apis/firestore_v1/classes.rb', line 2329

def input_uri_prefix
  @input_uri_prefix
end

#namespace_idsArray<String>

Which namespace IDs are being imported. Corresponds to the JSON property namespaceIds

Returns:

  • (Array<String>)


2334
2335
2336
# File 'lib/google/apis/firestore_v1/classes.rb', line 2334

def namespace_ids
  @namespace_ids
end

#operation_stateString

The state of the import operation. Corresponds to the JSON property operationState

Returns:

  • (String)


2339
2340
2341
# File 'lib/google/apis/firestore_v1/classes.rb', line 2339

def operation_state
  @operation_state
end

#progress_bytesGoogle::Apis::FirestoreV1::GoogleFirestoreAdminV1Progress

Describes the progress of the operation. Unit of work is generic and must be interpreted based on where Progress is used. Corresponds to the JSON property progressBytes



2345
2346
2347
# File 'lib/google/apis/firestore_v1/classes.rb', line 2345

def progress_bytes
  @progress_bytes
end

#progress_documentsGoogle::Apis::FirestoreV1::GoogleFirestoreAdminV1Progress

Describes the progress of the operation. Unit of work is generic and must be interpreted based on where Progress is used. Corresponds to the JSON property progressDocuments



2351
2352
2353
# File 'lib/google/apis/firestore_v1/classes.rb', line 2351

def progress_documents
  @progress_documents
end

#start_timeString

The time this operation started. Corresponds to the JSON property startTime

Returns:

  • (String)


2356
2357
2358
# File 'lib/google/apis/firestore_v1/classes.rb', line 2356

def start_time
  @start_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2363
2364
2365
2366
2367
2368
2369
2370
2371
2372
# File 'lib/google/apis/firestore_v1/classes.rb', line 2363

def update!(**args)
  @collection_ids = args[:collection_ids] if args.key?(:collection_ids)
  @end_time = args[:end_time] if args.key?(:end_time)
  @input_uri_prefix = args[:input_uri_prefix] if args.key?(:input_uri_prefix)
  @namespace_ids = args[:namespace_ids] if args.key?(:namespace_ids)
  @operation_state = args[:operation_state] if args.key?(:operation_state)
  @progress_bytes = args[:progress_bytes] if args.key?(:progress_bytes)
  @progress_documents = args[:progress_documents] if args.key?(:progress_documents)
  @start_time = args[:start_time] if args.key?(:start_time)
end