Class: Google::Apis::FirestoreV1::GoogleFirestoreAdminV1ImportDocumentsRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/firestore_v1/classes.rb,
lib/google/apis/firestore_v1/representations.rb,
lib/google/apis/firestore_v1/representations.rb

Overview

The request for FirestoreAdmin.ImportDocuments.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleFirestoreAdminV1ImportDocumentsRequest

Returns a new instance of GoogleFirestoreAdminV1ImportDocumentsRequest.



2402
2403
2404
# File 'lib/google/apis/firestore_v1/classes.rb', line 2402

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#collection_idsArray<String>

IDs of the collection groups to import. Unspecified means all collection groups that were included in the export. Each collection group in this list must be unique. Corresponds to the JSON property collectionIds

Returns:

  • (Array<String>)


2384
2385
2386
# File 'lib/google/apis/firestore_v1/classes.rb', line 2384

def collection_ids
  @collection_ids
end

#input_uri_prefixString

Location of the exported files. This must match the output_uri_prefix of an ExportDocumentsResponse from an export that has completed successfully. See: google.firestore.admin.v1.ExportDocumentsResponse.output_uri_prefix. Corresponds to the JSON property inputUriPrefix

Returns:

  • (String)


2391
2392
2393
# File 'lib/google/apis/firestore_v1/classes.rb', line 2391

def input_uri_prefix
  @input_uri_prefix
end

#namespace_idsArray<String>

An empty list represents all namespaces. This is the preferred usage for databases that don't use namespaces. An empty string element represents the default namespace. This should be used if the database has data in non-default namespaces, but doesn't want to include them. Each namespace in this list must be unique. Corresponds to the JSON property namespaceIds

Returns:

  • (Array<String>)


2400
2401
2402
# File 'lib/google/apis/firestore_v1/classes.rb', line 2400

def namespace_ids
  @namespace_ids
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2407
2408
2409
2410
2411
# File 'lib/google/apis/firestore_v1/classes.rb', line 2407

def update!(**args)
  @collection_ids = args[:collection_ids] if args.key?(:collection_ids)
  @input_uri_prefix = args[:input_uri_prefix] if args.key?(:input_uri_prefix)
  @namespace_ids = args[:namespace_ids] if args.key?(:namespace_ids)
end