Class: Google::Apis::FirestoreV1::GoogleFirestoreAdminV1IndexConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/firestore_v1/classes.rb,
lib/google/apis/firestore_v1/representations.rb,
lib/google/apis/firestore_v1/representations.rb

Overview

The index configuration for this field.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleFirestoreAdminV1IndexConfig

Returns a new instance of GoogleFirestoreAdminV1IndexConfig.



2546
2547
2548
# File 'lib/google/apis/firestore_v1/classes.rb', line 2546

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#ancestor_fieldString

Output only. Specifies the resource name of the Field from which this field' s index configuration is set (when uses_ancestor_config is true), or from which it would be set if this field had no index configuration (when uses_ancestor_config is false). Corresponds to the JSON property ancestorField

Returns:

  • (String)


2522
2523
2524
# File 'lib/google/apis/firestore_v1/classes.rb', line 2522

def ancestor_field
  @ancestor_field
end

#indexesArray<Google::Apis::FirestoreV1::GoogleFirestoreAdminV1Index>

The indexes supported for this field. Corresponds to the JSON property indexes



2527
2528
2529
# File 'lib/google/apis/firestore_v1/classes.rb', line 2527

def indexes
  @indexes
end

#revertingBoolean Also known as: reverting?

Output only When true, the Field's index configuration is in the process of being reverted. Once complete, the index config will transition to the same state as the field specified by ancestor_field, at which point uses_ancestor_config will be true and reverting will be false. Corresponds to the JSON property reverting

Returns:

  • (Boolean)


2535
2536
2537
# File 'lib/google/apis/firestore_v1/classes.rb', line 2535

def reverting
  @reverting
end

#uses_ancestor_configBoolean Also known as: uses_ancestor_config?

Output only. When true, the Field's index configuration is set from the configuration specified by the ancestor_field. When false, the Field's index configuration is defined explicitly. Corresponds to the JSON property usesAncestorConfig

Returns:

  • (Boolean)


2543
2544
2545
# File 'lib/google/apis/firestore_v1/classes.rb', line 2543

def uses_ancestor_config
  @uses_ancestor_config
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2551
2552
2553
2554
2555
2556
# File 'lib/google/apis/firestore_v1/classes.rb', line 2551

def update!(**args)
  @ancestor_field = args[:ancestor_field] if args.key?(:ancestor_field)
  @indexes = args[:indexes] if args.key?(:indexes)
  @reverting = args[:reverting] if args.key?(:reverting)
  @uses_ancestor_config = args[:uses_ancestor_config] if args.key?(:uses_ancestor_config)
end