Class: Google::Apis::FirestoreV1::GoogleFirestoreAdminV1IndexField

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/firestore_v1/classes.rb,
lib/google/apis/firestore_v1/representations.rb,
lib/google/apis/firestore_v1/representations.rb

Overview

A field in an index. The field_path describes which field is indexed, the value_mode describes how the field value is indexed.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleFirestoreAdminV1IndexField

Returns a new instance of GoogleFirestoreAdminV1IndexField.



2631
2632
2633
# File 'lib/google/apis/firestore_v1/classes.rb', line 2631

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#array_configString

Indicates that this field supports operations on array_values. Corresponds to the JSON property arrayConfig

Returns:

  • (String)


2607
2608
2609
# File 'lib/google/apis/firestore_v1/classes.rb', line 2607

def array_config
  @array_config
end

#field_pathString

Can be name. For single field indexes, this must match the name of the field or may be omitted. Corresponds to the JSON property fieldPath

Returns:

  • (String)


2613
2614
2615
# File 'lib/google/apis/firestore_v1/classes.rb', line 2613

def field_path
  @field_path
end

#orderString

Indicates that this field supports ordering by the specified order or comparing using =, !=, <, <=, >, >=. Corresponds to the JSON property order

Returns:

  • (String)


2619
2620
2621
# File 'lib/google/apis/firestore_v1/classes.rb', line 2619

def order
  @order
end

#search_configGoogle::Apis::FirestoreV1::GoogleFirestoreAdminV1SearchConfig

The configuration for how to index a field for search. Corresponds to the JSON property searchConfig



2624
2625
2626
# File 'lib/google/apis/firestore_v1/classes.rb', line 2624

def search_config
  @search_config
end

#vector_configGoogle::Apis::FirestoreV1::GoogleFirestoreAdminV1VectorConfig

The index configuration to support vector search operations Corresponds to the JSON property vectorConfig



2629
2630
2631
# File 'lib/google/apis/firestore_v1/classes.rb', line 2629

def vector_config
  @vector_config
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2636
2637
2638
2639
2640
2641
2642
# File 'lib/google/apis/firestore_v1/classes.rb', line 2636

def update!(**args)
  @array_config = args[:array_config] if args.key?(:array_config)
  @field_path = args[:field_path] if args.key?(:field_path)
  @order = args[:order] if args.key?(:order)
  @search_config = args[:search_config] if args.key?(:search_config)
  @vector_config = args[:vector_config] if args.key?(:vector_config)
end