Class: Google::Apis::FirestoreV1::GoogleFirestoreAdminV1IndexOperationMetadata
- Inherits:
-
Object
- Object
- Google::Apis::FirestoreV1::GoogleFirestoreAdminV1IndexOperationMetadata
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/firestore_v1/classes.rb,
lib/google/apis/firestore_v1/representations.rb,
lib/google/apis/firestore_v1/representations.rb
Overview
Metadata for google.longrunning.Operation results from FirestoreAdmin. CreateIndex.
Instance Attribute Summary collapse
-
#end_time ⇒ String
The time this operation completed.
-
#index ⇒ String
The index resource that this operation is acting on.
-
#progress_bytes ⇒ Google::Apis::FirestoreV1::GoogleFirestoreAdminV1Progress
Describes the progress of the operation.
-
#progress_documents ⇒ Google::Apis::FirestoreV1::GoogleFirestoreAdminV1Progress
Describes the progress of the operation.
-
#start_time ⇒ String
The time this operation started.
-
#state ⇒ String
The state of the operation.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleFirestoreAdminV1IndexOperationMetadata
constructor
A new instance of GoogleFirestoreAdminV1IndexOperationMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleFirestoreAdminV1IndexOperationMetadata
Returns a new instance of GoogleFirestoreAdminV1IndexOperationMetadata.
2830 2831 2832 |
# File 'lib/google/apis/firestore_v1/classes.rb', line 2830 def initialize(**args) update!(**args) end |
Instance Attribute Details
#end_time ⇒ String
The time this operation completed. Will be unset if operation still in
progress.
Corresponds to the JSON property endTime
2799 2800 2801 |
# File 'lib/google/apis/firestore_v1/classes.rb', line 2799 def end_time @end_time end |
#index ⇒ String
The index resource that this operation is acting on. For example: projects/
project_id/databases/database_id/collectionGroups/collection_id/indexes/
index_id`
Corresponds to the JSON propertyindex`
2806 2807 2808 |
# File 'lib/google/apis/firestore_v1/classes.rb', line 2806 def index @index end |
#progress_bytes ⇒ Google::Apis::FirestoreV1::GoogleFirestoreAdminV1Progress
Describes the progress of the operation. Unit of work is generic and must be
interpreted based on where Progress is used.
Corresponds to the JSON property progressBytes
2812 2813 2814 |
# File 'lib/google/apis/firestore_v1/classes.rb', line 2812 def progress_bytes @progress_bytes end |
#progress_documents ⇒ Google::Apis::FirestoreV1::GoogleFirestoreAdminV1Progress
Describes the progress of the operation. Unit of work is generic and must be
interpreted based on where Progress is used.
Corresponds to the JSON property progressDocuments
2818 2819 2820 |
# File 'lib/google/apis/firestore_v1/classes.rb', line 2818 def progress_documents @progress_documents end |
#start_time ⇒ String
The time this operation started.
Corresponds to the JSON property startTime
2823 2824 2825 |
# File 'lib/google/apis/firestore_v1/classes.rb', line 2823 def start_time @start_time end |
#state ⇒ String
The state of the operation.
Corresponds to the JSON property state
2828 2829 2830 |
# File 'lib/google/apis/firestore_v1/classes.rb', line 2828 def state @state end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2835 2836 2837 2838 2839 2840 2841 2842 |
# File 'lib/google/apis/firestore_v1/classes.rb', line 2835 def update!(**args) @end_time = args[:end_time] if args.key?(:end_time) @index = args[:index] if args.key?(:index) @progress_bytes = args[:progress_bytes] if args.key?(:progress_bytes) @progress_documents = args[:progress_documents] if args.key?(:progress_documents) @start_time = args[:start_time] if args.key?(:start_time) @state = args[:state] if args.key?(:state) end |