Class: Google::Apis::FirestoreV1::GoogleFirestoreAdminV1IndexOperationMetadata
- Inherits:
-
Object
- Object
- Google::Apis::FirestoreV1::GoogleFirestoreAdminV1IndexOperationMetadata
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/firestore_v1/classes.rb,
lib/google/apis/firestore_v1/representations.rb,
lib/google/apis/firestore_v1/representations.rb
Overview
Metadata for google.longrunning.Operation results from FirestoreAdmin. CreateIndex.
Instance Attribute Summary collapse
-
#end_time ⇒ String
The time this operation completed.
-
#index ⇒ String
The index resource that this operation is acting on.
-
#progress_bytes ⇒ Google::Apis::FirestoreV1::GoogleFirestoreAdminV1Progress
Describes the progress of the operation.
-
#progress_documents ⇒ Google::Apis::FirestoreV1::GoogleFirestoreAdminV1Progress
Describes the progress of the operation.
-
#start_time ⇒ String
The time this operation started.
-
#state ⇒ String
The state of the operation.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleFirestoreAdminV1IndexOperationMetadata
constructor
A new instance of GoogleFirestoreAdminV1IndexOperationMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleFirestoreAdminV1IndexOperationMetadata
Returns a new instance of GoogleFirestoreAdminV1IndexOperationMetadata.
2685 2686 2687 |
# File 'lib/google/apis/firestore_v1/classes.rb', line 2685 def initialize(**args) update!(**args) end |
Instance Attribute Details
#end_time ⇒ String
The time this operation completed. Will be unset if operation still in
progress.
Corresponds to the JSON property endTime
2654 2655 2656 |
# File 'lib/google/apis/firestore_v1/classes.rb', line 2654 def end_time @end_time end |
#index ⇒ String
The index resource that this operation is acting on. For example: projects/
project_id/databases/database_id/collectionGroups/collection_id/indexes/
index_id`
Corresponds to the JSON propertyindex`
2661 2662 2663 |
# File 'lib/google/apis/firestore_v1/classes.rb', line 2661 def index @index end |
#progress_bytes ⇒ Google::Apis::FirestoreV1::GoogleFirestoreAdminV1Progress
Describes the progress of the operation. Unit of work is generic and must be
interpreted based on where Progress is used.
Corresponds to the JSON property progressBytes
2667 2668 2669 |
# File 'lib/google/apis/firestore_v1/classes.rb', line 2667 def progress_bytes @progress_bytes end |
#progress_documents ⇒ Google::Apis::FirestoreV1::GoogleFirestoreAdminV1Progress
Describes the progress of the operation. Unit of work is generic and must be
interpreted based on where Progress is used.
Corresponds to the JSON property progressDocuments
2673 2674 2675 |
# File 'lib/google/apis/firestore_v1/classes.rb', line 2673 def progress_documents @progress_documents end |
#start_time ⇒ String
The time this operation started.
Corresponds to the JSON property startTime
2678 2679 2680 |
# File 'lib/google/apis/firestore_v1/classes.rb', line 2678 def start_time @start_time end |
#state ⇒ String
The state of the operation.
Corresponds to the JSON property state
2683 2684 2685 |
# File 'lib/google/apis/firestore_v1/classes.rb', line 2683 def state @state end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2690 2691 2692 2693 2694 2695 2696 2697 |
# File 'lib/google/apis/firestore_v1/classes.rb', line 2690 def update!(**args) @end_time = args[:end_time] if args.key?(:end_time) @index = args[:index] if args.key?(:index) @progress_bytes = args[:progress_bytes] if args.key?(:progress_bytes) @progress_documents = args[:progress_documents] if args.key?(:progress_documents) @start_time = args[:start_time] if args.key?(:start_time) @state = args[:state] if args.key?(:state) end |