Class: Google::Apis::FirestoreV1::GoogleFirestoreAdminV1IndexOperationMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/firestore_v1/classes.rb,
lib/google/apis/firestore_v1/representations.rb,
lib/google/apis/firestore_v1/representations.rb

Overview

Metadata for google.longrunning.Operation results from FirestoreAdmin. CreateIndex.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleFirestoreAdminV1IndexOperationMetadata

Returns a new instance of GoogleFirestoreAdminV1IndexOperationMetadata.



2671
2672
2673
# File 'lib/google/apis/firestore_v1/classes.rb', line 2671

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#end_timeString

The time this operation completed. Will be unset if operation still in progress. Corresponds to the JSON property endTime

Returns:

  • (String)


2640
2641
2642
# File 'lib/google/apis/firestore_v1/classes.rb', line 2640

def end_time
  @end_time
end

#indexString

The index resource that this operation is acting on. For example: projects/ project_id/databases/database_id/collectionGroups/collection_id/indexes/ index_id` Corresponds to the JSON propertyindex`

Returns:

  • (String)


2647
2648
2649
# File 'lib/google/apis/firestore_v1/classes.rb', line 2647

def index
  @index
end

#progress_bytesGoogle::Apis::FirestoreV1::GoogleFirestoreAdminV1Progress

Describes the progress of the operation. Unit of work is generic and must be interpreted based on where Progress is used. Corresponds to the JSON property progressBytes



2653
2654
2655
# File 'lib/google/apis/firestore_v1/classes.rb', line 2653

def progress_bytes
  @progress_bytes
end

#progress_documentsGoogle::Apis::FirestoreV1::GoogleFirestoreAdminV1Progress

Describes the progress of the operation. Unit of work is generic and must be interpreted based on where Progress is used. Corresponds to the JSON property progressDocuments



2659
2660
2661
# File 'lib/google/apis/firestore_v1/classes.rb', line 2659

def progress_documents
  @progress_documents
end

#start_timeString

The time this operation started. Corresponds to the JSON property startTime

Returns:

  • (String)


2664
2665
2666
# File 'lib/google/apis/firestore_v1/classes.rb', line 2664

def start_time
  @start_time
end

#stateString

The state of the operation. Corresponds to the JSON property state

Returns:

  • (String)


2669
2670
2671
# File 'lib/google/apis/firestore_v1/classes.rb', line 2669

def state
  @state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2676
2677
2678
2679
2680
2681
2682
2683
# File 'lib/google/apis/firestore_v1/classes.rb', line 2676

def update!(**args)
  @end_time = args[:end_time] if args.key?(:end_time)
  @index = args[:index] if args.key?(:index)
  @progress_bytes = args[:progress_bytes] if args.key?(:progress_bytes)
  @progress_documents = args[:progress_documents] if args.key?(:progress_documents)
  @start_time = args[:start_time] if args.key?(:start_time)
  @state = args[:state] if args.key?(:state)
end