Class: Google::Apis::FirestoreV1::GoogleFirestoreAdminV1RestoreDatabaseMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/firestore_v1/classes.rb,
lib/google/apis/firestore_v1/representations.rb,
lib/google/apis/firestore_v1/representations.rb

Overview

Metadata for the long-running operation from the RestoreDatabase request.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleFirestoreAdminV1RestoreDatabaseMetadata

Returns a new instance of GoogleFirestoreAdminV1RestoreDatabaseMetadata.



3024
3025
3026
# File 'lib/google/apis/firestore_v1/classes.rb', line 3024

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#backupString

The name of the backup restoring from. Corresponds to the JSON property backup

Returns:

  • (String)


2996
2997
2998
# File 'lib/google/apis/firestore_v1/classes.rb', line 2996

def backup
  @backup
end

#databaseString

The name of the database being restored to. Corresponds to the JSON property database

Returns:

  • (String)


3001
3002
3003
# File 'lib/google/apis/firestore_v1/classes.rb', line 3001

def database
  @database
end

#end_timeString

The time the restore finished, unset for ongoing restores. Corresponds to the JSON property endTime

Returns:

  • (String)


3006
3007
3008
# File 'lib/google/apis/firestore_v1/classes.rb', line 3006

def end_time
  @end_time
end

#operation_stateString

The operation state of the restore. Corresponds to the JSON property operationState

Returns:

  • (String)


3011
3012
3013
# File 'lib/google/apis/firestore_v1/classes.rb', line 3011

def operation_state
  @operation_state
end

#progress_percentageGoogle::Apis::FirestoreV1::GoogleFirestoreAdminV1Progress

Describes the progress of the operation. Unit of work is generic and must be interpreted based on where Progress is used. Corresponds to the JSON property progressPercentage



3017
3018
3019
# File 'lib/google/apis/firestore_v1/classes.rb', line 3017

def progress_percentage
  @progress_percentage
end

#start_timeString

The time the restore was started. Corresponds to the JSON property startTime

Returns:

  • (String)


3022
3023
3024
# File 'lib/google/apis/firestore_v1/classes.rb', line 3022

def start_time
  @start_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3029
3030
3031
3032
3033
3034
3035
3036
# File 'lib/google/apis/firestore_v1/classes.rb', line 3029

def update!(**args)
  @backup = args[:backup] if args.key?(:backup)
  @database = args[:database] if args.key?(:database)
  @end_time = args[:end_time] if args.key?(:end_time)
  @operation_state = args[:operation_state] if args.key?(:operation_state)
  @progress_percentage = args[:progress_percentage] if args.key?(:progress_percentage)
  @start_time = args[:start_time] if args.key?(:start_time)
end