Class: Google::Apis::FirestoreV1::GoogleFirestoreAdminV1RestoreDatabaseMetadata
- Inherits:
-
Object
- Object
- Google::Apis::FirestoreV1::GoogleFirestoreAdminV1RestoreDatabaseMetadata
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/firestore_v1/classes.rb,
lib/google/apis/firestore_v1/representations.rb,
lib/google/apis/firestore_v1/representations.rb
Overview
Metadata for the long-running operation from the RestoreDatabase request.
Instance Attribute Summary collapse
-
#backup ⇒ String
The name of the backup restoring from.
-
#database ⇒ String
The name of the database being restored to.
-
#end_time ⇒ String
The time the restore finished, unset for ongoing restores.
-
#operation_state ⇒ String
The operation state of the restore.
-
#progress_percentage ⇒ Google::Apis::FirestoreV1::GoogleFirestoreAdminV1Progress
Describes the progress of the operation.
-
#start_time ⇒ String
The time the restore was started.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleFirestoreAdminV1RestoreDatabaseMetadata
constructor
A new instance of GoogleFirestoreAdminV1RestoreDatabaseMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleFirestoreAdminV1RestoreDatabaseMetadata
Returns a new instance of GoogleFirestoreAdminV1RestoreDatabaseMetadata.
2980 2981 2982 |
# File 'lib/google/apis/firestore_v1/classes.rb', line 2980 def initialize(**args) update!(**args) end |
Instance Attribute Details
#backup ⇒ String
The name of the backup restoring from.
Corresponds to the JSON property backup
2952 2953 2954 |
# File 'lib/google/apis/firestore_v1/classes.rb', line 2952 def backup @backup end |
#database ⇒ String
The name of the database being restored to.
Corresponds to the JSON property database
2957 2958 2959 |
# File 'lib/google/apis/firestore_v1/classes.rb', line 2957 def database @database end |
#end_time ⇒ String
The time the restore finished, unset for ongoing restores.
Corresponds to the JSON property endTime
2962 2963 2964 |
# File 'lib/google/apis/firestore_v1/classes.rb', line 2962 def end_time @end_time end |
#operation_state ⇒ String
The operation state of the restore.
Corresponds to the JSON property operationState
2967 2968 2969 |
# File 'lib/google/apis/firestore_v1/classes.rb', line 2967 def operation_state @operation_state end |
#progress_percentage ⇒ Google::Apis::FirestoreV1::GoogleFirestoreAdminV1Progress
Describes the progress of the operation. Unit of work is generic and must be
interpreted based on where Progress is used.
Corresponds to the JSON property progressPercentage
2973 2974 2975 |
# File 'lib/google/apis/firestore_v1/classes.rb', line 2973 def progress_percentage @progress_percentage end |
#start_time ⇒ String
The time the restore was started.
Corresponds to the JSON property startTime
2978 2979 2980 |
# File 'lib/google/apis/firestore_v1/classes.rb', line 2978 def start_time @start_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2985 2986 2987 2988 2989 2990 2991 2992 |
# File 'lib/google/apis/firestore_v1/classes.rb', line 2985 def update!(**args) @backup = args[:backup] if args.key?(:backup) @database = args[:database] if args.key?(:database) @end_time = args[:end_time] if args.key?(:end_time) @operation_state = args[:operation_state] if args.key?(:operation_state) @progress_percentage = args[:progress_percentage] if args.key?(:progress_percentage) @start_time = args[:start_time] if args.key?(:start_time) end |