Class: Google::Apis::FirestoreV1::GoogleFirestoreAdminV1RestoreDatabaseMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/firestore_v1/classes.rb,
lib/google/apis/firestore_v1/representations.rb,
lib/google/apis/firestore_v1/representations.rb

Overview

Metadata for the long-running operation from the RestoreDatabase request.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleFirestoreAdminV1RestoreDatabaseMetadata

Returns a new instance of GoogleFirestoreAdminV1RestoreDatabaseMetadata.



2967
2968
2969
# File 'lib/google/apis/firestore_v1/classes.rb', line 2967

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#backupString

The name of the backup restoring from. Corresponds to the JSON property backup

Returns:

  • (String)


2939
2940
2941
# File 'lib/google/apis/firestore_v1/classes.rb', line 2939

def backup
  @backup
end

#databaseString

The name of the database being restored to. Corresponds to the JSON property database

Returns:

  • (String)


2944
2945
2946
# File 'lib/google/apis/firestore_v1/classes.rb', line 2944

def database
  @database
end

#end_timeString

The time the restore finished, unset for ongoing restores. Corresponds to the JSON property endTime

Returns:

  • (String)


2949
2950
2951
# File 'lib/google/apis/firestore_v1/classes.rb', line 2949

def end_time
  @end_time
end

#operation_stateString

The operation state of the restore. Corresponds to the JSON property operationState

Returns:

  • (String)


2954
2955
2956
# File 'lib/google/apis/firestore_v1/classes.rb', line 2954

def operation_state
  @operation_state
end

#progress_percentageGoogle::Apis::FirestoreV1::GoogleFirestoreAdminV1Progress

Describes the progress of the operation. Unit of work is generic and must be interpreted based on where Progress is used. Corresponds to the JSON property progressPercentage



2960
2961
2962
# File 'lib/google/apis/firestore_v1/classes.rb', line 2960

def progress_percentage
  @progress_percentage
end

#start_timeString

The time the restore was started. Corresponds to the JSON property startTime

Returns:

  • (String)


2965
2966
2967
# File 'lib/google/apis/firestore_v1/classes.rb', line 2965

def start_time
  @start_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2972
2973
2974
2975
2976
2977
2978
2979
# File 'lib/google/apis/firestore_v1/classes.rb', line 2972

def update!(**args)
  @backup = args[:backup] if args.key?(:backup)
  @database = args[:database] if args.key?(:database)
  @end_time = args[:end_time] if args.key?(:end_time)
  @operation_state = args[:operation_state] if args.key?(:operation_state)
  @progress_percentage = args[:progress_percentage] if args.key?(:progress_percentage)
  @start_time = args[:start_time] if args.key?(:start_time)
end