Class: Google::Apis::FirestoreV1::GoogleFirestoreAdminV1RestoreDatabaseRequest
- Inherits:
-
Object
- Object
- Google::Apis::FirestoreV1::GoogleFirestoreAdminV1RestoreDatabaseRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/firestore_v1/classes.rb,
lib/google/apis/firestore_v1/representations.rb,
lib/google/apis/firestore_v1/representations.rb
Overview
The request message for FirestoreAdmin.RestoreDatabase.
Instance Attribute Summary collapse
-
#backup ⇒ String
Required.
-
#database_id ⇒ String
Required.
-
#encryption_config ⇒ Google::Apis::FirestoreV1::GoogleFirestoreAdminV1EncryptionConfig
Encryption configuration for a new database being created from another source.
-
#tags ⇒ Hash<String,String>
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleFirestoreAdminV1RestoreDatabaseRequest
constructor
A new instance of GoogleFirestoreAdminV1RestoreDatabaseRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleFirestoreAdminV1RestoreDatabaseRequest
Returns a new instance of GoogleFirestoreAdminV1RestoreDatabaseRequest.
3045 3046 3047 |
# File 'lib/google/apis/firestore_v1/classes.rb', line 3045 def initialize(**args) update!(**args) end |
Instance Attribute Details
#backup ⇒ String
Required. Backup to restore from. Must be from the same project as the parent.
The restored database will be created in the same location as the source
backup. Format is: projects/project_id/locations/location/backups/backup
Corresponds to the JSON property backup
3019 3020 3021 |
# File 'lib/google/apis/firestore_v1/classes.rb', line 3019 def backup @backup end |
#database_id ⇒ String
Required. The ID to use for the database, which will become the final
component of the database's resource name. This database ID must not be
associated with an existing database. This value should be 4-63 characters.
Valid characters are /a-z-/ with first character a letter and the last a
letter or a number. Must not be UUID-like /[0-9a-f]8(-[0-9a-f]4)3-[0-9a-
f]12/. "(default)" database ID is also valid if the database is Standard
edition.
Corresponds to the JSON property databaseId
3030 3031 3032 |
# File 'lib/google/apis/firestore_v1/classes.rb', line 3030 def database_id @database_id end |
#encryption_config ⇒ Google::Apis::FirestoreV1::GoogleFirestoreAdminV1EncryptionConfig
Encryption configuration for a new database being created from another source.
The source could be a Backup or a PitrSnapshot.
Corresponds to the JSON property encryptionConfig
3036 3037 3038 |
# File 'lib/google/apis/firestore_v1/classes.rb', line 3036 def encryption_config @encryption_config end |
#tags ⇒ Hash<String,String>
Optional. Immutable. Tags to be bound to the restored database. The tags
should be provided in the format of tagKeys/tag_key_id-> tagValues/
tag_value_id`.
Corresponds to the JSON propertytags`
3043 3044 3045 |
# File 'lib/google/apis/firestore_v1/classes.rb', line 3043 def @tags end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3050 3051 3052 3053 3054 3055 |
# File 'lib/google/apis/firestore_v1/classes.rb', line 3050 def update!(**args) @backup = args[:backup] if args.key?(:backup) @database_id = args[:database_id] if args.key?(:database_id) @encryption_config = args[:encryption_config] if args.key?(:encryption_config) @tags = args[:tags] if args.key?(:tags) end |