Class: Google::Apis::FirestoreV1::GoogleFirestoreAdminV1RestoreDatabaseRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/firestore_v1/classes.rb,
lib/google/apis/firestore_v1/representations.rb,
lib/google/apis/firestore_v1/representations.rb

Overview

The request message for FirestoreAdmin.RestoreDatabase.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleFirestoreAdminV1RestoreDatabaseRequest

Returns a new instance of GoogleFirestoreAdminV1RestoreDatabaseRequest.



3036
3037
3038
# File 'lib/google/apis/firestore_v1/classes.rb', line 3036

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#backupString

Required. Backup to restore from. Must be from the same project as the parent. The restored database will be created in the same location as the source backup. Format is: projects/project_id/locations/location/backups/backup Corresponds to the JSON property backup

Returns:

  • (String)


3010
3011
3012
# File 'lib/google/apis/firestore_v1/classes.rb', line 3010

def backup
  @backup
end

#database_idString

Required. The ID to use for the database, which will become the final component of the database's resource name. This database ID must not be associated with an existing database. This value should be 4-63 characters. Valid characters are /a-z-/ with first character a letter and the last a letter or a number. Must not be UUID-like /[0-9a-f]8(-[0-9a-f]4)3-[0-9a- f]12/. "(default)" database ID is also valid if the database is Standard edition. Corresponds to the JSON property databaseId

Returns:

  • (String)


3021
3022
3023
# File 'lib/google/apis/firestore_v1/classes.rb', line 3021

def database_id
  @database_id
end

#encryption_configGoogle::Apis::FirestoreV1::GoogleFirestoreAdminV1EncryptionConfig

Encryption configuration for a new database being created from another source. The source could be a Backup or a PitrSnapshot. Corresponds to the JSON property encryptionConfig



3027
3028
3029
# File 'lib/google/apis/firestore_v1/classes.rb', line 3027

def encryption_config
  @encryption_config
end

#tagsHash<String,String>

Optional. Immutable. Tags to be bound to the restored database. The tags should be provided in the format of tagKeys/tag_key_id-> tagValues/ tag_value_id`. Corresponds to the JSON propertytags`

Returns:

  • (Hash<String,String>)


3034
3035
3036
# File 'lib/google/apis/firestore_v1/classes.rb', line 3034

def tags
  @tags
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3041
3042
3043
3044
3045
3046
# File 'lib/google/apis/firestore_v1/classes.rb', line 3041

def update!(**args)
  @backup = args[:backup] if args.key?(:backup)
  @database_id = args[:database_id] if args.key?(:database_id)
  @encryption_config = args[:encryption_config] if args.key?(:encryption_config)
  @tags = args[:tags] if args.key?(:tags)
end