Class: Google::Apis::FirestoreV1::GoogleFirestoreAdminV1SearchTextSpec

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/firestore_v1/classes.rb,
lib/google/apis/firestore_v1/representations.rb,
lib/google/apis/firestore_v1/representations.rb

Overview

The specification for how to build a text search index for a field.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleFirestoreAdminV1SearchTextSpec

Returns a new instance of GoogleFirestoreAdminV1SearchTextSpec.



3158
3159
3160
# File 'lib/google/apis/firestore_v1/classes.rb', line 3158

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#index_specsArray<Google::Apis::FirestoreV1::GoogleFirestoreAdminV1SearchTextIndexSpec>

Required. Specifications for how the field should be indexed. Repeated so that the field can be indexed in multiple ways. Corresponds to the JSON property indexSpecs



3156
3157
3158
# File 'lib/google/apis/firestore_v1/classes.rb', line 3156

def index_specs
  @index_specs
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3163
3164
3165
# File 'lib/google/apis/firestore_v1/classes.rb', line 3163

def update!(**args)
  @index_specs = args[:index_specs] if args.key?(:index_specs)
end