Class: Google::Apis::FirestoreV1::GoogleFirestoreAdminV1Stats

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/firestore_v1/classes.rb,
lib/google/apis/firestore_v1/representations.rb,
lib/google/apis/firestore_v1/representations.rb

Overview

Backup specific statistics.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleFirestoreAdminV1Stats

Returns a new instance of GoogleFirestoreAdminV1Stats.



3242
3243
3244
# File 'lib/google/apis/firestore_v1/classes.rb', line 3242

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#document_countFixnum

Output only. The total number of documents contained in the backup. Corresponds to the JSON property documentCount

Returns:

  • (Fixnum)


3229
3230
3231
# File 'lib/google/apis/firestore_v1/classes.rb', line 3229

def document_count
  @document_count
end

#index_countFixnum

Output only. The total number of index entries contained in the backup. Corresponds to the JSON property indexCount

Returns:

  • (Fixnum)


3234
3235
3236
# File 'lib/google/apis/firestore_v1/classes.rb', line 3234

def index_count
  @index_count
end

#size_bytesFixnum

Output only. Summation of the size of all documents and index entries in the backup, measured in bytes. Corresponds to the JSON property sizeBytes

Returns:

  • (Fixnum)


3240
3241
3242
# File 'lib/google/apis/firestore_v1/classes.rb', line 3240

def size_bytes
  @size_bytes
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3247
3248
3249
3250
3251
# File 'lib/google/apis/firestore_v1/classes.rb', line 3247

def update!(**args)
  @document_count = args[:document_count] if args.key?(:document_count)
  @index_count = args[:index_count] if args.key?(:index_count)
  @size_bytes = args[:size_bytes] if args.key?(:size_bytes)
end