Class: Google::Apis::FirestoreV1::GoogleFirestoreAdminV1Stats

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/firestore_v1/classes.rb,
lib/google/apis/firestore_v1/representations.rb,
lib/google/apis/firestore_v1/representations.rb

Overview

Backup specific statistics.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleFirestoreAdminV1Stats

Returns a new instance of GoogleFirestoreAdminV1Stats.



3091
3092
3093
# File 'lib/google/apis/firestore_v1/classes.rb', line 3091

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#document_countFixnum

Output only. The total number of documents contained in the backup. Corresponds to the JSON property documentCount

Returns:

  • (Fixnum)


3078
3079
3080
# File 'lib/google/apis/firestore_v1/classes.rb', line 3078

def document_count
  @document_count
end

#index_countFixnum

Output only. The total number of index entries contained in the backup. Corresponds to the JSON property indexCount

Returns:

  • (Fixnum)


3083
3084
3085
# File 'lib/google/apis/firestore_v1/classes.rb', line 3083

def index_count
  @index_count
end

#size_bytesFixnum

Output only. Summation of the size of all documents and index entries in the backup, measured in bytes. Corresponds to the JSON property sizeBytes

Returns:

  • (Fixnum)


3089
3090
3091
# File 'lib/google/apis/firestore_v1/classes.rb', line 3089

def size_bytes
  @size_bytes
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3096
3097
3098
3099
3100
# File 'lib/google/apis/firestore_v1/classes.rb', line 3096

def update!(**args)
  @document_count = args[:document_count] if args.key?(:document_count)
  @index_count = args[:index_count] if args.key?(:index_count)
  @size_bytes = args[:size_bytes] if args.key?(:size_bytes)
end