Class: Google::Apis::FirestoreV1::GoogleFirestoreAdminV1TtlConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/firestore_v1/classes.rb,
lib/google/apis/firestore_v1/representations.rb,
lib/google/apis/firestore_v1/representations.rb

Overview

The TTL (time-to-live) configuration for documents that have this Field set. Storing a timestamp value into a TTL-enabled field will be treated as the document's absolute expiration time. For Enterprise edition databases, the timestamp value may also be stored in an array value in the TTL-enabled field. Timestamp values in the past indicate that the document is eligible for immediate expiration. Using any other data type or leaving the field absent will disable expiration for the individual document.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleFirestoreAdminV1TtlConfig

Returns a new instance of GoogleFirestoreAdminV1TtlConfig.



3118
3119
3120
# File 'lib/google/apis/firestore_v1/classes.rb', line 3118

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#stateString

Output only. The state of the TTL configuration. Corresponds to the JSON property state

Returns:

  • (String)


3116
3117
3118
# File 'lib/google/apis/firestore_v1/classes.rb', line 3116

def state
  @state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3123
3124
3125
# File 'lib/google/apis/firestore_v1/classes.rb', line 3123

def update!(**args)
  @state = args[:state] if args.key?(:state)
end