Class: Google::Apis::FirestoreV1::GoogleFirestoreAdminV1VectorConfig
- Inherits:
-
Object
- Object
- Google::Apis::FirestoreV1::GoogleFirestoreAdminV1VectorConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/firestore_v1/classes.rb,
lib/google/apis/firestore_v1/representations.rb,
lib/google/apis/firestore_v1/representations.rb
Overview
The index configuration to support vector search operations
Instance Attribute Summary collapse
-
#dimension ⇒ Fixnum
Required.
-
#flat ⇒ Google::Apis::FirestoreV1::GoogleFirestoreAdminV1FlatIndex
An index that stores vectors in a flat data structure, and supports exhaustive search.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleFirestoreAdminV1VectorConfig
constructor
A new instance of GoogleFirestoreAdminV1VectorConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleFirestoreAdminV1VectorConfig
Returns a new instance of GoogleFirestoreAdminV1VectorConfig.
3384 3385 3386 |
# File 'lib/google/apis/firestore_v1/classes.rb', line 3384 def initialize(**args) update!(**args) end |
Instance Attribute Details
#dimension ⇒ Fixnum
Required. The vector dimension this configuration applies to. The resulting
index will only include vectors of this dimension, and can be used for vector
search with the same dimension.
Corresponds to the JSON property dimension
3376 3377 3378 |
# File 'lib/google/apis/firestore_v1/classes.rb', line 3376 def dimension @dimension end |
#flat ⇒ Google::Apis::FirestoreV1::GoogleFirestoreAdminV1FlatIndex
An index that stores vectors in a flat data structure, and supports exhaustive
search.
Corresponds to the JSON property flat
3382 3383 3384 |
# File 'lib/google/apis/firestore_v1/classes.rb', line 3382 def flat @flat end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3389 3390 3391 3392 |
# File 'lib/google/apis/firestore_v1/classes.rb', line 3389 def update!(**args) @dimension = args[:dimension] if args.key?(:dimension) @flat = args[:flat] if args.key?(:flat) end |