Class: Google::Apis::FirestoreV1::LatLng

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/firestore_v1/classes.rb,
lib/google/apis/firestore_v1/representations.rb,
lib/google/apis/firestore_v1/representations.rb

Overview

An object that represents a latitude/longitude pair. This is expressed as a pair of doubles to represent degrees latitude and degrees longitude. Unless specified otherwise, this object must conform to the WGS84 standard. Values must be within normalized ranges.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ LatLng

Returns a new instance of LatLng.



3545
3546
3547
# File 'lib/google/apis/firestore_v1/classes.rb', line 3545

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#latitudeFloat

The latitude in degrees. It must be in the range [-90.0, +90.0]. Corresponds to the JSON property latitude

Returns:

  • (Float)


3538
3539
3540
# File 'lib/google/apis/firestore_v1/classes.rb', line 3538

def latitude
  @latitude
end

#longitudeFloat

The longitude in degrees. It must be in the range [-180.0, +180.0]. Corresponds to the JSON property longitude

Returns:

  • (Float)


3543
3544
3545
# File 'lib/google/apis/firestore_v1/classes.rb', line 3543

def longitude
  @longitude
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3550
3551
3552
3553
# File 'lib/google/apis/firestore_v1/classes.rb', line 3550

def update!(**args)
  @latitude = args[:latitude] if args.key?(:latitude)
  @longitude = args[:longitude] if args.key?(:longitude)
end