Class: Google::Apis::FirestoreV1::LatLng
- Inherits:
-
Object
- Object
- Google::Apis::FirestoreV1::LatLng
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/firestore_v1/classes.rb,
lib/google/apis/firestore_v1/representations.rb,
lib/google/apis/firestore_v1/representations.rb
Overview
An object that represents a latitude/longitude pair. This is expressed as a pair of doubles to represent degrees latitude and degrees longitude. Unless specified otherwise, this object must conform to the WGS84 standard. Values must be within normalized ranges.
Instance Attribute Summary collapse
-
#latitude ⇒ Float
The latitude in degrees.
-
#longitude ⇒ Float
The longitude in degrees.
Instance Method Summary collapse
-
#initialize(**args) ⇒ LatLng
constructor
A new instance of LatLng.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ LatLng
Returns a new instance of LatLng.
3546 3547 3548 |
# File 'lib/google/apis/firestore_v1/classes.rb', line 3546 def initialize(**args) update!(**args) end |
Instance Attribute Details
#latitude ⇒ Float
The latitude in degrees. It must be in the range [-90.0, +90.0].
Corresponds to the JSON property latitude
3539 3540 3541 |
# File 'lib/google/apis/firestore_v1/classes.rb', line 3539 def latitude @latitude end |
#longitude ⇒ Float
The longitude in degrees. It must be in the range [-180.0, +180.0].
Corresponds to the JSON property longitude
3544 3545 3546 |
# File 'lib/google/apis/firestore_v1/classes.rb', line 3544 def longitude @longitude end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3551 3552 3553 3554 |
# File 'lib/google/apis/firestore_v1/classes.rb', line 3551 def update!(**args) @latitude = args[:latitude] if args.key?(:latitude) @longitude = args[:longitude] if args.key?(:longitude) end |