Class: Google::Apis::FirestoreV1::LatLng
- Inherits:
-
Object
- Object
- Google::Apis::FirestoreV1::LatLng
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/firestore_v1/classes.rb,
lib/google/apis/firestore_v1/representations.rb,
lib/google/apis/firestore_v1/representations.rb
Overview
An object that represents a latitude/longitude pair. This is expressed as a pair of doubles to represent degrees latitude and degrees longitude. Unless specified otherwise, this object must conform to the WGS84 standard. Values must be within normalized ranges.
Instance Attribute Summary collapse
-
#latitude ⇒ Float
The latitude in degrees.
-
#longitude ⇒ Float
The longitude in degrees.
Instance Method Summary collapse
-
#initialize(**args) ⇒ LatLng
constructor
A new instance of LatLng.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ LatLng
Returns a new instance of LatLng.
3386 3387 3388 |
# File 'lib/google/apis/firestore_v1/classes.rb', line 3386 def initialize(**args) update!(**args) end |
Instance Attribute Details
#latitude ⇒ Float
The latitude in degrees. It must be in the range [-90.0, +90.0].
Corresponds to the JSON property latitude
3379 3380 3381 |
# File 'lib/google/apis/firestore_v1/classes.rb', line 3379 def latitude @latitude end |
#longitude ⇒ Float
The longitude in degrees. It must be in the range [-180.0, +180.0].
Corresponds to the JSON property longitude
3384 3385 3386 |
# File 'lib/google/apis/firestore_v1/classes.rb', line 3384 def longitude @longitude end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3391 3392 3393 3394 |
# File 'lib/google/apis/firestore_v1/classes.rb', line 3391 def update!(**args) @latitude = args[:latitude] if args.key?(:latitude) @longitude = args[:longitude] if args.key?(:longitude) end |