Class: Google::Apis::FirestoreV1::ListCollectionIdsRequest
- Inherits:
-
Object
- Object
- Google::Apis::FirestoreV1::ListCollectionIdsRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/firestore_v1/classes.rb,
lib/google/apis/firestore_v1/representations.rb,
lib/google/apis/firestore_v1/representations.rb
Overview
The request for Firestore.ListCollectionIds.
Instance Attribute Summary collapse
-
#page_size ⇒ Fixnum
The maximum number of results to return.
-
#page_token ⇒ String
A page token.
-
#read_time ⇒ String
Reads documents as they were at the given time.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListCollectionIdsRequest
constructor
A new instance of ListCollectionIdsRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListCollectionIdsRequest
Returns a new instance of ListCollectionIdsRequest.
3418 3419 3420 |
# File 'lib/google/apis/firestore_v1/classes.rb', line 3418 def initialize(**args) update!(**args) end |
Instance Attribute Details
#page_size ⇒ Fixnum
The maximum number of results to return.
Corresponds to the JSON property pageSize
3404 3405 3406 |
# File 'lib/google/apis/firestore_v1/classes.rb', line 3404 def page_size @page_size end |
#page_token ⇒ String
A page token. Must be a value from ListCollectionIdsResponse.
Corresponds to the JSON property pageToken
3409 3410 3411 |
# File 'lib/google/apis/firestore_v1/classes.rb', line 3409 def page_token @page_token end |
#read_time ⇒ String
Reads documents as they were at the given time. This must be a microsecond
precision timestamp within the past one hour, or if Point-in-Time Recovery is
enabled, can additionally be a whole minute timestamp within the past 7 days.
Corresponds to the JSON property readTime
3416 3417 3418 |
# File 'lib/google/apis/firestore_v1/classes.rb', line 3416 def read_time @read_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3423 3424 3425 3426 3427 |
# File 'lib/google/apis/firestore_v1/classes.rb', line 3423 def update!(**args) @page_size = args[:page_size] if args.key?(:page_size) @page_token = args[:page_token] if args.key?(:page_token) @read_time = args[:read_time] if args.key?(:read_time) end |