Class: Google::Apis::FirestoreV1::PartitionQueryRequest
- Inherits:
-
Object
- Object
- Google::Apis::FirestoreV1::PartitionQueryRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/firestore_v1/classes.rb,
lib/google/apis/firestore_v1/representations.rb,
lib/google/apis/firestore_v1/representations.rb
Overview
The request for Firestore.PartitionQuery.
Instance Attribute Summary collapse
-
#page_size ⇒ Fixnum
The maximum number of partitions to return in this call, subject to
partition_count. -
#page_token ⇒ String
The
next_page_tokenvalue returned from a previous call to PartitionQuery that may be used to get an additional set of results. -
#partition_count ⇒ Fixnum
The desired maximum number of partition points.
-
#read_time ⇒ String
Reads documents as they were at the given time.
-
#request_options ⇒ Google::Apis::FirestoreV1::RequestOptions
Options for a server request.
-
#structured_query ⇒ Google::Apis::FirestoreV1::StructuredQuery
A Firestore query.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PartitionQueryRequest
constructor
A new instance of PartitionQueryRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PartitionQueryRequest
Returns a new instance of PartitionQueryRequest.
4103 4104 4105 |
# File 'lib/google/apis/firestore_v1/classes.rb', line 4103 def initialize(**args) update!(**args) end |
Instance Attribute Details
#page_size ⇒ Fixnum
The maximum number of partitions to return in this call, subject to
partition_count. For example, if partition_count = 10 and page_size = 8,
the first call to PartitionQuery will return up to 8 partitions and a
next_page_token if more results exist. A second call to PartitionQuery will
return up to 2 partitions, to complete the total of 10 specified in
partition_count.
Corresponds to the JSON property pageSize
4060 4061 4062 |
# File 'lib/google/apis/firestore_v1/classes.rb', line 4060 def page_size @page_size end |
#page_token ⇒ String
The next_page_token value returned from a previous call to PartitionQuery
that may be used to get an additional set of results. There are no ordering
guarantees between sets of results. Thus, using multiple sets of results will
require merging the different result sets. For example, two subsequent calls
using a page_token may return: * cursor B, cursor M, cursor Q * cursor A,
cursor U, cursor W To obtain a complete result set ordered with respect to the
results of the query supplied to PartitionQuery, the results sets should be
merged: cursor A, cursor B, cursor M, cursor Q, cursor U, cursor W
Corresponds to the JSON property pageToken
4072 4073 4074 |
# File 'lib/google/apis/firestore_v1/classes.rb', line 4072 def page_token @page_token end |
#partition_count ⇒ Fixnum
The desired maximum number of partition points. The partitions may be returned
across multiple pages of results. The number must be positive. The actual
number of partitions returned may be fewer. For example, this may be set to
one fewer than the number of parallel queries to be run, or in running a data
pipeline job, one fewer than the number of workers or compute instances
available.
Corresponds to the JSON property partitionCount
4082 4083 4084 |
# File 'lib/google/apis/firestore_v1/classes.rb', line 4082 def partition_count @partition_count end |
#read_time ⇒ String
Reads documents as they were at the given time. This must be a microsecond
precision timestamp within the past one hour, or if Point-in-Time Recovery is
enabled, can additionally be a whole minute timestamp within the past 7 days.
Corresponds to the JSON property readTime
4089 4090 4091 |
# File 'lib/google/apis/firestore_v1/classes.rb', line 4089 def read_time @read_time end |
#request_options ⇒ Google::Apis::FirestoreV1::RequestOptions
Options for a server request.
Corresponds to the JSON property requestOptions
4094 4095 4096 |
# File 'lib/google/apis/firestore_v1/classes.rb', line 4094 def @request_options end |
#structured_query ⇒ Google::Apis::FirestoreV1::StructuredQuery
A Firestore query. The query stages are executed in the following order: 1.
from 2. where 3. select 4. order_by + start_at + end_at 5. offset 6. limit 7.
find_nearest
Corresponds to the JSON property structuredQuery
4101 4102 4103 |
# File 'lib/google/apis/firestore_v1/classes.rb', line 4101 def structured_query @structured_query end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4108 4109 4110 4111 4112 4113 4114 4115 |
# File 'lib/google/apis/firestore_v1/classes.rb', line 4108 def update!(**args) @page_size = args[:page_size] if args.key?(:page_size) @page_token = args[:page_token] if args.key?(:page_token) @partition_count = args[:partition_count] if args.key?(:partition_count) @read_time = args[:read_time] if args.key?(:read_time) @request_options = args[:request_options] if args.key?(:request_options) @structured_query = args[:structured_query] if args.key?(:structured_query) end |