Class: Google::Apis::FirestoreV1::Precondition

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/firestore_v1/classes.rb,
lib/google/apis/firestore_v1/representations.rb,
lib/google/apis/firestore_v1/representations.rb

Overview

A precondition on a document, used for conditional operations.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Precondition

Returns a new instance of Precondition.



3841
3842
3843
# File 'lib/google/apis/firestore_v1/classes.rb', line 3841

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#existsBoolean Also known as: exists?

When set to true, the target document must exist. When set to false, the target document must not exist. Corresponds to the JSON property exists

Returns:

  • (Boolean)


3832
3833
3834
# File 'lib/google/apis/firestore_v1/classes.rb', line 3832

def exists
  @exists
end

#update_timeString

When set, the target document must exist and have been last updated at that time. Timestamp must be microsecond aligned. Corresponds to the JSON property updateTime

Returns:

  • (String)


3839
3840
3841
# File 'lib/google/apis/firestore_v1/classes.rb', line 3839

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3846
3847
3848
3849
# File 'lib/google/apis/firestore_v1/classes.rb', line 3846

def update!(**args)
  @exists = args[:exists] if args.key?(:exists)
  @update_time = args[:update_time] if args.key?(:update_time)
end