Class: Google::Apis::FirestoreV1::RunAggregationQueryRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/firestore_v1/classes.rb,
lib/google/apis/firestore_v1/representations.rb,
lib/google/apis/firestore_v1/representations.rb

Overview

The request for Firestore.RunAggregationQuery.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RunAggregationQueryRequest

Returns a new instance of RunAggregationQueryRequest.



4254
4255
4256
# File 'lib/google/apis/firestore_v1/classes.rb', line 4254

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#explain_optionsGoogle::Apis::FirestoreV1::ExplainOptions

Explain options for the query. Corresponds to the JSON property explainOptions



4223
4224
4225
# File 'lib/google/apis/firestore_v1/classes.rb', line 4223

def explain_options
  @explain_options
end

#new_transactionGoogle::Apis::FirestoreV1::TransactionOptions

Options for creating a new transaction. Corresponds to the JSON property newTransaction



4228
4229
4230
# File 'lib/google/apis/firestore_v1/classes.rb', line 4228

def new_transaction
  @new_transaction
end

#read_timeString

Executes the query at the given timestamp. This must be a microsecond precision timestamp within the past one hour, or if Point-in-Time Recovery is enabled, can additionally be a whole minute timestamp within the past 7 days. Corresponds to the JSON property readTime

Returns:

  • (String)


4235
4236
4237
# File 'lib/google/apis/firestore_v1/classes.rb', line 4235

def read_time
  @read_time
end

#request_optionsGoogle::Apis::FirestoreV1::RequestOptions

Options for a server request. Corresponds to the JSON property requestOptions



4240
4241
4242
# File 'lib/google/apis/firestore_v1/classes.rb', line 4240

def request_options
  @request_options
end

#structured_aggregation_queryGoogle::Apis::FirestoreV1::StructuredAggregationQuery

Firestore query for running an aggregation over a StructuredQuery. Corresponds to the JSON property structuredAggregationQuery



4245
4246
4247
# File 'lib/google/apis/firestore_v1/classes.rb', line 4245

def structured_aggregation_query
  @structured_aggregation_query
end

#transactionString

Run the aggregation within an already active transaction. The value here is the opaque transaction ID to execute the query in. Corresponds to the JSON property transaction NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


4252
4253
4254
# File 'lib/google/apis/firestore_v1/classes.rb', line 4252

def transaction
  @transaction
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4259
4260
4261
4262
4263
4264
4265
4266
# File 'lib/google/apis/firestore_v1/classes.rb', line 4259

def update!(**args)
  @explain_options = args[:explain_options] if args.key?(:explain_options)
  @new_transaction = args[:new_transaction] if args.key?(:new_transaction)
  @read_time = args[:read_time] if args.key?(:read_time)
  @request_options = args[:request_options] if args.key?(:request_options)
  @structured_aggregation_query = args[:structured_aggregation_query] if args.key?(:structured_aggregation_query)
  @transaction = args[:transaction] if args.key?(:transaction)
end