Class: Google::Apis::FirestoreV1::RunAggregationQueryRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/firestore_v1/classes.rb,
lib/google/apis/firestore_v1/representations.rb,
lib/google/apis/firestore_v1/representations.rb

Overview

The request for Firestore.RunAggregationQuery.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RunAggregationQueryRequest

Returns a new instance of RunAggregationQueryRequest.



4176
4177
4178
# File 'lib/google/apis/firestore_v1/classes.rb', line 4176

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#explain_optionsGoogle::Apis::FirestoreV1::ExplainOptions

Explain options for the query. Corresponds to the JSON property explainOptions



4150
4151
4152
# File 'lib/google/apis/firestore_v1/classes.rb', line 4150

def explain_options
  @explain_options
end

#new_transactionGoogle::Apis::FirestoreV1::TransactionOptions

Options for creating a new transaction. Corresponds to the JSON property newTransaction



4155
4156
4157
# File 'lib/google/apis/firestore_v1/classes.rb', line 4155

def new_transaction
  @new_transaction
end

#read_timeString

Executes the query at the given timestamp. This must be a microsecond precision timestamp within the past one hour, or if Point-in-Time Recovery is enabled, can additionally be a whole minute timestamp within the past 7 days. Corresponds to the JSON property readTime

Returns:

  • (String)


4162
4163
4164
# File 'lib/google/apis/firestore_v1/classes.rb', line 4162

def read_time
  @read_time
end

#structured_aggregation_queryGoogle::Apis::FirestoreV1::StructuredAggregationQuery

Firestore query for running an aggregation over a StructuredQuery. Corresponds to the JSON property structuredAggregationQuery



4167
4168
4169
# File 'lib/google/apis/firestore_v1/classes.rb', line 4167

def structured_aggregation_query
  @structured_aggregation_query
end

#transactionString

Run the aggregation within an already active transaction. The value here is the opaque transaction ID to execute the query in. Corresponds to the JSON property transaction NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


4174
4175
4176
# File 'lib/google/apis/firestore_v1/classes.rb', line 4174

def transaction
  @transaction
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4181
4182
4183
4184
4185
4186
4187
# File 'lib/google/apis/firestore_v1/classes.rb', line 4181

def update!(**args)
  @explain_options = args[:explain_options] if args.key?(:explain_options)
  @new_transaction = args[:new_transaction] if args.key?(:new_transaction)
  @read_time = args[:read_time] if args.key?(:read_time)
  @structured_aggregation_query = args[:structured_aggregation_query] if args.key?(:structured_aggregation_query)
  @transaction = args[:transaction] if args.key?(:transaction)
end