Class: Google::Apis::FirestoreV1::RunAggregationQueryResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/firestore_v1/classes.rb,
lib/google/apis/firestore_v1/representations.rb,
lib/google/apis/firestore_v1/representations.rb

Overview

The response for Firestore.RunAggregationQuery.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RunAggregationQueryResponse

Returns a new instance of RunAggregationQueryResponse.



4213
4214
4215
# File 'lib/google/apis/firestore_v1/classes.rb', line 4213

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#explain_metricsGoogle::Apis::FirestoreV1::ExplainMetrics

Explain metrics for the query. Corresponds to the JSON property explainMetrics



4188
4189
4190
# File 'lib/google/apis/firestore_v1/classes.rb', line 4188

def explain_metrics
  @explain_metrics
end

#read_timeString

The time at which the aggregate result was computed. This is always monotonically increasing; in this case, the previous AggregationResult in the result stream are guaranteed not to have changed between their read_time and this one. If the query returns no results, a response with read_time and no result will be sent, and this represents the time at which the query was run. Corresponds to the JSON property readTime

Returns:

  • (String)


4197
4198
4199
# File 'lib/google/apis/firestore_v1/classes.rb', line 4197

def read_time
  @read_time
end

#resultGoogle::Apis::FirestoreV1::AggregationResult

The result of a single bucket from a Firestore aggregation query. The keys of aggregate_fields are the same for all results in an aggregation query, unlike document queries which can have different fields present for each result. Corresponds to the JSON property result



4204
4205
4206
# File 'lib/google/apis/firestore_v1/classes.rb', line 4204

def result
  @result
end

#transactionString

The transaction that was started as part of this request. Only present on the first response when the request requested to start a new transaction. Corresponds to the JSON property transaction NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


4211
4212
4213
# File 'lib/google/apis/firestore_v1/classes.rb', line 4211

def transaction
  @transaction
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4218
4219
4220
4221
4222
4223
# File 'lib/google/apis/firestore_v1/classes.rb', line 4218

def update!(**args)
  @explain_metrics = args[:explain_metrics] if args.key?(:explain_metrics)
  @read_time = args[:read_time] if args.key?(:read_time)
  @result = args[:result] if args.key?(:result)
  @transaction = args[:transaction] if args.key?(:transaction)
end