Class: Google::Apis::FirestoreV1::RunAggregationQueryResponse
- Inherits:
-
Object
- Object
- Google::Apis::FirestoreV1::RunAggregationQueryResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/firestore_v1/classes.rb,
lib/google/apis/firestore_v1/representations.rb,
lib/google/apis/firestore_v1/representations.rb
Overview
The response for Firestore.RunAggregationQuery.
Instance Attribute Summary collapse
-
#explain_metrics ⇒ Google::Apis::FirestoreV1::ExplainMetrics
Explain metrics for the query.
-
#read_time ⇒ String
The time at which the aggregate result was computed.
-
#result ⇒ Google::Apis::FirestoreV1::AggregationResult
The result of a single bucket from a Firestore aggregation query.
-
#transaction ⇒ String
The transaction that was started as part of this request.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RunAggregationQueryResponse
constructor
A new instance of RunAggregationQueryResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RunAggregationQueryResponse
Returns a new instance of RunAggregationQueryResponse.
4200 4201 4202 |
# File 'lib/google/apis/firestore_v1/classes.rb', line 4200 def initialize(**args) update!(**args) end |
Instance Attribute Details
#explain_metrics ⇒ Google::Apis::FirestoreV1::ExplainMetrics
Explain metrics for the query.
Corresponds to the JSON property explainMetrics
4175 4176 4177 |
# File 'lib/google/apis/firestore_v1/classes.rb', line 4175 def explain_metrics @explain_metrics end |
#read_time ⇒ String
The time at which the aggregate result was computed. This is always
monotonically increasing; in this case, the previous AggregationResult in the
result stream are guaranteed not to have changed between their read_time and
this one. If the query returns no results, a response with read_time and no
result will be sent, and this represents the time at which the query was run.
Corresponds to the JSON property readTime
4184 4185 4186 |
# File 'lib/google/apis/firestore_v1/classes.rb', line 4184 def read_time @read_time end |
#result ⇒ Google::Apis::FirestoreV1::AggregationResult
The result of a single bucket from a Firestore aggregation query. The keys of
aggregate_fields are the same for all results in an aggregation query, unlike
document queries which can have different fields present for each result.
Corresponds to the JSON property result
4191 4192 4193 |
# File 'lib/google/apis/firestore_v1/classes.rb', line 4191 def result @result end |
#transaction ⇒ String
The transaction that was started as part of this request. Only present on the
first response when the request requested to start a new transaction.
Corresponds to the JSON property transaction
NOTE: Values are automatically base64 encoded/decoded in the client library.
4198 4199 4200 |
# File 'lib/google/apis/firestore_v1/classes.rb', line 4198 def transaction @transaction end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4205 4206 4207 4208 4209 4210 |
# File 'lib/google/apis/firestore_v1/classes.rb', line 4205 def update!(**args) @explain_metrics = args[:explain_metrics] if args.key?(:explain_metrics) @read_time = args[:read_time] if args.key?(:read_time) @result = args[:result] if args.key?(:result) @transaction = args[:transaction] if args.key?(:transaction) end |