Class: Google::Apis::FirestoreV1::RunQueryRequest
- Inherits:
-
Object
- Object
- Google::Apis::FirestoreV1::RunQueryRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/firestore_v1/classes.rb,
lib/google/apis/firestore_v1/representations.rb,
lib/google/apis/firestore_v1/representations.rb
Overview
The request for Firestore.RunQuery.
Instance Attribute Summary collapse
-
#explain_options ⇒ Google::Apis::FirestoreV1::ExplainOptions
Explain options for the query.
-
#new_transaction ⇒ Google::Apis::FirestoreV1::TransactionOptions
Options for creating a new transaction.
-
#read_time ⇒ String
Reads documents as they were at the given time.
-
#structured_query ⇒ Google::Apis::FirestoreV1::StructuredQuery
A Firestore query.
-
#transaction ⇒ String
Run the query within an already active transaction.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RunQueryRequest
constructor
A new instance of RunQueryRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RunQueryRequest
Returns a new instance of RunQueryRequest.
4248 4249 4250 |
# File 'lib/google/apis/firestore_v1/classes.rb', line 4248 def initialize(**args) update!(**args) end |
Instance Attribute Details
#explain_options ⇒ Google::Apis::FirestoreV1::ExplainOptions
Explain options for the query.
Corresponds to the JSON property explainOptions
4220 4221 4222 |
# File 'lib/google/apis/firestore_v1/classes.rb', line 4220 def @explain_options end |
#new_transaction ⇒ Google::Apis::FirestoreV1::TransactionOptions
Options for creating a new transaction.
Corresponds to the JSON property newTransaction
4225 4226 4227 |
# File 'lib/google/apis/firestore_v1/classes.rb', line 4225 def new_transaction @new_transaction end |
#read_time ⇒ String
Reads documents as they were at the given time. This must be a microsecond
precision timestamp within the past one hour, or if Point-in-Time Recovery is
enabled, can additionally be a whole minute timestamp within the past 7 days.
Corresponds to the JSON property readTime
4232 4233 4234 |
# File 'lib/google/apis/firestore_v1/classes.rb', line 4232 def read_time @read_time end |
#structured_query ⇒ Google::Apis::FirestoreV1::StructuredQuery
A Firestore query. The query stages are executed in the following order: 1.
from 2. where 3. select 4. order_by + start_at + end_at 5. offset 6. limit 7.
find_nearest
Corresponds to the JSON property structuredQuery
4239 4240 4241 |
# File 'lib/google/apis/firestore_v1/classes.rb', line 4239 def structured_query @structured_query end |
#transaction ⇒ String
Run the query within an already active transaction. The value here is the
opaque transaction ID to execute the query in.
Corresponds to the JSON property transaction
NOTE: Values are automatically base64 encoded/decoded in the client library.
4246 4247 4248 |
# File 'lib/google/apis/firestore_v1/classes.rb', line 4246 def transaction @transaction end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4253 4254 4255 4256 4257 4258 4259 |
# File 'lib/google/apis/firestore_v1/classes.rb', line 4253 def update!(**args) @explain_options = args[:explain_options] if args.key?(:explain_options) @new_transaction = args[:new_transaction] if args.key?(:new_transaction) @read_time = args[:read_time] if args.key?(:read_time) @structured_query = args[:structured_query] if args.key?(:structured_query) @transaction = args[:transaction] if args.key?(:transaction) end |