Class: Google::Apis::FirestoreV1::StructuredPipeline

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/firestore_v1/classes.rb,
lib/google/apis/firestore_v1/representations.rb,
lib/google/apis/firestore_v1/representations.rb

Overview

A Firestore query represented as an ordered list of operations / stages. This is considered the top-level function which plans and executes a query. It is logically equivalent to query(stages, options), but prevents the client from having to build a function wrapper.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ StructuredPipeline

Returns a new instance of StructuredPipeline.



4456
4457
4458
# File 'lib/google/apis/firestore_v1/classes.rb', line 4456

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#optionsHash<String,Google::Apis::FirestoreV1::Value>

Optional. Optional query-level arguments. Corresponds to the JSON property options

Returns:



4449
4450
4451
# File 'lib/google/apis/firestore_v1/classes.rb', line 4449

def options
  @options
end

#pipelineGoogle::Apis::FirestoreV1::Pipeline

A Firestore query represented as an ordered list of operations / stages. Corresponds to the JSON property pipeline



4454
4455
4456
# File 'lib/google/apis/firestore_v1/classes.rb', line 4454

def pipeline
  @pipeline
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4461
4462
4463
4464
# File 'lib/google/apis/firestore_v1/classes.rb', line 4461

def update!(**args)
  @options = args[:options] if args.key?(:options)
  @pipeline = args[:pipeline] if args.key?(:pipeline)
end