Class: Google::Apis::FirestoreV1::StructuredPipeline
- Inherits:
-
Object
- Object
- Google::Apis::FirestoreV1::StructuredPipeline
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/firestore_v1/classes.rb,
lib/google/apis/firestore_v1/representations.rb,
lib/google/apis/firestore_v1/representations.rb
Overview
A Firestore query represented as an ordered list of operations / stages. This
is considered the top-level function which plans and executes a query. It is
logically equivalent to query(stages, options), but prevents the client from
having to build a function wrapper.
Instance Attribute Summary collapse
-
#options ⇒ Hash<String,Google::Apis::FirestoreV1::Value>
Optional.
-
#pipeline ⇒ Google::Apis::FirestoreV1::Pipeline
A Firestore query represented as an ordered list of operations / stages.
Instance Method Summary collapse
-
#initialize(**args) ⇒ StructuredPipeline
constructor
A new instance of StructuredPipeline.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ StructuredPipeline
Returns a new instance of StructuredPipeline.
4288 4289 4290 |
# File 'lib/google/apis/firestore_v1/classes.rb', line 4288 def initialize(**args) update!(**args) end |
Instance Attribute Details
#options ⇒ Hash<String,Google::Apis::FirestoreV1::Value>
Optional. Optional query-level arguments.
Corresponds to the JSON property options
4281 4282 4283 |
# File 'lib/google/apis/firestore_v1/classes.rb', line 4281 def @options end |
#pipeline ⇒ Google::Apis::FirestoreV1::Pipeline
A Firestore query represented as an ordered list of operations / stages.
Corresponds to the JSON property pipeline
4286 4287 4288 |
# File 'lib/google/apis/firestore_v1/classes.rb', line 4286 def pipeline @pipeline end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4293 4294 4295 4296 |
# File 'lib/google/apis/firestore_v1/classes.rb', line 4293 def update!(**args) @options = args[:options] if args.key?(:options) @pipeline = args[:pipeline] if args.key?(:pipeline) end |