Class: Google::Apis::FirestoreV1::TargetChange
- Inherits:
-
Object
- Object
- Google::Apis::FirestoreV1::TargetChange
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/firestore_v1/classes.rb,
lib/google/apis/firestore_v1/representations.rb,
lib/google/apis/firestore_v1/representations.rb
Overview
Targets being watched have changed.
Instance Attribute Summary collapse
-
#cause ⇒ Google::Apis::FirestoreV1::Status
The
Statustype defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. -
#read_time ⇒ String
The consistent
read_timefor the giventarget_ids(omitted when the target_ids are not at a consistent snapshot). -
#resume_token ⇒ String
A token that can be used to resume the stream for the given
target_ids, or all targets iftarget_idsis empty. -
#target_change_type ⇒ String
The type of change that occurred.
-
#target_ids ⇒ Array<Fixnum>
The target IDs of targets that have changed.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TargetChange
constructor
A new instance of TargetChange.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TargetChange
Returns a new instance of TargetChange.
4534 4535 4536 |
# File 'lib/google/apis/firestore_v1/classes.rb', line 4534 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cause ⇒ Google::Apis::FirestoreV1::Status
The Status type defines a logical error model that is suitable for different
programming environments, including REST APIs and RPC APIs. It is used by
gRPC. Each Status message contains three pieces of
data: error code, error message, and error details. You can find out more
about this error model and how to work with it in the API Design Guide.
Corresponds to the JSON property cause
4503 4504 4505 |
# File 'lib/google/apis/firestore_v1/classes.rb', line 4503 def cause @cause end |
#read_time ⇒ String
The consistent read_time for the given target_ids (omitted when the
target_ids are not at a consistent snapshot). The stream is guaranteed to send
a read_time with target_ids empty whenever the entire stream reaches a new
consistent snapshot. ADD, CURRENT, and RESET messages are guaranteed to (
eventually) result in a new consistent snapshot (while NO_CHANGE and REMOVE
messages are not). For a given stream, read_time is guaranteed to be
monotonically increasing.
Corresponds to the JSON property readTime
4514 4515 4516 |
# File 'lib/google/apis/firestore_v1/classes.rb', line 4514 def read_time @read_time end |
#resume_token ⇒ String
A token that can be used to resume the stream for the given target_ids, or
all targets if target_ids is empty. Not set on every target change.
Corresponds to the JSON property resumeToken
NOTE: Values are automatically base64 encoded/decoded in the client library.
4521 4522 4523 |
# File 'lib/google/apis/firestore_v1/classes.rb', line 4521 def resume_token @resume_token end |
#target_change_type ⇒ String
The type of change that occurred.
Corresponds to the JSON property targetChangeType
4526 4527 4528 |
# File 'lib/google/apis/firestore_v1/classes.rb', line 4526 def target_change_type @target_change_type end |
#target_ids ⇒ Array<Fixnum>
The target IDs of targets that have changed. If empty, the change applies to
all targets. The order of the target IDs is not defined.
Corresponds to the JSON property targetIds
4532 4533 4534 |
# File 'lib/google/apis/firestore_v1/classes.rb', line 4532 def target_ids @target_ids end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4539 4540 4541 4542 4543 4544 4545 |
# File 'lib/google/apis/firestore_v1/classes.rb', line 4539 def update!(**args) @cause = args[:cause] if args.key?(:cause) @read_time = args[:read_time] if args.key?(:read_time) @resume_token = args[:resume_token] if args.key?(:resume_token) @target_change_type = args[:target_change_type] if args.key?(:target_change_type) @target_ids = args[:target_ids] if args.key?(:target_ids) end |