Class: Google::Apis::FirestoreV1::Value
- Inherits:
-
Object
- Object
- Google::Apis::FirestoreV1::Value
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/firestore_v1/classes.rb,
lib/google/apis/firestore_v1/representations.rb,
lib/google/apis/firestore_v1/representations.rb
Overview
A message that can hold any of the supported value types.
Instance Attribute Summary collapse
-
#array_value ⇒ Google::Apis::FirestoreV1::ArrayValue
An array value.
-
#boolean_value ⇒ Boolean
(also: #boolean_value?)
A boolean value.
-
#bytes_value ⇒ String
A bytes value.
-
#double_value ⇒ Float
A double value.
-
#field_reference_value ⇒ String
Value which references a field.
-
#function_value ⇒ Google::Apis::FirestoreV1::Function
Represents an unevaluated scalar expression.
-
#geo_point_value ⇒ Google::Apis::FirestoreV1::LatLng
An object that represents a latitude/longitude pair.
-
#integer_value ⇒ Fixnum
An integer value.
-
#map_value ⇒ Google::Apis::FirestoreV1::MapValue
A map value.
-
#null_value ⇒ String
A null value.
-
#pipeline_value ⇒ Google::Apis::FirestoreV1::Pipeline
A Firestore query represented as an ordered list of operations / stages.
-
#reference_value ⇒ String
A reference to a document.
-
#string_value ⇒ String
A string value.
-
#timestamp_value ⇒ String
A timestamp value.
-
#variable_reference_value ⇒ String
Pointer to a variable defined elsewhere in a pipeline.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Value
constructor
A new instance of Value.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Value
Returns a new instance of Value.
5119 5120 5121 |
# File 'lib/google/apis/firestore_v1/classes.rb', line 5119 def initialize(**args) update!(**args) end |
Instance Attribute Details
#array_value ⇒ Google::Apis::FirestoreV1::ArrayValue
An array value.
Corresponds to the JSON property arrayValue
5026 5027 5028 |
# File 'lib/google/apis/firestore_v1/classes.rb', line 5026 def array_value @array_value end |
#boolean_value ⇒ Boolean Also known as: boolean_value?
A boolean value.
Corresponds to the JSON property booleanValue
5031 5032 5033 |
# File 'lib/google/apis/firestore_v1/classes.rb', line 5031 def boolean_value @boolean_value end |
#bytes_value ⇒ String
A bytes value. In Standard edition databases: * The value must not exceed 1
MiB - 89 bytes. * Only the first 1,500 bytes are considered by queries. In
Enterprise edition databases, there is no limit on the size of the value.
However, it is still subject to document and index entry size limits.
Corresponds to the JSON property bytesValue
NOTE: Values are automatically base64 encoded/decoded in the client library.
5041 5042 5043 |
# File 'lib/google/apis/firestore_v1/classes.rb', line 5041 def bytes_value @bytes_value end |
#double_value ⇒ Float
A double value.
Corresponds to the JSON property doubleValue
5046 5047 5048 |
# File 'lib/google/apis/firestore_v1/classes.rb', line 5046 def double_value @double_value end |
#field_reference_value ⇒ String
Value which references a field. This is considered relative (vs absolute)
since it only refers to a field and not a field within a particular document. *
Requires:* * Must follow field reference limitations. * Not allowed to be
used when writing documents.
Corresponds to the JSON property fieldReferenceValue
5054 5055 5056 |
# File 'lib/google/apis/firestore_v1/classes.rb', line 5054 def field_reference_value @field_reference_value end |
#function_value ⇒ Google::Apis::FirestoreV1::Function
Represents an unevaluated scalar expression. For example, the expression like(
user_name, "%alice%") is represented as: name: "like" args `
field_reference: "user_name" ` args ` string_value: "%alice%" `
Corresponds to the JSON property functionValue
5061 5062 5063 |
# File 'lib/google/apis/firestore_v1/classes.rb', line 5061 def function_value @function_value end |
#geo_point_value ⇒ Google::Apis::FirestoreV1::LatLng
An object that represents a latitude/longitude pair. This is expressed as a
pair of doubles to represent degrees latitude and degrees longitude. Unless
specified otherwise, this object must conform to the WGS84 standard. Values
must be within normalized ranges.
Corresponds to the JSON property geoPointValue
5069 5070 5071 |
# File 'lib/google/apis/firestore_v1/classes.rb', line 5069 def geo_point_value @geo_point_value end |
#integer_value ⇒ Fixnum
An integer value.
Corresponds to the JSON property integerValue
5074 5075 5076 |
# File 'lib/google/apis/firestore_v1/classes.rb', line 5074 def integer_value @integer_value end |
#map_value ⇒ Google::Apis::FirestoreV1::MapValue
A map value.
Corresponds to the JSON property mapValue
5079 5080 5081 |
# File 'lib/google/apis/firestore_v1/classes.rb', line 5079 def map_value @map_value end |
#null_value ⇒ String
A null value.
Corresponds to the JSON property nullValue
5084 5085 5086 |
# File 'lib/google/apis/firestore_v1/classes.rb', line 5084 def null_value @null_value end |
#pipeline_value ⇒ Google::Apis::FirestoreV1::Pipeline
A Firestore query represented as an ordered list of operations / stages.
Corresponds to the JSON property pipelineValue
5089 5090 5091 |
# File 'lib/google/apis/firestore_v1/classes.rb', line 5089 def pipeline_value @pipeline_value end |
#reference_value ⇒ String
A reference to a document. For example: projects/project_id/databases/
database_id/documents/document_path`.
Corresponds to the JSON propertyreferenceValue`
5095 5096 5097 |
# File 'lib/google/apis/firestore_v1/classes.rb', line 5095 def reference_value @reference_value end |
#string_value ⇒ String
A string value. In Standard edition databases: * The string, represented as
UTF-8, must not exceed 1 MiB - 89 bytes. * Only the first 1,500 bytes of the
UTF-8 representation are considered by queries. In Enterprise edition
databases, there is no limit on the size of the value. However, it is still
subject to document and index entry size limits.
Corresponds to the JSON property stringValue
5104 5105 5106 |
# File 'lib/google/apis/firestore_v1/classes.rb', line 5104 def string_value @string_value end |
#timestamp_value ⇒ String
A timestamp value. Precise only to microseconds. When stored, any additional
precision is rounded down.
Corresponds to the JSON property timestampValue
5110 5111 5112 |
# File 'lib/google/apis/firestore_v1/classes.rb', line 5110 def @timestamp_value end |
#variable_reference_value ⇒ String
Pointer to a variable defined elsewhere in a pipeline. Unlike
field_reference_value which references a field within a document, this refers
to a variable, defined in a separate namespace than the fields of a document.
Corresponds to the JSON property variableReferenceValue
5117 5118 5119 |
# File 'lib/google/apis/firestore_v1/classes.rb', line 5117 def variable_reference_value @variable_reference_value end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5124 5125 5126 5127 5128 5129 5130 5131 5132 5133 5134 5135 5136 5137 5138 5139 5140 |
# File 'lib/google/apis/firestore_v1/classes.rb', line 5124 def update!(**args) @array_value = args[:array_value] if args.key?(:array_value) @boolean_value = args[:boolean_value] if args.key?(:boolean_value) @bytes_value = args[:bytes_value] if args.key?(:bytes_value) @double_value = args[:double_value] if args.key?(:double_value) @field_reference_value = args[:field_reference_value] if args.key?(:field_reference_value) @function_value = args[:function_value] if args.key?(:function_value) @geo_point_value = args[:geo_point_value] if args.key?(:geo_point_value) @integer_value = args[:integer_value] if args.key?(:integer_value) @map_value = args[:map_value] if args.key?(:map_value) @null_value = args[:null_value] if args.key?(:null_value) @pipeline_value = args[:pipeline_value] if args.key?(:pipeline_value) @reference_value = args[:reference_value] if args.key?(:reference_value) @string_value = args[:string_value] if args.key?(:string_value) @timestamp_value = args[:timestamp_value] if args.key?(:timestamp_value) @variable_reference_value = args[:variable_reference_value] if args.key?(:variable_reference_value) end |