Class: Google::Apis::FirestoreV1::Value

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/firestore_v1/classes.rb,
lib/google/apis/firestore_v1/representations.rb,
lib/google/apis/firestore_v1/representations.rb

Overview

A message that can hold any of the supported value types.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Value

Returns a new instance of Value.



4962
4963
4964
# File 'lib/google/apis/firestore_v1/classes.rb', line 4962

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#array_valueGoogle::Apis::FirestoreV1::ArrayValue

An array value. Corresponds to the JSON property arrayValue



4873
4874
4875
# File 'lib/google/apis/firestore_v1/classes.rb', line 4873

def array_value
  @array_value
end

#boolean_valueBoolean Also known as: boolean_value?

A boolean value. Corresponds to the JSON property booleanValue

Returns:

  • (Boolean)


4878
4879
4880
# File 'lib/google/apis/firestore_v1/classes.rb', line 4878

def boolean_value
  @boolean_value
end

#bytes_valueString

A bytes value. Must not exceed 1 MiB - 89 bytes. Only the first 1,500 bytes are considered by queries. Corresponds to the JSON property bytesValue NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


4886
4887
4888
# File 'lib/google/apis/firestore_v1/classes.rb', line 4886

def bytes_value
  @bytes_value
end

#double_valueFloat

A double value. Corresponds to the JSON property doubleValue

Returns:

  • (Float)


4891
4892
4893
# File 'lib/google/apis/firestore_v1/classes.rb', line 4891

def double_value
  @double_value
end

#field_reference_valueString

Value which references a field. This is considered relative (vs absolute) since it only refers to a field and not a field within a particular document. * Requires:* * Must follow field reference limitations. * Not allowed to be used when writing documents. Corresponds to the JSON property fieldReferenceValue

Returns:

  • (String)


4899
4900
4901
# File 'lib/google/apis/firestore_v1/classes.rb', line 4899

def field_reference_value
  @field_reference_value
end

#function_valueGoogle::Apis::FirestoreV1::Function

Represents an unevaluated scalar expression. For example, the expression like( user_name, "%alice%") is represented as: name: "like" args ` field_reference: "user_name" ` args ` string_value: "%alice%" ` Corresponds to the JSON property functionValue



4906
4907
4908
# File 'lib/google/apis/firestore_v1/classes.rb', line 4906

def function_value
  @function_value
end

#geo_point_valueGoogle::Apis::FirestoreV1::LatLng

An object that represents a latitude/longitude pair. This is expressed as a pair of doubles to represent degrees latitude and degrees longitude. Unless specified otherwise, this object must conform to the WGS84 standard. Values must be within normalized ranges. Corresponds to the JSON property geoPointValue



4914
4915
4916
# File 'lib/google/apis/firestore_v1/classes.rb', line 4914

def geo_point_value
  @geo_point_value
end

#integer_valueFixnum

An integer value. Corresponds to the JSON property integerValue

Returns:

  • (Fixnum)


4919
4920
4921
# File 'lib/google/apis/firestore_v1/classes.rb', line 4919

def integer_value
  @integer_value
end

#map_valueGoogle::Apis::FirestoreV1::MapValue

A map value. Corresponds to the JSON property mapValue



4924
4925
4926
# File 'lib/google/apis/firestore_v1/classes.rb', line 4924

def map_value
  @map_value
end

#null_valueString

A null value. Corresponds to the JSON property nullValue

Returns:

  • (String)


4929
4930
4931
# File 'lib/google/apis/firestore_v1/classes.rb', line 4929

def null_value
  @null_value
end

#pipeline_valueGoogle::Apis::FirestoreV1::Pipeline

A Firestore query represented as an ordered list of operations / stages. Corresponds to the JSON property pipelineValue



4934
4935
4936
# File 'lib/google/apis/firestore_v1/classes.rb', line 4934

def pipeline_value
  @pipeline_value
end

#reference_valueString

A reference to a document. For example: projects/project_id/databases/ database_id/documents/document_path`. Corresponds to the JSON propertyreferenceValue`

Returns:

  • (String)


4940
4941
4942
# File 'lib/google/apis/firestore_v1/classes.rb', line 4940

def reference_value
  @reference_value
end

#string_valueString

A string value. The string, represented as UTF-8, must not exceed 1 MiB - 89 bytes. Only the first 1,500 bytes of the UTF-8 representation are considered by queries. Corresponds to the JSON property stringValue

Returns:

  • (String)


4947
4948
4949
# File 'lib/google/apis/firestore_v1/classes.rb', line 4947

def string_value
  @string_value
end

#timestamp_valueString

A timestamp value. Precise only to microseconds. When stored, any additional precision is rounded down. Corresponds to the JSON property timestampValue

Returns:

  • (String)


4953
4954
4955
# File 'lib/google/apis/firestore_v1/classes.rb', line 4953

def timestamp_value
  @timestamp_value
end

#variable_reference_valueString

Pointer to a variable defined elsewhere in a pipeline. Unlike field_reference_value which references a field within a document, this refers to a variable, defined in a separate namespace than the fields of a document. Corresponds to the JSON property variableReferenceValue

Returns:

  • (String)


4960
4961
4962
# File 'lib/google/apis/firestore_v1/classes.rb', line 4960

def variable_reference_value
  @variable_reference_value
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4967
4968
4969
4970
4971
4972
4973
4974
4975
4976
4977
4978
4979
4980
4981
4982
4983
# File 'lib/google/apis/firestore_v1/classes.rb', line 4967

def update!(**args)
  @array_value = args[:array_value] if args.key?(:array_value)
  @boolean_value = args[:boolean_value] if args.key?(:boolean_value)
  @bytes_value = args[:bytes_value] if args.key?(:bytes_value)
  @double_value = args[:double_value] if args.key?(:double_value)
  @field_reference_value = args[:field_reference_value] if args.key?(:field_reference_value)
  @function_value = args[:function_value] if args.key?(:function_value)
  @geo_point_value = args[:geo_point_value] if args.key?(:geo_point_value)
  @integer_value = args[:integer_value] if args.key?(:integer_value)
  @map_value = args[:map_value] if args.key?(:map_value)
  @null_value = args[:null_value] if args.key?(:null_value)
  @pipeline_value = args[:pipeline_value] if args.key?(:pipeline_value)
  @reference_value = args[:reference_value] if args.key?(:reference_value)
  @string_value = args[:string_value] if args.key?(:string_value)
  @timestamp_value = args[:timestamp_value] if args.key?(:timestamp_value)
  @variable_reference_value = args[:variable_reference_value] if args.key?(:variable_reference_value)
end