Class: Google::Apis::FirestoreV1::Value
- Inherits:
-
Object
- Object
- Google::Apis::FirestoreV1::Value
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/firestore_v1/classes.rb,
lib/google/apis/firestore_v1/representations.rb,
lib/google/apis/firestore_v1/representations.rb
Overview
A message that can hold any of the supported value types.
Instance Attribute Summary collapse
-
#array_value ⇒ Google::Apis::FirestoreV1::ArrayValue
An array value.
-
#boolean_value ⇒ Boolean
(also: #boolean_value?)
A boolean value.
-
#bytes_value ⇒ String
A bytes value.
-
#double_value ⇒ Float
A double value.
-
#field_reference_value ⇒ String
Value which references a field.
-
#function_value ⇒ Google::Apis::FirestoreV1::Function
Represents an unevaluated scalar expression.
-
#geo_point_value ⇒ Google::Apis::FirestoreV1::LatLng
An object that represents a latitude/longitude pair.
-
#integer_value ⇒ Fixnum
An integer value.
-
#map_value ⇒ Google::Apis::FirestoreV1::MapValue
A map value.
-
#null_value ⇒ String
A null value.
-
#pipeline_value ⇒ Google::Apis::FirestoreV1::Pipeline
A Firestore query represented as an ordered list of operations / stages.
-
#reference_value ⇒ String
A reference to a document.
-
#string_value ⇒ String
A string value.
-
#timestamp_value ⇒ String
A timestamp value.
-
#variable_reference_value ⇒ String
Pointer to a variable defined elsewhere in a pipeline.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Value
constructor
A new instance of Value.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Value
Returns a new instance of Value.
4867 4868 4869 |
# File 'lib/google/apis/firestore_v1/classes.rb', line 4867 def initialize(**args) update!(**args) end |
Instance Attribute Details
#array_value ⇒ Google::Apis::FirestoreV1::ArrayValue
An array value.
Corresponds to the JSON property arrayValue
4778 4779 4780 |
# File 'lib/google/apis/firestore_v1/classes.rb', line 4778 def array_value @array_value end |
#boolean_value ⇒ Boolean Also known as: boolean_value?
A boolean value.
Corresponds to the JSON property booleanValue
4783 4784 4785 |
# File 'lib/google/apis/firestore_v1/classes.rb', line 4783 def boolean_value @boolean_value end |
#bytes_value ⇒ String
A bytes value. Must not exceed 1 MiB - 89 bytes. Only the first 1,500 bytes
are considered by queries.
Corresponds to the JSON property bytesValue
NOTE: Values are automatically base64 encoded/decoded in the client library.
4791 4792 4793 |
# File 'lib/google/apis/firestore_v1/classes.rb', line 4791 def bytes_value @bytes_value end |
#double_value ⇒ Float
A double value.
Corresponds to the JSON property doubleValue
4796 4797 4798 |
# File 'lib/google/apis/firestore_v1/classes.rb', line 4796 def double_value @double_value end |
#field_reference_value ⇒ String
Value which references a field. This is considered relative (vs absolute)
since it only refers to a field and not a field within a particular document. *
Requires:* * Must follow field reference limitations. * Not allowed to be
used when writing documents.
Corresponds to the JSON property fieldReferenceValue
4804 4805 4806 |
# File 'lib/google/apis/firestore_v1/classes.rb', line 4804 def field_reference_value @field_reference_value end |
#function_value ⇒ Google::Apis::FirestoreV1::Function
Represents an unevaluated scalar expression. For example, the expression like(
user_name, "%alice%") is represented as: name: "like" args `
field_reference: "user_name" ` args ` string_value: "%alice%" `
Corresponds to the JSON property functionValue
4811 4812 4813 |
# File 'lib/google/apis/firestore_v1/classes.rb', line 4811 def function_value @function_value end |
#geo_point_value ⇒ Google::Apis::FirestoreV1::LatLng
An object that represents a latitude/longitude pair. This is expressed as a
pair of doubles to represent degrees latitude and degrees longitude. Unless
specified otherwise, this object must conform to the WGS84 standard. Values
must be within normalized ranges.
Corresponds to the JSON property geoPointValue
4819 4820 4821 |
# File 'lib/google/apis/firestore_v1/classes.rb', line 4819 def geo_point_value @geo_point_value end |
#integer_value ⇒ Fixnum
An integer value.
Corresponds to the JSON property integerValue
4824 4825 4826 |
# File 'lib/google/apis/firestore_v1/classes.rb', line 4824 def integer_value @integer_value end |
#map_value ⇒ Google::Apis::FirestoreV1::MapValue
A map value.
Corresponds to the JSON property mapValue
4829 4830 4831 |
# File 'lib/google/apis/firestore_v1/classes.rb', line 4829 def map_value @map_value end |
#null_value ⇒ String
A null value.
Corresponds to the JSON property nullValue
4834 4835 4836 |
# File 'lib/google/apis/firestore_v1/classes.rb', line 4834 def null_value @null_value end |
#pipeline_value ⇒ Google::Apis::FirestoreV1::Pipeline
A Firestore query represented as an ordered list of operations / stages.
Corresponds to the JSON property pipelineValue
4839 4840 4841 |
# File 'lib/google/apis/firestore_v1/classes.rb', line 4839 def pipeline_value @pipeline_value end |
#reference_value ⇒ String
A reference to a document. For example: projects/project_id/databases/
database_id/documents/document_path`.
Corresponds to the JSON propertyreferenceValue`
4845 4846 4847 |
# File 'lib/google/apis/firestore_v1/classes.rb', line 4845 def reference_value @reference_value end |
#string_value ⇒ String
A string value. The string, represented as UTF-8, must not exceed 1 MiB - 89
bytes. Only the first 1,500 bytes of the UTF-8 representation are considered
by queries.
Corresponds to the JSON property stringValue
4852 4853 4854 |
# File 'lib/google/apis/firestore_v1/classes.rb', line 4852 def string_value @string_value end |
#timestamp_value ⇒ String
A timestamp value. Precise only to microseconds. When stored, any additional
precision is rounded down.
Corresponds to the JSON property timestampValue
4858 4859 4860 |
# File 'lib/google/apis/firestore_v1/classes.rb', line 4858 def @timestamp_value end |
#variable_reference_value ⇒ String
Pointer to a variable defined elsewhere in a pipeline. Unlike
field_reference_value which references a field within a document, this refers
to a variable, defined in a separate namespace than the fields of a document.
Corresponds to the JSON property variableReferenceValue
4865 4866 4867 |
# File 'lib/google/apis/firestore_v1/classes.rb', line 4865 def variable_reference_value @variable_reference_value end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4872 4873 4874 4875 4876 4877 4878 4879 4880 4881 4882 4883 4884 4885 4886 4887 4888 |
# File 'lib/google/apis/firestore_v1/classes.rb', line 4872 def update!(**args) @array_value = args[:array_value] if args.key?(:array_value) @boolean_value = args[:boolean_value] if args.key?(:boolean_value) @bytes_value = args[:bytes_value] if args.key?(:bytes_value) @double_value = args[:double_value] if args.key?(:double_value) @field_reference_value = args[:field_reference_value] if args.key?(:field_reference_value) @function_value = args[:function_value] if args.key?(:function_value) @geo_point_value = args[:geo_point_value] if args.key?(:geo_point_value) @integer_value = args[:integer_value] if args.key?(:integer_value) @map_value = args[:map_value] if args.key?(:map_value) @null_value = args[:null_value] if args.key?(:null_value) @pipeline_value = args[:pipeline_value] if args.key?(:pipeline_value) @reference_value = args[:reference_value] if args.key?(:reference_value) @string_value = args[:string_value] if args.key?(:string_value) @timestamp_value = args[:timestamp_value] if args.key?(:timestamp_value) @variable_reference_value = args[:variable_reference_value] if args.key?(:variable_reference_value) end |