Class: Google::Apis::FirestoreV1::Value

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/firestore_v1/classes.rb,
lib/google/apis/firestore_v1/representations.rb,
lib/google/apis/firestore_v1/representations.rb

Overview

A message that can hold any of the supported value types.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Value

Returns a new instance of Value.



4857
4858
4859
# File 'lib/google/apis/firestore_v1/classes.rb', line 4857

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#array_valueGoogle::Apis::FirestoreV1::ArrayValue

An array value. Corresponds to the JSON property arrayValue



4768
4769
4770
# File 'lib/google/apis/firestore_v1/classes.rb', line 4768

def array_value
  @array_value
end

#boolean_valueBoolean Also known as: boolean_value?

A boolean value. Corresponds to the JSON property booleanValue

Returns:

  • (Boolean)


4773
4774
4775
# File 'lib/google/apis/firestore_v1/classes.rb', line 4773

def boolean_value
  @boolean_value
end

#bytes_valueString

A bytes value. Must not exceed 1 MiB - 89 bytes. Only the first 1,500 bytes are considered by queries. Corresponds to the JSON property bytesValue NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


4781
4782
4783
# File 'lib/google/apis/firestore_v1/classes.rb', line 4781

def bytes_value
  @bytes_value
end

#double_valueFloat

A double value. Corresponds to the JSON property doubleValue

Returns:

  • (Float)


4786
4787
4788
# File 'lib/google/apis/firestore_v1/classes.rb', line 4786

def double_value
  @double_value
end

#field_reference_valueString

Value which references a field. This is considered relative (vs absolute) since it only refers to a field and not a field within a particular document. * Requires:* * Must follow field reference limitations. * Not allowed to be used when writing documents. Corresponds to the JSON property fieldReferenceValue

Returns:

  • (String)


4794
4795
4796
# File 'lib/google/apis/firestore_v1/classes.rb', line 4794

def field_reference_value
  @field_reference_value
end

#function_valueGoogle::Apis::FirestoreV1::Function

Represents an unevaluated scalar expression. For example, the expression like( user_name, "%alice%") is represented as: name: "like" args ` field_reference: "user_name" ` args ` string_value: "%alice%" ` Corresponds to the JSON property functionValue



4801
4802
4803
# File 'lib/google/apis/firestore_v1/classes.rb', line 4801

def function_value
  @function_value
end

#geo_point_valueGoogle::Apis::FirestoreV1::LatLng

An object that represents a latitude/longitude pair. This is expressed as a pair of doubles to represent degrees latitude and degrees longitude. Unless specified otherwise, this object must conform to the WGS84 standard. Values must be within normalized ranges. Corresponds to the JSON property geoPointValue



4809
4810
4811
# File 'lib/google/apis/firestore_v1/classes.rb', line 4809

def geo_point_value
  @geo_point_value
end

#integer_valueFixnum

An integer value. Corresponds to the JSON property integerValue

Returns:

  • (Fixnum)


4814
4815
4816
# File 'lib/google/apis/firestore_v1/classes.rb', line 4814

def integer_value
  @integer_value
end

#map_valueGoogle::Apis::FirestoreV1::MapValue

A map value. Corresponds to the JSON property mapValue



4819
4820
4821
# File 'lib/google/apis/firestore_v1/classes.rb', line 4819

def map_value
  @map_value
end

#null_valueString

A null value. Corresponds to the JSON property nullValue

Returns:

  • (String)


4824
4825
4826
# File 'lib/google/apis/firestore_v1/classes.rb', line 4824

def null_value
  @null_value
end

#pipeline_valueGoogle::Apis::FirestoreV1::Pipeline

A Firestore query represented as an ordered list of operations / stages. Corresponds to the JSON property pipelineValue



4829
4830
4831
# File 'lib/google/apis/firestore_v1/classes.rb', line 4829

def pipeline_value
  @pipeline_value
end

#reference_valueString

A reference to a document. For example: projects/project_id/databases/ database_id/documents/document_path`. Corresponds to the JSON propertyreferenceValue`

Returns:

  • (String)


4835
4836
4837
# File 'lib/google/apis/firestore_v1/classes.rb', line 4835

def reference_value
  @reference_value
end

#string_valueString

A string value. The string, represented as UTF-8, must not exceed 1 MiB - 89 bytes. Only the first 1,500 bytes of the UTF-8 representation are considered by queries. Corresponds to the JSON property stringValue

Returns:

  • (String)


4842
4843
4844
# File 'lib/google/apis/firestore_v1/classes.rb', line 4842

def string_value
  @string_value
end

#timestamp_valueString

A timestamp value. Precise only to microseconds. When stored, any additional precision is rounded down. Corresponds to the JSON property timestampValue

Returns:

  • (String)


4848
4849
4850
# File 'lib/google/apis/firestore_v1/classes.rb', line 4848

def timestamp_value
  @timestamp_value
end

#variable_reference_valueString

Pointer to a variable defined elsewhere in a pipeline. Unlike field_reference_value which references a field within a document, this refers to a variable, defined in a separate namespace than the fields of a document. Corresponds to the JSON property variableReferenceValue

Returns:

  • (String)


4855
4856
4857
# File 'lib/google/apis/firestore_v1/classes.rb', line 4855

def variable_reference_value
  @variable_reference_value
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4862
4863
4864
4865
4866
4867
4868
4869
4870
4871
4872
4873
4874
4875
4876
4877
4878
# File 'lib/google/apis/firestore_v1/classes.rb', line 4862

def update!(**args)
  @array_value = args[:array_value] if args.key?(:array_value)
  @boolean_value = args[:boolean_value] if args.key?(:boolean_value)
  @bytes_value = args[:bytes_value] if args.key?(:bytes_value)
  @double_value = args[:double_value] if args.key?(:double_value)
  @field_reference_value = args[:field_reference_value] if args.key?(:field_reference_value)
  @function_value = args[:function_value] if args.key?(:function_value)
  @geo_point_value = args[:geo_point_value] if args.key?(:geo_point_value)
  @integer_value = args[:integer_value] if args.key?(:integer_value)
  @map_value = args[:map_value] if args.key?(:map_value)
  @null_value = args[:null_value] if args.key?(:null_value)
  @pipeline_value = args[:pipeline_value] if args.key?(:pipeline_value)
  @reference_value = args[:reference_value] if args.key?(:reference_value)
  @string_value = args[:string_value] if args.key?(:string_value)
  @timestamp_value = args[:timestamp_value] if args.key?(:timestamp_value)
  @variable_reference_value = args[:variable_reference_value] if args.key?(:variable_reference_value)
end