Class: Google::Apis::FirestoreV1::Write
- Inherits:
-
Object
- Object
- Google::Apis::FirestoreV1::Write
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/firestore_v1/classes.rb,
lib/google/apis/firestore_v1/representations.rb,
lib/google/apis/firestore_v1/representations.rb
Overview
A write on a document.
Instance Attribute Summary collapse
-
#current_document ⇒ Google::Apis::FirestoreV1::Precondition
A precondition on a document, used for conditional operations.
-
#delete ⇒ String
A document name to delete.
-
#transform ⇒ Google::Apis::FirestoreV1::DocumentTransform
A transformation of a document.
-
#update ⇒ Google::Apis::FirestoreV1::Document
A Firestore document.
-
#update_mask ⇒ Google::Apis::FirestoreV1::DocumentMask
A set of field paths on a document.
-
#update_transforms ⇒ Array<Google::Apis::FirestoreV1::FieldTransform>
The transforms to perform after update.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Write
constructor
A new instance of Write.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Write
Returns a new instance of Write.
5026 5027 5028 |
# File 'lib/google/apis/firestore_v1/classes.rb', line 5026 def initialize(**args) update!(**args) end |
Instance Attribute Details
#current_document ⇒ Google::Apis::FirestoreV1::Precondition
A precondition on a document, used for conditional operations.
Corresponds to the JSON property currentDocument
4993 4994 4995 |
# File 'lib/google/apis/firestore_v1/classes.rb', line 4993 def current_document @current_document end |
#delete ⇒ String
A document name to delete. In the format: projects/project_id/databases/
database_id/documents/document_path`.
Corresponds to the JSON propertydelete`
4999 5000 5001 |
# File 'lib/google/apis/firestore_v1/classes.rb', line 4999 def delete @delete end |
#transform ⇒ Google::Apis::FirestoreV1::DocumentTransform
A transformation of a document.
Corresponds to the JSON property transform
5004 5005 5006 |
# File 'lib/google/apis/firestore_v1/classes.rb', line 5004 def transform @transform end |
#update ⇒ Google::Apis::FirestoreV1::Document
A Firestore document. Must not exceed 1 MiB - 4 bytes.
Corresponds to the JSON property update
5009 5010 5011 |
# File 'lib/google/apis/firestore_v1/classes.rb', line 5009 def update @update end |
#update_mask ⇒ Google::Apis::FirestoreV1::DocumentMask
A set of field paths on a document. Used to restrict a get or update operation
on a document to a subset of its fields. This is different from standard field
masks, as this is always scoped to a Document, and takes in account the
dynamic nature of Value.
Corresponds to the JSON property updateMask
5017 5018 5019 |
# File 'lib/google/apis/firestore_v1/classes.rb', line 5017 def update_mask @update_mask end |
#update_transforms ⇒ Array<Google::Apis::FirestoreV1::FieldTransform>
The transforms to perform after update. This field can be set only when the
operation is update. If present, this write is equivalent to performing
update and transform to the same document atomically and in order.
Corresponds to the JSON property updateTransforms
5024 5025 5026 |
# File 'lib/google/apis/firestore_v1/classes.rb', line 5024 def update_transforms @update_transforms end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5031 5032 5033 5034 5035 5036 5037 5038 |
# File 'lib/google/apis/firestore_v1/classes.rb', line 5031 def update!(**args) @current_document = args[:current_document] if args.key?(:current_document) @delete = args[:delete] if args.key?(:delete) @transform = args[:transform] if args.key?(:transform) @update = args[:update] if args.key?(:update) @update_mask = args[:update_mask] if args.key?(:update_mask) @update_transforms = args[:update_transforms] if args.key?(:update_transforms) end |