Class: Google::Apis::FirestoreV1::Write

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/firestore_v1/classes.rb,
lib/google/apis/firestore_v1/representations.rb,
lib/google/apis/firestore_v1/representations.rb

Overview

A write on a document.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Write

Returns a new instance of Write.



4941
4942
4943
# File 'lib/google/apis/firestore_v1/classes.rb', line 4941

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#current_documentGoogle::Apis::FirestoreV1::Precondition

A precondition on a document, used for conditional operations. Corresponds to the JSON property currentDocument



4908
4909
4910
# File 'lib/google/apis/firestore_v1/classes.rb', line 4908

def current_document
  @current_document
end

#deleteString

A document name to delete. In the format: projects/project_id/databases/ database_id/documents/document_path`. Corresponds to the JSON propertydelete`

Returns:

  • (String)


4914
4915
4916
# File 'lib/google/apis/firestore_v1/classes.rb', line 4914

def delete
  @delete
end

#transformGoogle::Apis::FirestoreV1::DocumentTransform

A transformation of a document. Corresponds to the JSON property transform



4919
4920
4921
# File 'lib/google/apis/firestore_v1/classes.rb', line 4919

def transform
  @transform
end

#updateGoogle::Apis::FirestoreV1::Document

A Firestore document. Must not exceed 1 MiB - 4 bytes. Corresponds to the JSON property update



4924
4925
4926
# File 'lib/google/apis/firestore_v1/classes.rb', line 4924

def update
  @update
end

#update_maskGoogle::Apis::FirestoreV1::DocumentMask

A set of field paths on a document. Used to restrict a get or update operation on a document to a subset of its fields. This is different from standard field masks, as this is always scoped to a Document, and takes in account the dynamic nature of Value. Corresponds to the JSON property updateMask



4932
4933
4934
# File 'lib/google/apis/firestore_v1/classes.rb', line 4932

def update_mask
  @update_mask
end

#update_transformsArray<Google::Apis::FirestoreV1::FieldTransform>

The transforms to perform after update. This field can be set only when the operation is update. If present, this write is equivalent to performing update and transform to the same document atomically and in order. Corresponds to the JSON property updateTransforms



4939
4940
4941
# File 'lib/google/apis/firestore_v1/classes.rb', line 4939

def update_transforms
  @update_transforms
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4946
4947
4948
4949
4950
4951
4952
4953
# File 'lib/google/apis/firestore_v1/classes.rb', line 4946

def update!(**args)
  @current_document = args[:current_document] if args.key?(:current_document)
  @delete = args[:delete] if args.key?(:delete)
  @transform = args[:transform] if args.key?(:transform)
  @update = args[:update] if args.key?(:update)
  @update_mask = args[:update_mask] if args.key?(:update_mask)
  @update_transforms = args[:update_transforms] if args.key?(:update_transforms)
end